(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    382470,      11584]*)
(*NotebookOutlinePosition[    412696,      12685]*)
(*  CellTagsIndexPosition[    412652,      12681]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["The Seesaw/Pendulum Process", "Title",
  CellMargins->{{0, -87}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{0, Inherited}, {Inherited, Inherited}},
  TextAlignment->Left,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Modeling, Controller Design, Code Generation,\nand \
Simulation",
  FontSize->25]], "Subtitle",
  TextAlignment->Left,
  TextJustification->0],

Cell["Copyright \[Copyright] MathCore AB 1999-2004", "Copyright"],

Cell[TextData[StyleBox["This notebook will not work correctly in Mathematica \
6.0 and higher.",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(CSP\)\(=\)\(False\)\(\ \)\( (*\ 
        Whether\ Control\ System\ Professional\ is\ installed\ *) \)\(\ \
\)\)\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
This notebook illustrates how to build a dynamic model of a \
physical system and then generate efficient code for simulation.\
\>", "Text"],

Cell["\<\
The physical system is a seesaw where two carts C1 and C2 can be \
moved along two tracks by controlling the forces acting on them. Cart C1 \
carries a weight and cart C2 has an inverted pendulum attached by a friction \
free joint.\
\>", "Text"],

Cell[TextData[{
  "The model of the open loop system has the forces ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_2\)]],
  " acting on each cart as inputs. We first model the system by Lagrangian \
methodology and then linearize the obtained nonlinear model. The linearized \
model is used for control system design where the Control System Professional \
(CSP) application package is used. The closed loop system are then simulated \
both within ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and by external code generated using ",
  StyleBox["MathCode C++",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009/00018`P10`400001
00000800002008200000P800P020P<30`<3L`:K:l000DP00[@1B001BDP1B
[@1Bo`2]002]DP2][@2]o`3oDP3o[E800580DU80[E80oe9B059BDU9B[E9B
oe:]05:]DU:][E:]oe;o05;oDU;o[E;oojd00:d0DZd0[Jd0ojeB0:eBDZeB
[JeBojf]0:f]DZf][Jf]ojgo0:goDZgo[Jgoool0D_l0[OmB0?mBD_mB[OmB
oon]0?n]D_n][On]ooooD_oo[@0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?okl:2PY820P?l0003o0?oo0000ool0o`3o
oooooooooom^o`00ooooofko0007o`030?oo01co00<0ool08_l00`3oo`0Q
o`030?oo023o00<0ool06ol00`3oo`0Qo`030?oo01ko00<0ool07ol00`3o
o`0Po`030?oo027o00<0ool07Ol00`3oo`0So`030?oo01Wo00<0ool09?l0
0`3oo`0Mo`030?oo02;o00<0ool07?l00`3oo`0No`001ol00`3oo`0Ko`03
0?oo02?o00<0ool08?l00`3oo`0Po`030?oo01co00<0ool08Ol00`3oo`0M
o`030?oo01oo00<0ool08Ol00`3oo`0Qo`030?oo01go00<0ool08_l00`3o
o`0Io`030?oo02Co00<0ool07Ol00`3oo`0Ro`030?oo01go00<0ool07_l0
00Oo00<0ool06ol00`3oo`0Ro`030?oo027o00<0ool08?l00`3oo`0Lo`03
0?oo023o00<0ool07_l00`3oo`0Oo`030?oo027o00<0ool08?l00`3oo`0M
o`030?oo02?o00<0ool06Ol00`3oo`0To`030?oo01go00<0ool08_l00`3o
o`0Lo`030?oo01oo0006o`030?oo01co00<0ool08_l00`3oo`0Qo`030?oo
01oo00<0ool07?l00`3oo`0Qo`030?oo01go00<0ool08?l00`3oo`0Po`03
0?oo027o00<0ool07Ol00`3oo`0Ro`030?oo01[o00<0ool09?l00`3oo`0M
o`030?oo02;o00<0ool07?l00`3oo`0No`400006o`030?oo01_o00<0ool0
8_l00`3oo`0Qo`030?oo023o00<0ool07?l00`3oo`0Po`030?oo01ko00<0
ool07ol00`3oo`0Qo`030?oo027o00<0ool07Ol00`3oo`0Ro`030?oo01Wo
00<0ool09?l00`3oo`0Mo`030?oo02;o00<0ool07?l00`3oo`0Oo`400005
o`030?oo01co00<0ool08_l00`3oo`0Qo`030?oo023o00<0ool06ol00`3o
o`0Qo`030?oo01ko00<0ool07ol00`3oo`0Po`030?oo027o00<0ool07Ol0
0`3oo`0So`030?oo01Wo00<0ool09?l00`3oo`0Mo`030?oo02;o00<0ool0
7?l00`3oo`0Oo`400005o`030?oo01_o00<0ool08ol00`3oo`0Po`030?oo
023o00<0ool07?l00`3oo`0Qo`030?oo01go00<0ool07ol00`3oo`0Qo`03
0?oo027o00<0ool07Ol00`3oo`0Ro`030?oo01Wo00<0ool09?l00`3oo`0M
o`030?oo02;o00<0ool07Ol00`3oo`0No`400Ol000Go00<0ool06ol00`3o
o`0Ro`030?oo027o00<0ool08?l00`3oo`0Lo`030?oo023o00<0ool07_l0
0`3oo`0Oo`030?oo027o00<0ool08?l00`3oo`0Mo`030?oo02?o00<0ool0
6Ol00`3oo`0To`030?oo01go00<0ool08_l00`3oo`0Lo`030?oo01oo0@01
o`001?l00`3oo`0Lo`030?oo02;o00<0ool08Ol00`3oo`0Oo`030?oo01co
00<0ool08Ol00`3oo`0Mo`030?oo023o00<0ool08?l00`3oo`0Qo`030?oo
01go00<0ool08_l00`3oo`0Jo`030?oo02Co00<0ool07Ol00`3oo`0Ro`03
0?oo01co00<0ool07_l1007o0Ol000Co00<0ool06ol00`3oo`0Ro`030?oo
027o00<0ool08?l00`3oo`0Lo`030?oo023o00<0ool07_l00`3oo`0Oo`03
0?oo027o00<0ool08Ol00`3oo`0Mo`030?oo02;o00<0ool06Ol00`3oo`0T
o`030?oo01go00<0ool08_l00`3oo`0Lo`030?oo01oo0@01o`7o0003o`03
0?oo01co00<0ool08_l00`3oo`0Qo`030?oo023o00<0ool06ol00`3oo`0Q
o`030?oo01ko00<0ool07ol00`3oo`0Po`030?oo027o00<0ool07Ol00`3o
o`0So`030?oo01Wo00<0ool09?l00`3oo`0Mo`030?oo02;o00<0ool07?l0
0`3oo`0Oo`400Ol1o`000ol00`3oo`0Ko`030?oo02?o00<0ool08?l00`3o
o`0Po`030?oo01co00<0ool08Ol00`3oo`0Mo`030?oo01oo00<0ool08Ol0
0`3oo`0Qo`030?oo01go00<0ool08_l00`3oo`0Io`030?oo02Co00<0ool0
7Ol00`3oo`0Ro`030?oo01go00<0ool07_l00`3oo`01o`000ol00`3oo`0K
o`030?oo02;o00<0ool08Ol00`3oo`0Po`030?oo01co00<0ool08?l00`3o
o`0No`030?oo01oo00<0ool08Ol00`3oo`0Po`030?oo01go00<0ool08ol0
0`3oo`0Io`030?oo02Co00<0ool07Ol00`3oo`0Ro`030?oo01co00<0ool0
7ol00`3oo`01o`000_l00`3oo`0Lo`030?oo02;o00<0ool08Ol00`3oo`0O
o`030?oo01co00<0ool08Ol00`3oo`0Mo`030?oo023o00<0ool08?l00`3o
o`0Qo`030?oo01go00<0ool08_l00`3oo`0Jo`030?oo02Co00<0ool07Ol0
0`3oo`0Ro`030?oo01co00<0ool07_l00`3oo`02o`000_l00`3oo`0Ko`03
0?oo02;o00<0ool08Ol00`3oo`0Po`030?oo01co00<0ool08?l00`3oo`0N
o`030?oo01oo00<0ool08Ol00`3oo`0Qo`030?oo01go00<0ool08_l00`3o
o`0Io`030?oo02Co00<0ool07Ol00`3oo`0Ro`030?oo01co00<0ool07ol0
0`3oo`02o`00o`3o06/00ol00?oo:_l600[o1P3oobko003oobCo1P0Fo`H0
oolXo`00oolNo`H08_l60?oo8_l00?oo6?l602ko1P3ooaco003ooa;o1P0j
o`H0oolFo`00ool<o`H0A_l60?oo4?l00?oo1_l605;o1P3oo`[o003oo`H0
G_l60?oo1?l00?Wo1P1Zo`H0oOl00??o1P1fo`H0mol00>go1P22o`H0lOl0
0>Oo1P2>o`H0jol00>7o1P2Jo`H0iOl00=_o1P2Vo`H0gol00=Go1P2bo`H0
fOl00<oo1P2no`H0dol00<Wo1P3:o`H0cOl00<?o1P3Fo`H0aol00;go1P3R
o`H0`Ol00;Oo1P3^o`H0^ol00;7o1P3jo`H0]Ol00:_o1P3oo`Oo1P2_o`00
YOl60?oo4ol60:Wo002Oo`H0oolOo`H0Xol009Wo1P3oob_o1P2Mo`00Tol6
0?oo=ol609Oo002=o`H0oom3o`H0TOl008Oo1P3oodoo1P2;o`00POl60?oo
Fol608Go001ko`H0oomWo`H0Ool007Go1P3oog?o1P1io`00Kol60?ooOol6
07?o001Yo`H0oon;o`H0KOl006Ko0`3ooiOo0`1Zo`00I_l00`3oo`3ooiWo
00<0ool0J?l006Ko00<0ool0oonIo`030?oo06So001Vo`030?oo0?ooVOl0
0`3oo`1Xo`00I_l00`3oo`3ooiWo00<0ool0J?l006Ko00<0ool0a_l50<go
00<0ool0J?l006Ko00<0ool0a?l90<_o00<0ool0J?l006Ko00<0ool0a?l3
00Co0`3:o`030?oo06So001Vo`030?oo0<?o0P07o`80b_l00`3oo`1Xo`00
I_l00`3oo`33o`801ol20<[o00<0ool0J?l006Ko00<0ool0c?l20<[o00<0
ool0J?l006Ko00<0ool0bOl40<_o00<0ool0J?l006Ko00<0ool0a_l50<go
00<0ool0J?l006Ko00<0ool0aOl30=3o00<0ool0J?l006Ko00<0ool0a?l2
0=;o00<0ool0J?l006Ko00<0ool0a?l200Ko0P3:o`030?oo06So001Vo`03
0?oo0<Co0`04o`<0b_l00`3oo`1Xo`00I_l00`3oo`35o`P0bol00`3oo`1X
o`00I_l00`3oo`36o`H0c?l00`3oo`1Xo`00I_l00`3oo`3ooiWo00<0ool0
J?l006Ko00<0ool0oonIo`030?oo06So001Vo`030?oo0?ooVOl00`3oo`1X
o`00I_l00`3oo`3ooiWo00<0ool0J?l006Ko00<0ool0oonIo`030?oo06So
001Vo`030?oo0?ooVOl00`3oo`1Xo`00I_l00`3oo`3ooiWo00<0ool0J?l0
06Ko00<0ool0oonIo`030?oo06So001Vo`030?oo0?ooVOl00`3oo`1Xo`00
I_l00`3oo`3ooiWo00<0ool0J?l006Ko00<0ool0oonIo`030?oo06So001V
o`030?oo0?ooVOl00`3oo`1Xo`00I_l00`3oo`3ooiWo00<0ool0J?l006Ko
00<0ool0oonIo`030?oo06So001Vo`030?oo0?ooVOl00`3oo`1Xo`00I_oo
09d0J_l00=So00<0ool00ol201;o00<0ool00ol204go1@0Eo`@0ool8o`00
eol00`3oo`06o`030?oo00ko00<0ool01_l00`3oo`19o`030?oo00?o00<0
ool04?l200Co0P3oo`Ko003Fo`030?oo00Oo00<0ool03Ol00`3oo`07o`03
0?oo04Oo0P07o`030?oo00ko00<0ool01_l00`3oo`3oo`?o003Fo`030?oo
00So00<0ool02ol00`3oo`09o`030?oo04Ko00<0ool01ol00`3oo`0=o`03
0?oo00Oo00<0ool0ool2o`00eOl00`3oo`09o`030?oo00_o00<0ool02Ol0
0`3oo`15o`030?oo00Wo00<0ool02ol00`3oo`08o`030?oo0?oo0_l00=Go
00<0ool02Ol00`3oo`0;o`030?oo00Wo00<0ool0AOl00`3oo`09o`030?oo
00_o00<0ool02Ol00`3oo`3oo`7o003<ocP0?ol00`3oo`09o`030?oo00_o
00<0ool02Ol00`3oo`3oo`7o003<o`030?oo00Oo00<0ool02?l00`3oo`0;
o`030?oo00Wo00<0ool01Ol00`3oo`0mo`030?oo00Wo00<0ool02ol00`3o
o`09o`030?oo0?oo0Ol00<co00<0ool01ol00`3oo`07o`030?oo00go00<0
ool01ol00`3oo`06o`030?oo03Co=`3ko`00c?l00`3oo`08o`030?oo00Ko
00<0ool03_l00`3oo`06o`030?oo00Ko00<0ool0=?l00`3oo`06o`802Ol0
0`3oo`0<o`030?oo00So00<0ool01Ol00`3oo`3io`00c?l00`3oo`09o`03
0?oo00?o0P0Ao`801Ol200Wo00<0ool0=?l00`3oo`07o`030?oo00Ko00<0
ool03_l00`3oo`06o`030?oo00Ko00<0ool0nOl00<co00<0ool02_l601Co
1@0;o`030?oo03Co00<0ool02?l200Go0P0Ao`801Ol00`3oo`07o`030?oo
0?Wo003<o`030?oo03Co00<0ool0=?l00`3oo`09o`H05?l600[o00<0ool0
nOl00<co00<0ool0=?l00`3oo`0do`030?oo03?o00<0ool0nOl00<co00<0
ool0=?l00`3oo`0do`030?oo03?o00<0ool0nOl00<co00<0ool0=?l00`3o
o`0do`030?oo03?o00<0ool0nOl00<co00<0ool0=?l00`3oo`0do`030?oo
03?o00<0ool0nOl00<co00<0ool0=?l00`3oo`0do`030?oo03?o00<0ool0
nOl00<co00<0ool0=?l00`3oo`0do`030?oo03?o00<0ool0nOl00<co00<0
ool0=?l00`3oo`0do`030?oo03?o00<0ool0nOl00<co00<0ool0=?l00`3o
o`0do`030?oo03?o00<0ool0nOl00<co00<0ool0=?l00`3oo`0do`030?oo
03?o00<0ool0nOl00<co00<0ool0=?l00`3oo`0do`030?oo03?o00<0ool0
nOl00<co00<0ool0=?l00`3oo`0do`030?oo03?o00<0ool0nOl00<co00<0
ool0=?l00`3oo`0do`030?oo03?o00<0ool0nOl00<co00<0ool0=?l00`3o
o`0do`030?oo03?o00<0ool0nOl00<co00<0ool0=?l00`3oo`0do`030?oo
03?o00<0ool0nOl00<co00<0ool0=?l00`3oo`0do`030?oo03?o00<0ool0
nOl00<co>00fo`030?oo03?o00<0ool0nOl00=;o:`0mocL0nol00=;o00<0
ool09ol00`3oo`1Fo`030?oo0?oo5Ol00=;o00<0ool09ol00`3oo`1Fo`03
0?oo0?oo5Ol00=;o00<0ool09ol00`3oo`1Go`030?oo0?oo5?l00=;o00<0
ool09ol00`3oo`1Go`030?oo0?oo5?l00=;o00<0ool09ol00`3oo`1Go`03
0?oo0?oo5?l00=;o00<0ool09ol00`3oo`1Go`030?oo0?oo5?l00=;o00<0
ool09ol00`3oo`1Go`030?oo0?oo5?l00=;o00<0ool09ol00`3oo`1Ho`03
0?oo0?oo4ol00=;o00<0ool09ol00`3oo`1Ho`030?oo0?oo4ol00=;o00<0
ool09ol00`3oo`1Ho`030?oo0?oo4ol004Oo100<o`80NOl00`3oo`0Wo`03
0?oo05So00<0ool09ol400Wo2@3Eo`00AOl800[o0P1io`030?oo02Oo00<0
ool0F?l00`3oo`0Uo`P01ol90=Go0014o`<01?l300Wo0P1io`030?oo02Oo
00<0ool0FOl00`3oo`0So`<01?l300Oo0P3Ko`00A?l200Ko0P09o`80NOl[
05_o00<0ool08ol200Ko0P08o`80f_l004?o0P08o`802?l20?oo00<0ool0
8_l200So0P08o`80fOl004?o0P0Bo`80ool00`3oo`0Ro`804ol20=So0013
o`804_l20?oo00<0ool08_l201Co0P3Go`00@ol201;o0P3oo`030?oo02;o
0P0Eo`80e_l004?o0P0Bo`80ool1o`030?oo027o0P0Fo`80eOl004?o0P0?
o`8000?o0000ool1o`030?oo027o0P0Fo`80eOl004Co0P07o`801Ol50?oo
0Ol00`3oo`0Ro`801ol200Go0P05o`80eOl004Co0`05o`802?l30?oo0Ol0
0`3oo`0Ro`<01Ol200Ko0`03o`<0eOl004Go200:o`80ool1o`030?oo02?o
2008o`L0e_l004Oo100<o`80ool2o`030?oo02Co100;o`D0eol00?ooFol0
0`3oo`3ooa3o003ooe_o00<0ool0ool@o`00oomKo`030?oo0?oo4?l00?oo
Fol00`3oo`3ooa3o003ooeco00<0ool0ool?o`00oomLo`030?oo0?oo3ol0
0?ooG?l00`3oo`3oo`oo003ooeco00<0ool0ool?o`00oomLo`030?oo0?oo
3ol00?ooGOl00`3oo`3oo`ko003ooego00<0ool0ool>o`00oomMo`030?oo
0?oo3_l00?ooGOl00`3oo`3oo`ko003ooego00<0ool0ool>o`00oomMo`03
0?oo0?oo3_l00?ooG_l00`3oo`3oo`go003ooeko00<0ool0ool=o`00oomN
o`030?oo0?oo3Ol00?ooG_l00`3oo`3oo`go003ooeko00<0ool0ool=o`00
oomOo`030?oo0?oo3?l00?ooGol00`3oo`3oo`co003ooeoo00<0ool0ool<
o`00oomOo`030?oo0?oo3?l00?ooGol00`3oo`3oo`co003oof3o00<0ool0
ool;o`00oomPo`030?oo0?oo2ol00?ooH?l00`3oo`3oo`_o003oof3o00<0
ool0ool;o`00oomPo`030?oo0?oo2ol00?ooHOl00`3oo`3oo`[o003oof7o
00<0ool0ool:o`00oomQo`030?oo0?oo2_l00?ooHOl00`3oo`3oo`[o003o
of7o00<0ool0ool:o`00oomQo`030?oo0?oo2_l00?ooH_l00`3oo`3oo`Wo
003oof;o00<0ool0ool9o`00oomRo`030?oo0?oo2Ol00?ooH_l00`3oo`3o
o`Wo003oof;o00<0ool0ool9o`00oomSo`030?oo0?oo2?l00?ooHol00`3o
o`3oo`So003oof?o00<0ool0ool8o`00oomSo`030?oo0?oo2?l00?ooHol0
0`3oo`3oo`So003oofCo00<0ool0ool7o`00oomTo`030?oo0?oo1ol00?oo
I?l00`3oo`3oo`Oo003oofCo00<0ool0ool7o`00oomTo`030?oo0?oo1ol0
0?ooI?l00`3oo`3oo`Oo003oofGo00<0ool0ool6o`00oomUo`030?oo0?oo
1_l00?ooIOl00`3oo`3oo`Ko003oofGo00<0ool0ool6o`00oomUo`030?oo
0?oo1_l00?ooI_l00`3oo`3oo`Go003oofKo00<0ool0ool5o`00oomVo`03
0?oo0?oo1Ol00?ooI_l00`3oo`3oo`Go003oofKo00<0ool0ool5o`00oomW
o`030?oo0?oo1?l00?ooIol00`3oo`3oo`Co003oofOo00<0ool0ool4o`00
oomWo`030?oo0?oo1?l00?ooIol00`3oo`3oo`Co003oofSo00<0ool0ool3
o`00oomXo`030?oo0?oo0ol00?ooJ?l00`3oo`3oo`?o003oofSo00<0ool0
ool3o`00oomXo`030?oo0?oo0ol00?ooJ?l00`3oo`3oo`?o003oofWo00<0
ool0ool2o`00oomYo`030?oo0?oo0_l00?ooJOl00`3oo`3oo`;o003oofWo
00<0ool0ool2o`00oomYo`030?oo0?oo0_l00?ooJ_l00`3oo`3oo`7o003o
of[o00<0ool0ool1o`00oomZo`030?oo0?oo0Ol00?ooJ_l00`3oo`3oo`7o
003oof[o00<0ool0ool1o`00oom[o`030?oo0?oo003oof_o00<0ool0ool0
0?ooJol00`3oo`3oo`00oom[o`030?oo0?oo003oof_o00<0ool0ool00?oo
K?l00`3oo`3no`00oom/o`030?oo0?ko003oofco00<0ool0o_l00?ooK?l0
0`3oo`3no`00oom/o`030?oo0?ko003oofco00<0ool0o_l00?ooKOl00`3o
o`3mo`00oom]o`030?oo0?go003oofgo00<0ool0oOl00?ooKOl00`3oo`3m
o`00oom]o`030?oo0?go003oofko00<0ool0o?l00?ooK_l00`3oo`3lo`00
oom^o`030?oo0?co003oofko00<0ool0o?l00?ooK_l00`3oo`3lo`00oom_
o`030?oo0?_o003oofoo00<0ool0nol00?ooKol00`3oo`3ko`00oom_o`03
0?oo0?_o003oofoo00<0ool0nol00?ooKol00`3oo`3ko`00oom`o`030?oo
0?[o003oog3o00<0ool0n_l00?ooL?l00`3oo`3jo`00oom`o`030?oo0?[o
003oog3o00<0ool0n_l00?ooLOl00`3oo`3io`00oomao`030?oo0?Wo003o
og7o00<0ool0nOl00?ooLOl00`3oo`3io`00oomao`030?oo0?Wo003oog;o
00<0ool0n?l00?ooL_l00`3oo`3ho`00oombo`030?oo0?So003oog;o00<0
ool0n?l00?ooL_l00`3oo`3ho`00oomco`030?oo0?Oo003oog?o00<0ool0
mol00?ooLol00`3oo`3go`00oomco`030?oo0?Oo003oog?o00<0ool0mol0
0?ooLol00`3oo`3go`00oomdo`030?oo0?Ko003oogCo00<0ool0m_l00?oo
M?l00`3oo`3fo`00oomdo`030?oo0?Ko003oogCo00<0ool0m_l00?ooMOl0
0`3oo`3eo`00oomeo`030?oo0?Go003oogGo00<0ool0mOl00?ooMOl00`3o
o`3eo`00oomeo`030?oo0?Go003oogKo00<0ool0m?l00?ooM_l00`3oo`3d
o`00oomfo`030?oo0?Co003oogKo00<0ool0m?l00?ooM_l00`3oo`3do`00
oomgo`030?oo0??o003oogOo00<0ool0lol00?ooMol00`3oo`3co`00oomg
o`030?oo0??o003oogOo00<0ool0lol00001\
\>"], "Text",
  ImageSize->{620, 291},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Variables and Constants", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Variables:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "\ttranslation of cart 1 from center of track\n\t",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  "\ttranslation of cart 2 from center of track\n\t\[Theta]\tangle of seesaw \
with vertical\n\t\[Alpha]\tangle of pendulum with normal to track\n\t",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  "\tforce applied to cart 1\n\t",
  Cell[BoxData[
      \(TraditionalForm\`F\_2\)]],
  "\tforce applied to cart 2"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Constants:\n\tJ\tinertia of seesaw with track att height h\n\t",
  Cell[BoxData[
      \(TraditionalForm\`m\_s\)]],
  "\tmass of seesaw with track\n\tc\tcenter of gravity\n\th\theight of track \
from pivot point\n\t",
  Cell[BoxData[
      \(TraditionalForm\`m\_1\)]],
  "\tmass of cart 1 (weight cart, on the back track)\n\t",
  Cell[BoxData[
      \(TraditionalForm\`m\_2\)]],
  "\tmass of cart 2\t (pendulum cart, on the front track)\n\t",
  Cell[BoxData[
      \(TraditionalForm\`m\_p\)]],
  "\tmass of pendulum\n\t",
  Cell[BoxData[
      \(TraditionalForm\`l\_p\)]],
  "\tcenter of mass of pendulum rod (half of full length)\n\tg\tgravitational \
acceleration"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(physicalvalues := {\ \ J \[Rule] 1.6, m\_s \[Rule] 6.6, c \[Rule] 0.06, 
        h \[Rule] 0.115, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tm\_1 \[Rule] 
          0.48 + 0.38, m\_2 \[Rule] 0.48, 
        m\_p \[Rule] 
          0.2, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\ \ l\_p \[Rule] 
          0.61\/2 + 0.03, g \[Rule] 9.81}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mathematical Modeling", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The Lagrangian methodology for deriving dynamic equations of a \
mechanical system consists of introducing so called generalized coordinates \
that describes (angular) positions and (angular) velocities of subsystems of \
the true system. Using these coordinates expressions for the kinetic and \
potential energy for each subsystem can be formed. Once this is done the \
dynamic equations describing the whole system can be derived automatically. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["Computation of the Lagrangian", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Coordinates of the center of mass of the seesaw", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(x\_s := c\ Sin[\[Theta][t]]\), "\n", 
    \(y\_s := c\ Cos[\[Theta][t]]\)}], "Input"],

Cell["The potential and kinetic energies of the seesaw", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(V\_s := m\_s\ g\ y\_s\), "\n", 
    \(T\_s := 
      Simplify[1\/2\ J\ \((\[PartialD]\_t \[Theta][t])\)\^2]\)}], "Input"],

Cell["Coordinates of the center of track", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(x\_c := h\ Sin[\[Theta][t]]\), "\n", 
    \(y\_c := h\ Cos[\[Theta][t]]\)}], "Input"],

Cell["Coordinates of cart 1", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(x\_m1 := x\_c + x\_1[t]\ Cos[\[Theta][t]]\), "\n", 
    \(y\_m1 := y\_c - x\_1[t]\ Sin[\[Theta][t]]\)}], "Input"],

Cell["The potential and kinetic energies of cart 1", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(V\_m1 := m\_1\ g\ y\_m1\), "\n", 
    \(T\_m1 := 
      Simplify[1\/2\ m\_1\ \((\((\[PartialD]\_t x\_m1)\)\^2 + \
\((\[PartialD]\_t y\_m1)\)\^2)\)]\)}], "Input"],

Cell["Coordinates of cart 2", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(x\_m2 := x\_c + x\_2[t]\ Cos[\[Theta][t]]\), "\n", 
    \(y\_m2 := y\_c - x\_2[t]\ Sin[\[Theta][t]]\)}], "Input"],

Cell["The potential and kinetic energies of cart 2", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(V\_m2 := m\_2\ g\ y\_m2\), "\n", 
    \(T\_m2 := 
      Simplify[1\/2\ m\_2\ \((\((\[PartialD]\_t x\_m2)\)\^2 + \
\((\[PartialD]\_t y\_m2)\)\^2)\)]\)}], "Input"],

Cell["Coordinates of the center of mass of the pendulum", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(x\_p := x\_m2 + l\_p\ Sin[\[Alpha][t] + \[Theta][t]]\), "\n", 
    \(y\_p := y\_m2 + l\_p\ Cos[\[Alpha][t] + \[Theta][t]]\)}], "Input"],

Cell["The potential and kinetic energies of the pendulum", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(V\_p := m\_p\ g\ y\_p\), "\n", 
    \(T\_p := 
      Simplify[1\/2\ m\_p\ \((\((\[PartialD]\_t x\_p)\)\^2 + \
\((\[PartialD]\_t y\_p)\)\^2)\)]\)}], "Input"],

Cell["The total potential energy", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(V\_tot := V\_s + V\_m1 + V\_m2 + V\_p\)], "Input"],

Cell["The total kinetic energy", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(T\_tot := T\_s + T\_m1 + T\_m2 + T\_p\)], "Input"],

Cell["The Lagrangian of the system ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(L := T\_tot - V\_tot\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of the Equations of Motion", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The equations of motion are given by\n\t ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(d\/\(d\ t\)\) \[PartialD]L\/\[PartialD]\(q\& . \)\_i - \
\[PartialD]L\/\[PartialD]q\_i \[Equal] Q\_i\),
          FontSize->18], TraditionalForm]]],
  "\n",
  "(This computation may take a while ...)"
}], "Text"],

Cell[BoxData[{
    \(\(eqn\_1 = 
        Simplify[\[PartialD]\_t\((\[PartialD]\_\(\[PartialD]\_t x\_1[t]\)L)\) \
- \[PartialD]\_\(x\_1[t]\)L == F\_1];\)\), "\n", 
    \(\(eqn\_2 = 
        Simplify[\[PartialD]\_t\((\[PartialD]\_\(\[PartialD]\_t x\_2[t]\)L)\) \
- \[PartialD]\_\(x\_2[t]\)L == F\_2];\)\), "\n", 
    \(\(eqn\_3 = 
        Simplify[\[PartialD]\_t\((\[PartialD]\_\(\[PartialD]\_t \
\[Theta][t]\)L)\) - \[PartialD]\_\(\[Theta][t]\)L == 0];\)\), "\n", 
    \(\(eqn\_4 = 
        Simplify[\[PartialD]\_t\((\[PartialD]\_\(\[PartialD]\_t \
\[Alpha][t]\)L)\) - \[PartialD]\_\(\[Alpha][t]\)L == 0];\)\)}], "Input"],

Cell[TextData[{
  "These equations are coupled ordinary differential equations (ODEs) of \
second order in the generalized coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \ \[Theta], \ x\_2, \ \[Alpha]\)]],
  ". To rewrite these in standard state space form (a system of first order \
ODEs) we introduce the following states:\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{"(", GridBox[{
                {\(x\_1\), "\[Theta]", \(x\_2\), 
                  "\[Alpha]", \(\(x\& . \)\_1\), \(\[Theta]\& . \), \(\(x\& . \
\)\_2\), \(\[Alpha]\& . \)}
                }], ")"}]}], TraditionalForm]],
    FontSize->14],
  ".\nThe inputs to the system are\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"u", "=", 
          RowBox[{"(", GridBox[{
                {\(F\_1\), \(F\_2\)}
                }], ")"}]}], TraditionalForm]]],
  ".\nWe observe that the second order time derivatives of the positions and \
angles appears linearly which makes it easy to solve for these in terms the \
states."
}], "Text"],

Cell["Solve for second order derivatives", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sol = 
        Solve[\ {\ eqn\_1, eqn\_2, eqn\_3, 
            eqn\_4\ }, \n\t\t\t\t\t\t\t\t\t\t\t\t{\ \[PartialD]\_{t, 2}x\_1[
                t], \[PartialD]\_{t, 2}x\_2[
                t], \n\t\t\t\t\t\t\t\t\t\t\t\t\t\ \[PartialD]\_{t, 2}\[Theta][
                t], \[PartialD]\_{t, 2}\[Alpha][t]\ }\ ];\)\)], "Input"],

Cell["\<\
A look at the solutions (these will become the right hand sides of \
the differential equations used for simulating the system)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox[\(x\_1\), "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  
                  RowBox[{\(-F\_1\), "-", \(g\ Sin[\[Theta][t]]\ m\_1\), "-", 
                    
                    RowBox[{\(m\_1\), " ", \(x\_1[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], 
                        "2"]}]}], \(m\_1\)]}], "+", 
              RowBox[{"h", " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                          "+", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                t]]\ m\_1\ m\_2\), 
                          "-", \(g\ Sin[\[Alpha][t] + \[Theta][
                                  t]]\ m\_1\ m\_2\), 
                          "+", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                t]]\ m\_1\ m\_p\), 
                          "-", \(g\ Sin[\[Alpha][t] + \[Theta][
                                  t]]\ m\_1\ m\_p\), "+", 
                          
                          RowBox[{\(Cos[\[Alpha][t]]\), 
                            " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                            " ", \(m\_1\), " ", \(m\_p\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Alpha]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          RowBox[{
                          "2", " ", \(Cos[\[Alpha][t]]\), 
                            " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                            " ", \(m\_1\), " ", \(m\_p\), " ", 
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            " ", 
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}]}], 
                          "+", 
                          RowBox[{
                          "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_2\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Theta]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          RowBox[{
                          "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_p\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Theta]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          
                          RowBox[{\(Cos[\[Alpha][t]]\), 
                            " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                            " ", \(m\_1\), " ", \(m\_p\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Theta]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          RowBox[{
                          "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_2\), " ", 
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            " ", 
                            RowBox[{
                              SuperscriptBox[\(x\_2\), "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}]}], 
                          "+", 
                          RowBox[{
                          "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_p\), " ", 
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            " ", 
                            RowBox[{
                              SuperscriptBox[\(x\_2\), "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}]}]}],
                         ")"}], 
                      "/", \((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                          Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p + 
                          Sin[\[Alpha][t]]\ m\_1\ m\_2\ x\_2[t] + 
                          Sin[\[Alpha][t]]\ m\_1\ m\_p\ x\_2[t])\)}], "-", 
                    RowBox[{
                      RowBox[{"(", 
                        
                        RowBox[{\((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p)\), " ", 
                          RowBox[{"(", 
                            
                            RowBox[{\(\(-J\)\ Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                              "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\), 
                              "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_2\), 
                              "+", \(h\ F\_1\ l\_p\ m\_1\ m\_2\), 
                              "+", \(h\ F\_2\ l\_p\ m\_1\ m\_2\), 
                              "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_p\), 
                              "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_p\), 
                              "+", \(h\ F\_1\ l\_p\ m\_1\ m\_p\), 
                              "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_1\ l\_p\ m\_1\
\ m\_p\), "+", \(h\ F\_2\ l\_p\ m\_1\ m\_p\), 
                              "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_2\ l\_p\ m\_1\
\ m\_p\), "-", \(c\ g\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_2\ m\_s\), 
                              "-", \(c\ g\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                              "+", \(c\ g\ Cos[\[Alpha][t]]\^2\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\%2\ m\_2\ x\_1[t]\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                              "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                              "-", \(Cos[\[Alpha][
                                    t]]\ F\_2\ m\_1\%2\ x\_1[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_1\ m\_1\ m\_2\ x\_2[t]\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\%2\ x\_2[t]\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_1\ m\_1\ m\_p\ x\_2[t]\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\), 
                              "-", \(Cos[\[Alpha][t]]\ Sin[\[Alpha][
                                    t]]\ F\_2\ l\_p\ m\_1\ m\_p\ x\_2[t]\), 
                              "-", \(2\ g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                                    t]]\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "+", \(g\ Sin[\[Alpha][
                                    t]]\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                                    t]]\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "+", \(g\ Sin[\[Alpha][
                                    t]]\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\ m\_s\ x\_2[t]\), 
                              "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_p\ m\_s\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\%2\ m\_2\ x\_1[t]\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\%2\ m\_p\ x\_1[t]\ x\_2[t]\), 
                              "-", \(Cos[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                              "-", \(Cos[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\^2\), 
                              "-", \(2\ g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                              "-", \(2\ g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                              "+", \(2\ g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), "-", 
                              RowBox[{
                              "J", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_p\%2\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\^3\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "2", " ", "J", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^3\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "J", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_2\), " ", \(x\_1[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "2", " ", "h", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_p\%2\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\^3\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_2\), " ", \(x\_1[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "4", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}]}], ")"}]}], ")"}], 
                      "/", \((\((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p + 
                              Sin[\[Alpha][t]]\ m\_1\ m\_2\ x\_2[t] + 
                              Sin[\[Alpha][t]]\ m\_1\ m\_p\ x\_2[
                                  t])\)\ \((\(-J\)\ l\_p\ m\_1\ m\_2 - 
                              J\ l\_p\ m\_1\ m\_p + 
                              J\ Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p - 
                              l\_p\ m\_1\%2\ m\_2\ x\_1[t]\^2 - 
                              l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 + 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\%2\ m\_p\ \
x\_1[t]\^2 - l\_p\ m\_1\ m\_2\%2\ x\_2[t]\^2 - 
                              2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 + 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ \
x\_2[t]\^2 + Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 - 
                              l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 + 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ \
x\_2[t]\^2 + Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2)\))\)}]}], 
                  ")"}]}]}]}], ",", 
          RowBox[{
            RowBox[{
              SuperscriptBox[\(x\_2\), "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
            RowBox[{
              RowBox[{\(-Sec[\[Alpha][t]]\), " ", 
                RowBox[{"(", 
                  RowBox[{\(\(-g\)\ Sin[\[Alpha][t] + \[Theta][t]]\), "+", 
                    RowBox[{"h", " ", \(Sin[\[Alpha][t]]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{\(Cos[\[Alpha][t]]\), " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{"2", " ", \(Sin[\[Alpha][t]]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}]}], 
                  ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(Sec[\[Alpha][t]]\), " ", \(l\_p\), " ", 
                    RowBox[{"(", 
                      
                      RowBox[{\(\(-J\)\ Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                        "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\), 
                        "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_2\), 
                        "+", \(h\ F\_1\ l\_p\ m\_1\ m\_2\), 
                        "+", \(h\ F\_2\ l\_p\ m\_1\ m\_2\), 
                        "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_p\), 
                        "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_p\), 
                        "+", \(h\ F\_1\ l\_p\ m\_1\ m\_p\), 
                        "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_1\ l\_p\ m\_1\ m\_p\
\), "+", \(h\ F\_2\ l\_p\ m\_1\ m\_p\), 
                        "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_2\ l\_p\ m\_1\ m\_p\
\), "-", \(c\ g\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_2\ m\_s\), 
                        "-", \(c\ g\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                        "+", \(c\ g\ Cos[\[Alpha][t]]\^2\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                        "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\%2\ m\_2\ x\_1[
                            t]\), "-", \(g\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                        "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                        "-", \(Cos[\[Alpha][t]]\ F\_2\ m\_1\%2\ x\_1[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                        "+", \(h\ Sin[\[Alpha][t]]\ F\_1\ m\_1\ m\_2\ x\_2[
                            t]\), "+", \(h\ Sin[\[Alpha][
                              t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\ m\_2\%2\ x\_2[
                            t]\), "+", \(h\ Sin[\[Alpha][
                              t]]\ F\_1\ m\_1\ m\_p\ x\_2[t]\), 
                        "+", \(h\ Sin[\[Alpha][t]]\ F\_2\ m\_1\ m\_p\ x\_2[
                            t]\), "-", \(Cos[\[Alpha][t]]\ Sin[\[Alpha][
                              t]]\ F\_2\ l\_p\ m\_1\ m\_p\ x\_2[t]\), 
                        "-", \(2\ g\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                              t]]\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "+", \(g\ Sin[\[Alpha][
                              t]]\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[
                            t]\), "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                              t]]\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                        "+", \(g\ Sin[\[Alpha][
                              t]]\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                        "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\ m\_s\ x\_2[t]\), 
                        "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_p\ m\_s\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\%2\ m\_2\ x\_1[t]\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\%2\ m\_p\ x\_1[t]\ x\_2[t]\), 
                        "-", \(Cos[\[Alpha][
                              t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                        "-", \(Cos[\[Alpha][
                              t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\^2\), 
                        "-", \(2\ g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                        "-", \(2\ g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                        "+", \(2\ g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), "-", 
                        RowBox[{
                        "J", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "2", " ", "J", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\^2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "J", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_2\), 
                          " ", \(x\_1[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), " ", \(x\_1[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "2", " ", "h", " ", \(l\_p\), " ", \(m\_1\), 
                          " ", \(m\_2\), " ", \(m\_p\), " ", \(x\_2[t]\), " ",
                           
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_2\), 
                          " ", \(x\_1[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), " ", \(x\_1[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\^2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\^2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "4", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                          " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}]}], 
                      ")"}]}], ")"}], 
                "/", \((\(-J\)\ l\_p\ m\_1\ m\_2 - J\ l\_p\ m\_1\ m\_p + 
                    J\ Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p - 
                    l\_p\ m\_1\%2\ m\_2\ x\_1[t]\^2 - 
                    l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 + 
                    Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 - 
                    l\_p\ m\_1\ m\_2\%2\ x\_2[t]\^2 - 
                    2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 + 
                    Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 + 
                    Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 - 
                    l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 + 
                    Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 + 
                    Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2)\)}],
               "+", 
              
              RowBox[{\(Sec[\[Alpha][t]]\), 
                " ", \((h\ Cos[\[Alpha][t]] + l\_p + 
                    Sin[\[Alpha][t]]\ x\_2[t])\), " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                          "+", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                t]]\ m\_1\ m\_2\), 
                          "-", \(g\ Sin[\[Alpha][t] + \[Theta][
                                  t]]\ m\_1\ m\_2\), 
                          "+", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                t]]\ m\_1\ m\_p\), 
                          "-", \(g\ Sin[\[Alpha][t] + \[Theta][
                                  t]]\ m\_1\ m\_p\), "+", 
                          
                          RowBox[{\(Cos[\[Alpha][t]]\), 
                            " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                            " ", \(m\_1\), " ", \(m\_p\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Alpha]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          RowBox[{
                          "2", " ", \(Cos[\[Alpha][t]]\), 
                            " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                            " ", \(m\_1\), " ", \(m\_p\), " ", 
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            " ", 
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}]}], 
                          "+", 
                          RowBox[{
                          "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_2\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Theta]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          RowBox[{
                          "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_p\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Theta]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          
                          RowBox[{\(Cos[\[Alpha][t]]\), 
                            " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                            " ", \(m\_1\), " ", \(m\_p\), " ", 
                            SuperscriptBox[
                              RowBox[{
                                SuperscriptBox["\[Theta]", "\[Prime]",
                                  MultilineFunction->None], "[", "t", "]"}], 
                              "2"]}], "+", 
                          RowBox[{
                          "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_2\), " ", 
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            " ", 
                            RowBox[{
                              SuperscriptBox[\(x\_2\), "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}]}], 
                          "+", 
                          RowBox[{
                          "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                            " ", \(m\_p\), " ", 
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            " ", 
                            RowBox[{
                              SuperscriptBox[\(x\_2\), "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}]}]}],
                         ")"}], 
                      "/", \((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                          Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p + 
                          Sin[\[Alpha][t]]\ m\_1\ m\_2\ x\_2[t] + 
                          Sin[\[Alpha][t]]\ m\_1\ m\_p\ x\_2[t])\)}], "-", 
                    RowBox[{
                      RowBox[{"(", 
                        
                        RowBox[{\((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p)\), " ", 
                          RowBox[{"(", 
                            
                            RowBox[{\(\(-J\)\ Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                              "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\), 
                              "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_2\), 
                              "+", \(h\ F\_1\ l\_p\ m\_1\ m\_2\), 
                              "+", \(h\ F\_2\ l\_p\ m\_1\ m\_2\), 
                              "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_p\), 
                              "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_p\), 
                              "+", \(h\ F\_1\ l\_p\ m\_1\ m\_p\), 
                              "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_1\ l\_p\ m\_1\
\ m\_p\), "+", \(h\ F\_2\ l\_p\ m\_1\ m\_p\), 
                              "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_2\ l\_p\ m\_1\
\ m\_p\), "-", \(c\ g\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_2\ m\_s\), 
                              "-", \(c\ g\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                              "+", \(c\ g\ Cos[\[Alpha][t]]\^2\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\%2\ m\_2\ x\_1[t]\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                              "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                              "-", \(Cos[\[Alpha][
                                    t]]\ F\_2\ m\_1\%2\ x\_1[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_1\ m\_1\ m\_2\ x\_2[t]\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\%2\ x\_2[t]\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_1\ m\_1\ m\_p\ x\_2[t]\), 
                              "+", \(h\ Sin[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\), 
                              "-", \(Cos[\[Alpha][t]]\ Sin[\[Alpha][
                                    t]]\ F\_2\ l\_p\ m\_1\ m\_p\ x\_2[t]\), 
                              "-", \(2\ g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                                    t]]\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "+", \(g\ Sin[\[Alpha][
                                    t]]\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                                    t]]\ Sin[\[Theta][
                                    t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "+", \(g\ Sin[\[Alpha][
                                    t]]\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                              "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\ m\_s\ x\_2[t]\), 
                              "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_p\ m\_s\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\%2\ m\_2\ x\_1[t]\ x\_2[t]\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\%2\ m\_p\ x\_1[t]\ x\_2[t]\), 
                              "-", \(Cos[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                              "-", \(Cos[\[Alpha][
                                    t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\^2\), 
                              "-", \(2\ g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                              "-", \(2\ g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                              "+", \(2\ g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                                    t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                              "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                                    t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                              "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                      t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), "-", 
                              RowBox[{
                              "J", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_p\%2\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{\(Cos[\[Alpha][t]]\^3\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Alpha]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "2", " ", "J", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^3\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Alpha]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "J", " ", \(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_2\), " ", \(x\_1[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "2", " ", "h", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                                " ", \(m\_1\), " ", \(m\_p\%2\), 
                                " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              RowBox[{\(Cos[\[Alpha][t]]\^3\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "-", 
                              
                              RowBox[{\(Cos[\[Alpha][t]]\), 
                                " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\%2\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "h", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                SuperscriptBox[
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", "\[Prime]",
                                      MultilineFunction->None], "[", "t", 
                                    "]"}], "2"]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_2\), " ", \(x\_1[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\%2\), 
                                " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_1\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\), " ", \(m\_p\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_2\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\), 
                                " ", \(m\_1\%2\), " ", \(m\_p\), 
                                " ", \(x\_1[t]\^2\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "4", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_2\), " ", \(m\_p\), 
                                " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                                " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "+", 
                              RowBox[{
                              "2", " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Cos[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}], "-", 
                              RowBox[{
                              "2", " ", \(Sin[\[Alpha][t]]\^2\), 
                                " ", \(l\_p\), " ", \(m\_1\), 
                                " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                                RowBox[{
                                  SuperscriptBox["\[Theta]", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}],
                                 " ", 
                                RowBox[{
                                  SuperscriptBox[\(x\_2\), "\[Prime]",
                                    MultilineFunction->None], "[", "t", 
                                  "]"}]}]}], ")"}]}], ")"}], 
                      "/", \((\((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p + 
                              Sin[\[Alpha][t]]\ m\_1\ m\_2\ x\_2[t] + 
                              Sin[\[Alpha][t]]\ m\_1\ m\_p\ x\_2[
                                  t])\)\ \((\(-J\)\ l\_p\ m\_1\ m\_2 - 
                              J\ l\_p\ m\_1\ m\_p + 
                              J\ Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p - 
                              l\_p\ m\_1\%2\ m\_2\ x\_1[t]\^2 - 
                              l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 + 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\%2\ m\_p\ \
x\_1[t]\^2 - l\_p\ m\_1\ m\_2\%2\ x\_2[t]\^2 - 
                              2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 + 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ \
x\_2[t]\^2 + Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 - 
                              l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 + 
                              Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ \
x\_2[t]\^2 + Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2)\))\)}]}], 
                  ")"}]}]}]}], ",", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{
                  RowBox[{"(", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                      "+", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                            t]]\ m\_1\ m\_2\), 
                      "-", \(g\ Sin[\[Alpha][t] + \[Theta][t]]\ m\_1\ m\_2\), 
                      "+", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                            t]]\ m\_1\ m\_p\), 
                      "-", \(g\ Sin[\[Alpha][t] + \[Theta][t]]\ m\_1\ m\_p\), 
                      "+", 
                      
                      RowBox[{\(Cos[\[Alpha][t]]\), " ", \(Sin[\[Alpha][t]]\),
                         " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\), " ", 
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], 
                          "2"]}], "+", 
                      RowBox[{
                      "2", " ", \(Cos[\[Alpha][t]]\), 
                        " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                        " ", \(m\_1\), " ", \(m\_p\), " ", 
                        RowBox[{
                          SuperscriptBox["\[Alpha]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], " ", 
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}]}], "+", 
                      
                      RowBox[{
                      "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                        " ", \(m\_2\), " ", 
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], 
                          "2"]}], "+", 
                      RowBox[{
                      "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                        " ", \(m\_p\), " ", 
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], 
                          "2"]}], "+", 
                      
                      RowBox[{\(Cos[\[Alpha][t]]\), " ", \(Sin[\[Alpha][t]]\),
                         " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\), " ", 
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], 
                          "2"]}], "+", 
                      RowBox[{
                      "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                        " ", \(m\_2\), " ", 
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], " ", 
                        RowBox[{
                          SuperscriptBox[\(x\_2\), "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}]}], "+", 
                      
                      RowBox[{
                      "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                        " ", \(m\_p\), " ", 
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], " ", 
                        RowBox[{
                          SuperscriptBox[\(x\_2\), "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}]}]}], 
                    ")"}], "/", \((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                      Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p + 
                      Sin[\[Alpha][t]]\ m\_1\ m\_2\ x\_2[t] + 
                      Sin[\[Alpha][t]]\ m\_1\ m\_p\ x\_2[t])\)}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  
                  RowBox[{\((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                        Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p)\), " ", 
                    RowBox[{"(", 
                      
                      RowBox[{\(\(-J\)\ Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                        "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\), 
                        "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_2\), 
                        "+", \(h\ F\_1\ l\_p\ m\_1\ m\_2\), 
                        "+", \(h\ F\_2\ l\_p\ m\_1\ m\_2\), 
                        "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_p\), 
                        "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_p\), 
                        "+", \(h\ F\_1\ l\_p\ m\_1\ m\_p\), 
                        "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_1\ l\_p\ m\_1\ m\_p\
\), "+", \(h\ F\_2\ l\_p\ m\_1\ m\_p\), 
                        "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_2\ l\_p\ m\_1\ m\_p\
\), "-", \(c\ g\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_2\ m\_s\), 
                        "-", \(c\ g\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                        "+", \(c\ g\ Cos[\[Alpha][t]]\^2\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                        "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\%2\ m\_2\ x\_1[
                            t]\), "-", \(g\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                        "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                        "-", \(Cos[\[Alpha][t]]\ F\_2\ m\_1\%2\ x\_1[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                        "+", \(h\ Sin[\[Alpha][t]]\ F\_1\ m\_1\ m\_2\ x\_2[
                            t]\), "+", \(h\ Sin[\[Alpha][
                              t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\ m\_2\%2\ x\_2[
                            t]\), "+", \(h\ Sin[\[Alpha][
                              t]]\ F\_1\ m\_1\ m\_p\ x\_2[t]\), 
                        "+", \(h\ Sin[\[Alpha][t]]\ F\_2\ m\_1\ m\_p\ x\_2[
                            t]\), "-", \(Cos[\[Alpha][t]]\ Sin[\[Alpha][
                              t]]\ F\_2\ l\_p\ m\_1\ m\_p\ x\_2[t]\), 
                        "-", \(2\ g\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                              t]]\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "+", \(g\ Sin[\[Alpha][
                              t]]\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[
                            t]\), "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                              t]]\ Sin[\[Theta][
                              t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                        "+", \(g\ Sin[\[Alpha][
                              t]]\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                        "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\ m\_s\ x\_2[t]\), 
                        "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_p\ m\_s\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\%2\ m\_2\ x\_1[t]\ x\_2[t]\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\%2\ m\_p\ x\_1[t]\ x\_2[t]\), 
                        "-", \(Cos[\[Alpha][
                              t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                        "-", \(Cos[\[Alpha][
                              t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\^2\), 
                        "-", \(2\ g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                        "-", \(2\ g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                        "+", \(2\ g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                              t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                        "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                              t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                        "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                                t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), "-", 
                        RowBox[{
                        "J", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Alpha]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "2", " ", "J", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\^2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Alpha]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "J", " ", \(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_2\), 
                          " ", \(x\_1[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), " ", \(x\_1[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\^2\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "2", " ", "h", " ", \(l\_p\), " ", \(m\_1\), 
                          " ", \(m\_2\), " ", \(m\_p\), " ", \(x\_2[t]\), " ",
                           
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "-", 
                        
                        RowBox[{\(Cos[\[Alpha][t]]\), 
                          " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          SuperscriptBox[
                            RowBox[{
                              SuperscriptBox["\[Theta]", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}], 
                            "2"]}], "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_2\), 
                          " ", \(x\_1[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                          " ", \(x\_1[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\%2\), " ", \(m\_p\), " ", \(x\_1[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_1\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), 
                          " ", \(m\_1\), " ", \(m\_p\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_2\), " ", \(x\_1[t]\^2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                          " ", \(m\_p\), " ", \(x\_1[t]\^2\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "4", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                          " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "+", 
                        RowBox[{
                        "2", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\%2\), 
                          " ", \(x\_2[t]\), " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}], 
                        "-", 
                        RowBox[{
                        "2", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                          " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), 
                          " ", 
                          RowBox[{
                            SuperscriptBox["\[Theta]", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], " ", 
                          
                          RowBox[{
                            SuperscriptBox[\(x\_2\), "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}]}], 
                      ")"}]}], ")"}], 
                "/", \((\((l\_p\ m\_1\ m\_2 + l\_p\ m\_1\ m\_p - 
                        Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p + 
                        Sin[\[Alpha][t]]\ m\_1\ m\_2\ x\_2[t] + 
                        Sin[\[Alpha][t]]\ m\_1\ m\_p\ x\_2[
                            t])\)\ \((\(-J\)\ l\_p\ m\_1\ m\_2 - 
                        J\ l\_p\ m\_1\ m\_p + 
                        J\ Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p - 
                        l\_p\ m\_1\%2\ m\_2\ x\_1[t]\^2 - 
                        l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 + 
                        Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 \
- l\_p\ m\_1\ m\_2\%2\ x\_2[t]\^2 - 2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 + 
                        Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ \
x\_2[t]\^2 + Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 - 
                        l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 + 
                        Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 \
+ Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2)\))\)}]}]}], ",", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[Alpha]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
            RowBox[{"-", 
              RowBox[{
                RowBox[{"(", 
                  
                  RowBox[{\(\(-J\)\ Cos[\[Alpha][t]]\ F\_2\ m\_1\), 
                    "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\ m\_2\), 
                    "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][t]]\ m\_1\ m\_2\),
                     "+", \(h\ F\_1\ l\_p\ m\_1\ m\_2\), 
                    "+", \(h\ F\_2\ l\_p\ m\_1\ m\_2\), 
                    "-", \(g\ J\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\ m\_p\), 
                    "+", \(g\ J\ Sin[\[Alpha][t] + \[Theta][t]]\ m\_1\ m\_p\),
                     "+", \(h\ F\_1\ l\_p\ m\_1\ m\_p\), 
                    "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_1\ l\_p\ m\_1\ m\_p\), 
                    "+", \(h\ F\_2\ l\_p\ m\_1\ m\_p\), 
                    "-", \(h\ Cos[\[Alpha][t]]\^2\ F\_2\ l\_p\ m\_1\ m\_p\), 
                    "-", \(c\ g\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_2\ m\_s\), 
                    "-", \(c\ g\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                    "+", \(c\ g\ Cos[\[Alpha][t]]\^2\ Sin[\[Theta][
                          t]]\ l\_p\ m\_1\ m\_p\ m\_s\), 
                    "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\%2\ m\_2\ x\_1[
                        t]\), "-", \(g\ Cos[\[Theta][
                          t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                    "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                          t]]\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\), 
                    "-", \(Cos[\[Alpha][t]]\ F\_2\ m\_1\%2\ x\_1[t]\^2\), 
                    "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                    "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                            t]]\ m\_1\%2\ m\_2\ x\_1[t]\^2\), 
                    "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                    "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                            t]]\ m\_1\%2\ m\_p\ x\_1[t]\^2\), 
                    "+", \(h\ Sin[\[Alpha][t]]\ F\_1\ m\_1\ m\_2\ x\_2[t]\), 
                    "+", \(h\ Sin[\[Alpha][t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\), 
                    "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\ m\_2\%2\ x\_2[
                        t]\), "+", \(h\ Sin[\[Alpha][
                          t]]\ F\_1\ m\_1\ m\_p\ x\_2[t]\), 
                    "+", \(h\ Sin[\[Alpha][t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\), 
                    "-", \(Cos[\[Alpha][t]]\ Sin[\[Alpha][
                          t]]\ F\_2\ l\_p\ m\_1\ m\_p\ x\_2[t]\), 
                    "-", \(2\ g\ Cos[\[Theta][
                          t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                    "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                          t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                    "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                          t]]\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[
                        t]\), "+", \(g\ Sin[\[Alpha][
                          t]]\ Sin[\[Alpha][t] + \[Theta][
                            t]]\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\), 
                    "-", \(g\ Cos[\[Theta][t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[
                        t]\), "+", \(g\ Cos[\[Alpha][t]]\^2\ Cos[\[Theta][
                          t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                    "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Alpha][
                          t]]\ Sin[\[Theta][t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[
                        t]\), "+", \(g\ Sin[\[Alpha][
                          t]]\ Sin[\[Alpha][t] + \[Theta][
                            t]]\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\), 
                    "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\ m\_2\ m\_s\ x\_2[t]\), 
                    "-", \(c\ g\ Sin[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\ m\_p\ m\_s\ x\_2[t]\), 
                    "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                          t]]\ m\_1\%2\ m\_2\ x\_1[t]\ x\_2[t]\), 
                    "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                          t]]\ m\_1\%2\ m\_p\ x\_1[t]\ x\_2[t]\), 
                    "-", \(Cos[\[Alpha][t]]\ F\_2\ m\_1\ m\_2\ x\_2[t]\^2\), 
                    "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                          t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                    "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                    "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                            t]]\ m\_1\ m\_2\%2\ x\_2[t]\^2\), 
                    "-", \(Cos[\[Alpha][t]]\ F\_2\ m\_1\ m\_p\ x\_2[t]\^2\), 
                    "-", \(2\ g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                          t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                    "-", \(2\ g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                    "+", \(2\ g\ Sin[\[Alpha][t] + \[Theta][
                            t]]\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2\), 
                    "-", \(g\ Cos[\[Theta][t]]\ Sin[\[Alpha][
                          t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                    "-", \(g\ Cos[\[Alpha][t]]\ Sin[\[Theta][
                          t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), 
                    "+", \(g\ Sin[\[Alpha][t] + \[Theta][
                            t]]\ m\_1\ m\_p\%2\ x\_2[t]\^2\), "-", 
                    RowBox[{
                    "J", " ", \(Cos[\[Alpha][t]]\), " ", \(Sin[\[Alpha][t]]\),
                       " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Alpha]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), " ", \(Sin[\[Alpha][t]]\), 
                      " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                      " ", \(x\_1[t]\^2\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Alpha]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                      " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Alpha]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Alpha]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Alpha]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), 
                      " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Alpha]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "2", " ", "J", " ", \(Cos[\[Alpha][t]]\), 
                      " ", \(Sin[\[Alpha][t]]\), " ", \(l\_p\), " ", \(m\_1\),
                       " ", \(m\_p\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Alpha]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\), " ", \(Sin[\[Alpha][t]]\),
                       " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                      " ", \(x\_1[t]\^2\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Alpha]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                      " ", \(x\_2[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Alpha]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Alpha]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Alpha]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\), 
                      " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Alpha]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                      " ", \(m\_2\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", "J", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                      " ", \(m\_p\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "J", " ", \(Cos[\[Alpha][t]]\), " ", \(Sin[\[Alpha][t]]\),
                       " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "h", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_2\), 
                      " ", \(x\_1[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "h", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                      " ", \(x\_1[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\%2\), " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_2\), " ", \(x\_1[t]\^2\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_p\), " ", \(x\_1[t]\^2\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), " ", \(Sin[\[Alpha][t]]\), 
                      " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                      " ", \(x\_1[t]\^2\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "h", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\%2\), 
                      " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "2", " ", "h", " ", \(l\_p\), " ", \(m\_1\), 
                      " ", \(m\_2\), " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                      " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                      " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                      " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "h", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\%2\), 
                      " ", \(x\_2[t]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    RowBox[{
                    "h", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\^3\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "-", 
                    
                    RowBox[{\(Cos[\[Alpha][t]]\), 
                      " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\%2\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_2\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "h", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_p\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                      
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["\[Theta]", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     "+", 
                    RowBox[{
                    "2", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_2\), 
                      " ", \(x\_1[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_1\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "2", " ", \(l\_p\), " ", \(m\_1\%2\), " ", \(m\_p\), 
                      " ", \(x\_1[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_1\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\%2\), " ", \(m\_p\), " ", \(x\_1[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_1\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_2\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_1\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_p\), " ", \(x\_1[t]\), " ", \(x\_2[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_1\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                      " ", \(m\_2\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", "J", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\), 
                      " ", \(m\_p\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_2\), " ", \(x\_1[t]\^2\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Sin[\[Alpha][t]]\), " ", \(m\_1\%2\), 
                      " ", \(m\_p\), " ", \(x\_1[t]\^2\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "2", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\%2\), 
                      " ", \(x\_2[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "4", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_2\), 
                      " ", \(m\_p\), " ", \(x\_2[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                      " ", \(x\_2[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_2\), " ", \(m\_p\), 
                      " ", \(x\_2[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    "2", " ", \(l\_p\), " ", \(m\_1\), " ", \(m\_p\%2\), 
                      " ", \(x\_2[t]\), " ", 
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Cos[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    "2", " ", \(Sin[\[Alpha][t]]\^2\), " ", \(l\_p\), 
                      " ", \(m\_1\), " ", \(m\_p\%2\), " ", \(x\_2[t]\), " ", 
                      
                      RowBox[{
                        SuperscriptBox["\[Theta]", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], " ", 
                      RowBox[{
                        SuperscriptBox[\(x\_2\), "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}]}]}], 
                  ")"}], "/", \((\(-J\)\ l\_p\ m\_1\ m\_2 - 
                    J\ l\_p\ m\_1\ m\_p + 
                    J\ Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p - 
                    l\_p\ m\_1\%2\ m\_2\ x\_1[t]\^2 - 
                    l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 + 
                    Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\%2\ m\_p\ x\_1[t]\^2 - 
                    l\_p\ m\_1\ m\_2\%2\ x\_2[t]\^2 - 
                    2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 + 
                    Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 + 
                    Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_2\ m\_p\ x\_2[t]\^2 - 
                    l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 + 
                    Cos[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ x\_2[t]\^2 + 
                    Sin[\[Alpha][t]]\^2\ l\_p\ m\_1\ m\_p\%2\ \
x\_2[t]\^2)\)}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["Turn off the spell checking", "Text"],

Cell[BoxData[
    \(Off[General::"\<spell1\>"]\)], "Input"],

Cell["Conversion rules to get rid of explicit time dependence", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ssvariables := {\ \ x\_1[t] \[Rule] 
            x\_1, \[Theta][
              t] \[Rule] \[Theta], \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tx\_2[
              t] \[Rule] 
            x\_2, \[Alpha][
              t] \[Rule] \[Alpha], \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\[PartialD]\_t x\_1[t] \[Rule] dx\_1, \[PartialD]\_t \[Theta][t] \[Rule] 
            d\[Theta], \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\[PartialD]\_t x\_2[
                t] \[Rule] dx\_2, \[PartialD]\_t \[Alpha][t] \[Rule] 
            d\[Alpha]\ };\)\)], "Input"],

Cell[TextData[{
  "We compute the right hand side of the nonlinear state space equations:\t",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(x\& . \)[t] = f\ [x[t], u[t]]\),
          FontSize->16], TraditionalForm]]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"f", "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(\[PartialD]\_t\ x\_1[t]\)},
                    {\(\[PartialD]\_t \[Theta][t]\)},
                    {\(\[PartialD]\_t x\_2[t]\)},
                    {\(\[PartialD]\_t \[Alpha][t]\)},
                    {\(\[PartialD]\_{t, 2}x\_1[t]\)},
                    {\(\[PartialD]\_{t, 2}\[Theta][t]\)},
                    {\(\[PartialD]\_{t, 2}x\_2[t]\)},
                    {\(\[PartialD]\_{t, 2}\[Alpha][t]\)}
                    }], ")"}], 
              "/.", \(sol\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], "/.",
             "ssvariables"}], "//", "Flatten"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Linearized Model (ONLY if Control Systems Professional IS \
installed)\
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Load the Control System Professional (CSP) package (if you don't \
have this package skip this subsection and evaluate the cells in \"The \
Linearized Model (Non Control Systems Professional Users)\" instead)\
\>", \
"Text"],

Cell[BoxData[
    \(\(If[CSP, Needs["\<ControlSystems`Master`\>"]];\)\)], "Input"],

Cell[TextData[{
  "Linearize the equations around the origin\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"x", "=", 
            RowBox[{"(", GridBox[{
                  {"0", "0", "0", "0", "0", "0", "0", "0"}
                  }], ")"}]}], ",", " ", 
          RowBox[{"u", "=", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0"}
                    }], ")"}], " ", "\[Implies]", 
              " ", \(\(x\& . \)[t] \[Equal] A\ x[t] + \ B\ u[t]\)}]}]}], 
        TraditionalForm]],
    FontSize->14],
  StyleBox[".",
    FontSize->14],
  "\nusing the Linearize function in CSP"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(If[CSP, 
      ss = Linearize[
            f, {x\_1, \[Theta], 
              x\_2, \[Alpha]}, \n\t\t{{x\_1, 0}, {\[Theta], 0}, {x\_2, 
                0}, {\[Alpha], 0}, {dx\_1, 0}, {d\[Theta], 0}, {dx\_2, 
                0}, {d\[Alpha], 0}}, \n\t\t{{F\_1, 0}, {F\_2, 0}}] // 
          Simplify; \nMap[MatrixForm, ss]]\)], "Input"],

Cell["\<\
We extract the matrices from the linearization and substitute with \
the physical values of the parameters\
\>", "Text"],

Cell[BoxData[
    \(\(If[
        CSP, {\[ScriptCapitalA], \[ScriptCapitalB], \[ScriptCapitalC], \
\[ScriptCapitalD]} = \(ss /. StateSpace \[Rule] List\) /. 
            physicalvalues];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalA] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox["\[ScriptCapitalA]",
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalB] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox["\[ScriptCapitalB]",
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalC] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox["\[ScriptCapitalC]",
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalD] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox["\[ScriptCapitalD]",
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Check controllability", "Text"],

Cell[BoxData[
    \(If[CSP, Controllable[ss /. physicalvalues]]\)], "Input"],

Cell["\<\
Compute a full state feedback controller using the LQG-method \
(LQRegulatorGains is a CSP command).\
\>", "Text"],

Cell[BoxData[
    \(If[CSP, \[ScriptCapitalL] = 
        LQRegulatorGains[\n\t\t\t\t\t\tss /. 
            physicalvalues, \n\t\t\t\t\t\tDiagonalMatrix[{1, 5. , 1, 5. , 0, 
              0, 0, 0}], \n\t\t\t\t\t\t0.1\ IdentityMatrix[
              2]\ ]; \n\[ScriptCapitalL] // MatrixForm]\)], "Input"],

Cell[TextData[{
  "The control law to be used is\n\t",
  Cell[BoxData[
      \(TraditionalForm\`u[t] = \(-\[ScriptCapitalL] . x[t]\)\)]],
  " \nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`x[t]\)]],
  " are measurements of the states. This gives the following closed loop \
system to simulate\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)[t] = 
        f\ [x[t], \(-\[ScriptCapitalL] . x[t]\)]\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Linearized Model (ONLY if Control Systems Professional is  NOT \
installed)\
\>", "Subsection"],

Cell["\<\
This subsection only needs to be evaluated if the application \
package Control System Professional is not available.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ScriptCapitalA]", "=", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"0", "0", "0", "0", "1", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "1", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "1", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "1"},
                {\(-\(\(g\ h\ m\_1\)\/J\)\), \(g - \(c\ g\ h\ m\_s\)\/J\), \
\(-\(\(g\ h\ \((m\_2 + m\_p)\)\)\/J\)\), "0", "0", "0", "0", "0"},
                {\(\(g\ m\_1\)\/J\), \(\(c\ g\ m\_s\)\/J\), \(\(g\ \((m\_2 + 
                            m\_p)\)\)\/J\), "0", "0", "0", "0", "0"},
                {\(-\(\(g\ h\ m\_1\)\/J\)\), \(g - \(c\ g\ h\ m\_s\)\/J\), \
\(-\(\(g\ h\ \((m\_2 + m\_p)\)\)\/J\)\), \(-\(\(g\ m\_p\)\/m\_2\)\), "0", "0",
                   "0", "0"},
                {\(-\(\(g\ m\_1\)\/J\)\), \(-\(\(c\ g\ m\_s\)\/J\)\), \
\(-\(\(g\ \((m\_2 + m\_p)\)\)\/J\)\), \(\(g\ \((m\_2 + 
                            m\_p)\)\)\/\(l\_p\ m\_2\)\), "0", "0", "0", "0"}
                }], ")"}], "/.", "physicalvalues"}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ScriptCapitalB]", "=", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {\(h\^2\/J + 1\/m\_1\), \(h\^2\/J\)},
                {\(-\(h\/J\)\), \(-\(h\/J\)\)},
                {\(h\^2\/J\), \(h\^2\/J + 1\/m\_2\)},
                {\(h\/J\), \(h\/J - 1\/\(l\_p\ m\_2\)\)}
                }], ")"}], "/.", "physicalvalues"}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ScriptCapitalC]", "=", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"1", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "1", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "1", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "1", "0", "0", "0", "0"}
                }], ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ScriptCapitalD]", "=", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"}
                }], ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ScriptCapitalL]", "=", 
        RowBox[{"(", GridBox[{
              {"26.7929176340570451`", "52.940017572506921`", 
                "21.3676324363225722`", "11.8260757522378035`", 
                "7.23981708831001657`", "18.3074986680684386`", 
                "6.54027930973907345`", "2.28919536473904816`"},
              {\(-7.65182809411970588`\), \(-26.7908119385335119`\), \
\(-10.0775285345229015`\), \(-27.725924950006533`\), \
\(-1.62889424735209065`\), \(-8.77816698970899089`\), \(-5.38840857578496201`\
\), \(-4.54939001709865742`\)}
              }], ")"}]}], ";"}]], "Input"],

Cell["The following standard package is needed later on.", "Text"],

Cell[BoxData[
    \(Needs["\<LinearAlgebra`MatrixManipulation`\>"]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulation", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Load ",
  StyleBox["MathCode F90",
    FontSlant->"Italic"],
  " and set Current Directory"
}], "Subsection"],

Cell[TextData[{
  "Load the ",
  StyleBox["MathCode F90",
    FontSlant->"Italic"],
  " package"
}], "Text"],

Cell[CellGroupData[{

Cell["Needs[\"MathCode`\"];", "Input"],

Cell[BoxData[
    InterpretationBox[\("MathCode F90 1.0.1"\[InvisibleSpace]" loaded"\),
      SequenceForm[ "MathCode F90 1.0.1", " loaded"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "Since a number of temporary files will be generated by ",
  StyleBox["MathCode F90",
    FontSlant->"Italic"],
  " we create a temporary directory and set this to the current working \
directory."
}], "Text"],

Cell["SetDirectory[$MCRoot<>\"/DemosF90/Pendulum\"];", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection"],

Cell["We store the states as a vector", "Text"],

Cell[BoxData[
    \(x\_ss := {x\_1, \[Theta], x\_2, \[Alpha], dx\_1, d\[Theta], dx\_2, 
        d\[Alpha]}\)], "Input"],

Cell["\<\
and close the feedback loop which gives the following right hand \
side of the state space equations\
\>", "Text"],

Cell[BoxData[
    \(\(f1 = 
        f /. Thread[{F\_1, 
                F\_2} \[Rule] \(-\[ScriptCapitalL] . x\_ss\)];\)\)], "Input"],

Cell["Turn off the spell checking", "Text"],

Cell[BoxData[
    \(Off[General::"\<spell1\>"]\)], "Input"],

Cell["\<\
Change names of variables to only ASCII characters (needed for code \
generation)\
\>", "Text"],

Cell[BoxData[
    \(\(Cvariables\  = \n\t\t{x\_1 \[Rule] \ x1, \[Theta]\  \[Rule] \ 
            theta, \n\t\t\tx\_2\  \[Rule] \ x2, \[Alpha]\  \[Rule] \ 
            alpha, \n\t\t\tdx\_1\  \[Rule] \ dx1, 
          d\[Theta]\  \[Rule] \ dtheta, \n\t\t\tdx\_2\  \[Rule] \ dx2, \ 
          d\[Alpha] \[Rule] \ dalpha};\)\)], "Input"],

Cell["\<\
The right hand side of the closed loop state space equations \
(intended for code generation)\
\>", "Text"],

Cell[BoxData[
    \(\(rhs = \(f1 /. physicalvalues\)\  /. \ Cvariables;\)\)], "Input"],

Cell[CellGroupData[{

Cell["The right hand side of the state space equations", "Subsubsection"],

Cell["\<\
We define the function ClosedLoopPendulumEquationsRHS which has the \
huge rhs expression from above as its body. Note that the expression also can \
read from the file PendulumExpr.m which is created above (in case of memory \
problems). This file makes it quicker to try out the compilation in different \
sessions without recomputing rhs each time.\
\>", "Text"],

Cell[BoxData[
    \(\(ClosedLoopPendulumEquationsRHS[\n\tReal\ x1_, Real\ theta_, 
            Real\ x2_, Real\ alpha_, \n\tReal\ dx1_, Real\ dtheta_, 
            Real\ dx2_, Real\ dalpha_] \[Rule] Real[8] = rhs;\)\)], "Input"],

Cell["\<\
Note that we have added type declarations to be able to generate \
code for this function later on.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Simulation of the Nonlinear Model within ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Subsection"],

Cell[TextData[{
  "We define ",
  Cell[BoxData[
      \(TraditionalForm\`f\_cl[t]\)]],
  " to be a short notation for the ClosedLoopPendulumEquationsRHS"
}], "Text"],

Cell[BoxData[
    \(f\_cl[t_] := 
      ClosedLoopPendulumEquationsRHS[x1[t], theta[t], x2[t], alpha[t], 
        dx1[t], dtheta[t], dx2[t], dalpha[t]]\)], "Input"],

Cell["The state vector", "Text"],

Cell[BoxData[
    \(\(x[t_] := {x1[t], theta[t], x2[t], alpha[t], dx1[t], dtheta[t], 
          dx2[t], dalpha[t]};\)\)], "Input"],

Cell["The differential equations for the closed loop system", "Text"],

Cell[BoxData[
    \(deq := Thread[\(x'\)[t] == f\_cl[t]]\)], "Input"],

Cell["\<\
Initial conditions for the simulation. Cart 1 is positioned at -1, \
the seesaw is horizontal, cart 2 is positioned at +1 and the pendulum has a \
small deviation of 5.7\[Degree] from the vertical axis. The system is at rest \
at these positions (all time derivatives are zero).\
\>", "Text"],

Cell[BoxData[
    \(initeq := Thread[x[0] == {\(-1\), 0, 1, 0.1, 0, 0, 0, 0}]\)], "Input"],

Cell["We simulate the system using NDSolve", "Text"],

Cell[TextData[StyleBox["Standard usage",
  FontWeight->"Bold"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dsolStandard = 
          NDSolve[\ 
            deq\  \[Union] \ initeq, {x1, theta, x2, alpha, dx1, dtheta, dx2, 
              dalpha}, {t, 0, 10}\ ];\) // Timing\), "\n", 
    \(\(NDSolveStandardTime = First[%];\)\)}], "Input"],

Cell[BoxData[
    \({0.125`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Uncompiled equations",
  FontWeight->"Bold"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dsolUncompiled = 
          NDSolve[\ 
            deq\  \[Union] \ initeq, {x1, theta, x2, alpha, dx1, dtheta, dx2, 
              dalpha}, {t, 0, 10}, Compiled \[Rule] False\ ];\) // 
      Timing\), "\n", 
    \(\(NDSolveUncompiledTime = First[%];\)\)}], "Input"],

Cell[BoxData[
    \({0.3439999999999994`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Force ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" to use 4-5 Runge-Kutta with step size 0.01. (",
    FontWeight->"Bold"],
  "The method internals changed in",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" 5.0.)",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($MethodToUse = 
      If[$VersionNumber < 5.0, RungeKutta, ExplicitRungeKutta]\)], "Input"],

Cell[BoxData[
    \(ExplicitRungeKutta\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dsolRK = 
          NDSolve[\ 
            deq\  \[Union] \ initeq, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t{x1, 
              theta, x2, alpha, dx1, dtheta, dx2, dalpha}, {t, 0. , 
              10}, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tMaxStepSize \[Rule] 
              0.01, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tMethod \[Rule] \
$MethodToUse, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tMaxSteps \[Rule] 10000\ ];\) // 
      Timing\), "\n", 
    \(\(NDSolveRKTime = First[%];\)\)}], "Input"],

Cell[BoxData[
    \({0.5629999999999988`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \($MethodToUse\)], "Input"],

Cell[BoxData[
    \(ExplicitRungeKutta\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Force ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" to use 4-5 Runge-Kutta with step size 0.01 (uncompiled \
equations)",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dsolRKUncompiled = 
          NDSolve[\ 
            deq\  \[Union] \ initeq, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t{x1, 
              theta, x2, alpha, dx1, dtheta, dx2, dalpha}, {t, 0. , 
              10}, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tMaxStepSize \[Rule] 
              0.01, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tMethod \[Rule] \
$MethodToUse, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tMaxSteps \[Rule] 
              10000, \n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tCompiled \[Rule] 
              False\ ];\) // Timing\), "\n", 
    \(\(NDSolveRKUncompiledTime = First[%];\)\)}], "Input"],

Cell[BoxData[
    \({7.233999999999998`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["The linear system",
  FontWeight->"Bold"]], "Text"],

Cell[BoxData[
    \(dlineq := 
      Thread[\(x'\)[
              t] == \((\[ScriptCapitalA] - \[ScriptCapitalB] . \
\[ScriptCapitalL])\) . x[t]] // Chop\)], "Input"],

Cell["We simulate the linear system using NDSolve", "Text"],

Cell[BoxData[
    \(\(dsollin = 
        NDSolve[\ 
          dlineq\  \[Union] \ initeq, {x1, theta, x2, alpha, dx1, dtheta, 
            dx2, dalpha}, {t, 0, 8}\ ];\)\)], "Input"],

Cell[TextData[{
  "Plot the result for the first 4 state variables (the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " standard usage of NDSolve) together with the result for the linear \
system. The other simulation methods above can be shown to give the same \
result as the standard usage of NDSolve."
}], "Text"],

Cell[BoxData[
    \(\(Map[\n\t
        Plot[#, {t, 0, 8}, PlotRange \[Rule] All, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] {{RGBColor[0, 0, 0]}, {RGBColor[1, 0, 
                    0]}}] &, {Part[Flatten[x[t] /. dsolStandard], 
              Range[4]], \n\t\tPart[Flatten[x[t] /. dsollin], Range[4]]} // 
          Transpose\ ];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[%], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.564365 0.54965 [
[.2619 .55187 -3 -9 ]
[.2619 .55187 3 0 ]
[.5 .55187 -3 -9 ]
[.5 .55187 3 0 ]
[.7381 .55187 -3 -9 ]
[.7381 .55187 3 0 ]
[.97619 .55187 -3 -9 ]
[.97619 .55187 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .12465 -24 -4.5 ]
[.01131 .12465 0 4.5 ]
[.01131 .23458 -24 -4.5 ]
[.01131 .23458 0 4.5 ]
[.01131 .34451 -24 -4.5 ]
[.01131 .34451 0 4.5 ]
[.01131 .45444 -24 -4.5 ]
[.01131 .45444 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .56437 m
.2619 .57062 L
s
[(2)] .2619 .55187 0 1 Mshowa
.5 .56437 m
.5 .57062 L
s
[(4)] .5 .55187 0 1 Mshowa
.7381 .56437 m
.7381 .57062 L
s
[(6)] .7381 .55187 0 1 Mshowa
.97619 .56437 m
.97619 .57062 L
s
[(8)] .97619 .55187 0 1 Mshowa
.125 Mabswid
.08333 .56437 m
.08333 .56812 L
s
.14286 .56437 m
.14286 .56812 L
s
.20238 .56437 m
.20238 .56812 L
s
.32143 .56437 m
.32143 .56812 L
s
.38095 .56437 m
.38095 .56812 L
s
.44048 .56437 m
.44048 .56812 L
s
.55952 .56437 m
.55952 .56812 L
s
.61905 .56437 m
.61905 .56812 L
s
.67857 .56437 m
.67857 .56812 L
s
.79762 .56437 m
.79762 .56812 L
s
.85714 .56437 m
.85714 .56812 L
s
.91667 .56437 m
.91667 .56812 L
s
.25 Mabswid
0 .56437 m
1 .56437 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .12465 m
.03006 .12465 L
s
[(-0.8)] .01131 .12465 1 0 Mshowa
.02381 .23458 m
.03006 .23458 L
s
[(-0.6)] .01131 .23458 1 0 Mshowa
.02381 .34451 m
.03006 .34451 L
s
[(-0.4)] .01131 .34451 1 0 Mshowa
.02381 .45444 m
.03006 .45444 L
s
[(-0.2)] .01131 .45444 1 0 Mshowa
.125 Mabswid
.02381 .0422 m
.02756 .0422 L
s
.02381 .06968 m
.02756 .06968 L
s
.02381 .09716 m
.02756 .09716 L
s
.02381 .15213 m
.02756 .15213 L
s
.02381 .17961 m
.02756 .17961 L
s
.02381 .20709 m
.02756 .20709 L
s
.02381 .26206 m
.02756 .26206 L
s
.02381 .28954 m
.02756 .28954 L
s
.02381 .31702 m
.02756 .31702 L
s
.02381 .37199 m
.02756 .37199 L
s
.02381 .39947 m
.02756 .39947 L
s
.02381 .42695 m
.02756 .42695 L
s
.02381 .48192 m
.02756 .48192 L
s
.02381 .5094 m
.02756 .5094 L
s
.02381 .53688 m
.02756 .53688 L
s
.02381 .59185 m
.02756 .59185 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01485 L
.02605 .01519 L
.02729 .01582 L
.02846 .01665 L
.03053 .01863 L
.03279 .02142 L
.0379 .02989 L
.04262 .03982 L
.06244 .09513 L
.10458 .24274 L
.1249 .31573 L
.14393 .37799 L
.16333 .43077 L
.18177 .46891 L
.19145 .4844 L
.20201 .49825 L
.22054 .51668 L
.26118 .54539 L
.30031 .57015 L
.3106 .57592 L
.32172 .58141 L
.33134 .58535 L
.33643 .58708 L
.34189 .58865 L
.34729 .5899 L
.35221 .59076 L
.35457 .59108 L
.35715 .59136 L
.35833 .59147 L
.35958 .59156 L
.36068 .59163 L
.36183 .59169 L
.36313 .59174 L
.36432 .59177 L
.3656 .59179 L
.36632 .59179 L
.367 .59179 L
.36823 .59177 L
.36934 .59174 L
.37063 .59169 L
.37185 .59162 L
.37461 .59143 L
.37715 .59118 L
.3829 .59041 L
.38757 .58957 L
.39259 .58849 L
.40166 .58611 L
.4223 .57936 L
.44205 .57247 L
Mistroke
.45248 .56913 L
.46358 .56605 L
.47441 .56362 L
.48421 .56197 L
.48895 .56137 L
.49407 .56086 L
.49642 .56067 L
.4989 .56051 L
.50103 .56039 L
.50334 .56029 L
.50467 .56025 L
.50589 .56021 L
.50707 .56019 L
.50831 .56017 L
.50942 .56015 L
.51047 .56015 L
.51161 .56014 L
.51284 .56015 L
.51408 .56016 L
.51478 .56017 L
.51543 .56018 L
.51675 .5602 L
.51815 .56024 L
.5207 .56032 L
.52302 .56041 L
.52755 .56065 L
.53246 .56097 L
.54136 .56168 L
.56089 .56356 L
.57123 .56454 L
.58233 .56545 L
.58781 .56583 L
.593 .56613 L
.59805 .56637 L
.60273 .56655 L
.60715 .56666 L
.60939 .56671 L
.61067 .56673 L
.61186 .56674 L
.61305 .56675 L
.61432 .56676 L
.61559 .56677 L
.61631 .56677 L
.61698 .56677 L
.61819 .56677 L
.6193 .56677 L
.62058 .56676 L
.62179 .56675 L
.62294 .56674 L
.62417 .56672 L
Mistroke
.62641 .56669 L
.63149 .56657 L
.63687 .5664 L
.64178 .56621 L
.66022 .56526 L
.68083 .56405 L
.69086 .56352 L
.69995 .56311 L
.70453 .56294 L
.70948 .56278 L
.71376 .56267 L
.71845 .56257 L
.72104 .56253 L
.72345 .5625 L
.72599 .56247 L
.72742 .56246 L
.72872 .56245 L
.72993 .56245 L
.73104 .56245 L
.73227 .56244 L
.73357 .56244 L
.7347 .56245 L
.73576 .56245 L
.73691 .56245 L
.73816 .56246 L
.74056 .56248 L
.74313 .56251 L
.74774 .56258 L
.75323 .56268 L
.75822 .5628 L
.77932 .56347 L
.80014 .56422 L
.80928 .56451 L
.81933 .56479 L
.82899 .56501 L
.83363 .56509 L
.83803 .56515 L
.84041 .56518 L
.84301 .5652 L
.8454 .56522 L
.84757 .56523 L
.85014 .56525 L
.85156 .56525 L
.8522 .56525 L
.85288 .56525 L
.85412 .56525 L
.85525 .56526 L
.85647 .56526 L
.85717 .56526 L
.85781 .56525 L
Mistroke
.85908 .56525 L
.85972 .56525 L
.86043 .56525 L
.86284 .56524 L
.8642 .56523 L
.86566 .56523 L
.8683 .56521 L
.87348 .56516 L
.87822 .56511 L
.89679 .56483 L
.91737 .56447 L
.9274 .5643 L
.93649 .56417 L
.946 .56406 L
.95036 .56402 L
.95497 .56398 L
.95989 .56396 L
.96208 .56395 L
.96443 .56394 L
.96575 .56393 L
.96695 .56393 L
.96818 .56393 L
.96931 .56392 L
.97063 .56392 L
.97132 .56392 L
.97206 .56392 L
.9733 .56392 L
.97401 .56392 L
.97467 .56392 L
.97546 .56392 L
.97619 .56392 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02499 .01485 L
.02605 .01521 L
.02729 .01588 L
.02846 .01678 L
.03053 .01895 L
.03279 .0221 L
.0379 .03204 L
.04262 .04417 L
.06244 .11556 L
.0825 .19976 L
.10458 .2832 L
.1249 .34203 L
.14393 .38166 L
.16418 .41232 L
.1827 .43551 L
.22241 .48697 L
.2606 .54287 L
.28192 .57055 L
.29199 .58124 L
.30125 .58935 L
.31093 .59588 L
.31602 .59848 L
.3214 .60062 L
.32366 .60133 L
.32608 .60196 L
.32817 .60241 L
.33045 .6028 L
.33183 .60298 L
.33311 .60311 L
.33434 .60321 L
.33564 .60328 L
.3368 .60331 L
.33789 .60332 L
.33909 .6033 L
.34038 .60325 L
.34164 .60318 L
.34278 .60308 L
.34534 .60279 L
.34771 .60242 L
.34995 .60198 L
.35497 .60073 L
.36042 .59897 L
.38152 .58939 L
.401 .57891 L
.41134 .57362 L
.42244 .56858 L
.43308 .56463 L
.4428 .56188 L
.44747 .56087 L
Mistroke
.45257 .56 L
.4549 .55968 L
.45738 .55939 L
.45951 .55918 L
.46184 .55901 L
.46446 .55886 L
.46588 .5588 L
.46657 .55878 L
.46721 .55876 L
.46846 .55874 L
.4696 .55873 L
.47082 .55873 L
.47151 .55873 L
.47215 .55874 L
.47279 .55875 L
.47348 .55876 L
.47472 .5588 L
.4762 .55885 L
.47756 .55891 L
.48035 .55907 L
.48329 .55929 L
.49294 .56032 L
.50348 .56183 L
.52477 .56532 L
.53483 .56684 L
.54409 .568 L
.55375 .56891 L
.55884 .56925 L
.5614 .56938 L
.56421 .5695 L
.56548 .56954 L
.56669 .56957 L
.56778 .56959 L
.56894 .56962 L
.57021 .56963 L
.57137 .56964 L
.57263 .56965 L
.57335 .56965 L
.57402 .56965 L
.57514 .56964 L
.57632 .56963 L
.57733 .56961 L
.57843 .56959 L
.58089 .56953 L
.58319 .56946 L
.58822 .56923 L
.59369 .56889 L
.60362 .56808 L
.6222 .5661 L
.64166 .56389 L
Mistroke
.65198 .56286 L
.66309 .56196 L
.66853 .56161 L
.67371 .56134 L
.67835 .56115 L
.68101 .56107 L
.68342 .56101 L
.68588 .56096 L
.68701 .56094 L
.6882 .56093 L
.68947 .56092 L
.69065 .56091 L
.69191 .5609 L
.69262 .5609 L
.69329 .5609 L
.69448 .5609 L
.69561 .56091 L
.69662 .56091 L
.69772 .56092 L
.69891 .56094 L
.70018 .56095 L
.70246 .56099 L
.70735 .56111 L
.71184 .56126 L
.72194 .56171 L
.74023 .56279 L
.76077 .56411 L
.77078 .56468 L
.77987 .56513 L
.78936 .56549 L
.79371 .56562 L
.79831 .56573 L
.80065 .56578 L
.80323 .56582 L
.8056 .56586 L
.80776 .56588 L
.80898 .56589 L
.81031 .5659 L
.81104 .5659 L
.81172 .56591 L
.8124 .56591 L
.81305 .56591 L
.81431 .56592 L
.81545 .56592 L
.81667 .56592 L
.81737 .56591 L
.818 .56591 L
.81927 .56591 L
.82047 .5659 L
.82272 .56589 L
Mistroke
.82514 .56586 L
.82777 .56583 L
.8325 .56576 L
.83688 .56568 L
.85756 .56512 L
.87787 .56448 L
.8878 .56419 L
.8969 .56397 L
.90624 .56378 L
.91053 .56371 L
.91512 .56365 L
.91766 .56362 L
.91997 .5636 L
.92232 .56359 L
.92449 .56357 L
.92702 .56356 L
.92835 .56356 L
.92903 .56355 L
.92976 .56355 L
.93098 .56355 L
.93212 .56355 L
.93282 .56355 L
.93348 .56355 L
.93472 .56355 L
.93586 .56355 L
.93708 .56355 L
.93824 .56356 L
.93931 .56356 L
.94177 .56357 L
.94437 .56359 L
.94926 .56362 L
.95462 .56368 L
.97304 .56394 L
.97619 .56399 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.388523 3.58661 [
[.2619 .37602 -3 -9 ]
[.2619 .37602 3 0 ]
[.5 .37602 -3 -9 ]
[.5 .37602 3 0 ]
[.7381 .37602 -3 -9 ]
[.7381 .37602 3 0 ]
[.97619 .37602 -3 -9 ]
[.97619 .37602 3 0 ]
[.01131 .02986 -24 -4.5 ]
[.01131 .02986 0 4.5 ]
[.01131 .11953 -36 -4.5 ]
[.01131 .11953 0 4.5 ]
[.01131 .20919 -30 -4.5 ]
[.01131 .20919 0 4.5 ]
[.01131 .29886 -36 -4.5 ]
[.01131 .29886 0 4.5 ]
[.01131 .47819 -30 -4.5 ]
[.01131 .47819 0 4.5 ]
[.01131 .56785 -24 -4.5 ]
[.01131 .56785 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .38852 m
.2619 .39477 L
s
[(2)] .2619 .37602 0 1 Mshowa
.5 .38852 m
.5 .39477 L
s
[(4)] .5 .37602 0 1 Mshowa
.7381 .38852 m
.7381 .39477 L
s
[(6)] .7381 .37602 0 1 Mshowa
.97619 .38852 m
.97619 .39477 L
s
[(8)] .97619 .37602 0 1 Mshowa
.125 Mabswid
.08333 .38852 m
.08333 .39227 L
s
.14286 .38852 m
.14286 .39227 L
s
.20238 .38852 m
.20238 .39227 L
s
.32143 .38852 m
.32143 .39227 L
s
.38095 .38852 m
.38095 .39227 L
s
.44048 .38852 m
.44048 .39227 L
s
.55952 .38852 m
.55952 .39227 L
s
.61905 .38852 m
.61905 .39227 L
s
.67857 .38852 m
.67857 .39227 L
s
.79762 .38852 m
.79762 .39227 L
s
.85714 .38852 m
.85714 .39227 L
s
.91667 .38852 m
.91667 .39227 L
s
.25 Mabswid
0 .38852 m
1 .38852 L
s
.02381 .02986 m
.03006 .02986 L
s
[(-0.1)] .01131 .02986 1 0 Mshowa
.02381 .11953 m
.03006 .11953 L
s
[(-0.075)] .01131 .11953 1 0 Mshowa
.02381 .20919 m
.03006 .20919 L
s
[(-0.05)] .01131 .20919 1 0 Mshowa
.02381 .29886 m
.03006 .29886 L
s
[(-0.025)] .01131 .29886 1 0 Mshowa
.02381 .47819 m
.03006 .47819 L
s
[(0.025)] .01131 .47819 1 0 Mshowa
.02381 .56785 m
.03006 .56785 L
s
[(0.05)] .01131 .56785 1 0 Mshowa
.125 Mabswid
.02381 .0478 m
.02756 .0478 L
s
.02381 .06573 m
.02756 .06573 L
s
.02381 .08366 m
.02756 .08366 L
s
.02381 .10159 m
.02756 .10159 L
s
.02381 .13746 m
.02756 .13746 L
s
.02381 .15539 m
.02756 .15539 L
s
.02381 .17333 m
.02756 .17333 L
s
.02381 .19126 m
.02756 .19126 L
s
.02381 .22713 m
.02756 .22713 L
s
.02381 .24506 m
.02756 .24506 L
s
.02381 .26299 m
.02756 .26299 L
s
.02381 .28093 m
.02756 .28093 L
s
.02381 .31679 m
.02756 .31679 L
s
.02381 .33472 m
.02756 .33472 L
s
.02381 .35266 m
.02756 .35266 L
s
.02381 .37059 m
.02756 .37059 L
s
.02381 .40646 m
.02756 .40646 L
s
.02381 .42439 m
.02756 .42439 L
s
.02381 .44232 m
.02756 .44232 L
s
.02381 .46026 m
.02756 .46026 L
s
.02381 .49612 m
.02756 .49612 L
s
.02381 .51405 m
.02756 .51405 L
s
.02381 .53199 m
.02756 .53199 L
s
.02381 .54992 m
.02756 .54992 L
s
.02381 .01193 m
.02756 .01193 L
s
.02381 .58579 m
.02756 .58579 L
s
.02381 .60372 m
.02756 .60372 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 0 r
.5 Mabswid
.02381 .38852 m
.06244 .28693 L
.08255 .21778 L
.0932 .18829 L
.09905 .17487 L
.10458 .16423 L
.10972 .15627 L
.11243 .15286 L
.11531 .14987 L
.11772 .14786 L
.119 .14699 L
.12038 .1462 L
.12164 .14562 L
.1228 .1452 L
.12396 .14489 L
.12507 .14471 L
.12627 .14463 L
.12736 .14466 L
.12861 .14483 L
.1298 .14511 L
.1309 .14548 L
.13191 .14592 L
.13419 .14724 L
.1365 .14904 L
.13903 .15156 L
.14415 .15839 L
.14939 .16774 L
.15436 .17874 L
.16366 .20454 L
.18458 .28166 L
.2028 .35852 L
.22291 .43618 L
.23242 .46571 L
.24268 .49038 L
.24833 .50046 L
.25081 .50406 L
.25352 .50742 L
.25591 .50989 L
.25847 .51202 L
.25989 .51296 L
.26117 .51368 L
.26247 .51428 L
.26369 .51471 L
.2648 .515 L
.266 .51521 L
.26668 .51528 L
.26732 .51532 L
.26854 .51529 L
.26981 .51515 L
.27099 .5149 L
Mistroke
.27229 .51452 L
.27367 .51397 L
.27616 .51265 L
.2785 .51102 L
.28287 .50702 L
.28808 .50075 L
.29287 .4937 L
.30367 .47413 L
.32413 .42928 L
.34321 .38813 L
.35265 .37092 L
.36157 .35752 L
.36651 .35149 L
.37186 .3461 L
.37673 .34229 L
.38123 .33968 L
.38366 .33864 L
.38588 .3379 L
.38715 .33757 L
.38832 .33733 L
.38955 .33714 L
.39019 .33706 L
.39089 .33699 L
.39206 .33693 L
.39333 .33692 L
.39453 .33697 L
.39563 .33706 L
.39663 .33719 L
.39772 .33736 L
.39994 .33786 L
.40262 .33869 L
.40508 .33966 L
.41059 .34253 L
.42055 .34975 L
.44122 .36995 L
.46036 .38964 L
.46993 .39819 L
.47893 .40485 L
.4883 .41012 L
.49329 .41216 L
.49588 .41301 L
.49866 .41375 L
.50125 .41429 L
.50361 .41466 L
.50475 .4148 L
.50598 .41492 L
.50714 .415 L
.50822 .41505 L
.50947 .41507 L
.51064 .41507 L
Mistroke
.51192 .41504 L
.51264 .415 L
.5133 .41497 L
.51462 .41486 L
.51606 .41471 L
.51868 .41434 L
.52146 .41381 L
.52398 .41322 L
.52962 .41153 L
.53977 .40744 L
.56065 .39646 L
.57986 .38609 L
.58956 .38163 L
.59862 .37823 L
.60356 .37674 L
.60806 .37561 L
.61307 .37464 L
.61582 .37422 L
.61843 .37392 L
.6208 .3737 L
.62188 .37362 L
.62302 .37356 L
.62429 .3735 L
.62546 .37347 L
.62672 .37344 L
.62743 .37344 L
.62809 .37344 L
.62873 .37344 L
.62943 .37345 L
.63069 .37349 L
.63192 .37353 L
.63305 .37359 L
.63563 .37377 L
.63835 .37402 L
.64289 .3746 L
.64713 .3753 L
.65678 .37736 L
.69562 .38862 L
.70576 .39127 L
.71681 .39362 L
.72187 .39448 L
.72725 .39521 L
.73232 .39575 L
.73692 .39609 L
.73925 .39622 L
.74059 .39628 L
.74181 .39632 L
.7431 .39635 L
.74377 .39637 L
.74449 .39638 L
Mistroke
.74577 .3964 L
.74698 .3964 L
.74809 .3964 L
.74931 .39639 L
.75058 .39637 L
.75178 .39634 L
.75392 .39627 L
.75622 .39617 L
.75888 .39602 L
.76179 .39582 L
.7671 .39536 L
.77706 .39421 L
.79836 .39101 L
.81769 .38803 L
.82736 .38677 L
.83783 .38567 L
.84263 .38527 L
.84771 .38493 L
.85205 .38471 L
.85452 .38461 L
.85681 .38454 L
.85931 .38448 L
.86064 .38445 L
.86204 .38443 L
.86326 .38442 L
.8644 .38441 L
.86565 .38441 L
.86636 .38441 L
.867 .38441 L
.86813 .38442 L
.86917 .38443 L
.87031 .38444 L
.87154 .38446 L
.87403 .38451 L
.87631 .38457 L
.88147 .38475 L
.88706 .38502 L
.89722 .38566 L
.91669 .38721 L
.93812 .38894 L
.9476 .38958 L
.95283 .38987 L
.95779 .39012 L
.96239 .39031 L
.9674 .39047 L
.96961 .39053 L
.97196 .39059 L
.97619 .39066 L
Mfstroke
1 0 0 r
.02381 .38852 m
.06244 .18666 L
.07216 .12121 L
.08255 .06471 L
.08852 .04099 L
.09135 .0323 L
.09396 .02579 L
.09658 .02075 L
.09795 .0187 L
.09942 .01699 L
.10069 .01589 L
.10187 .01519 L
.10318 .01478 L
.10391 .01472 L
.10458 .01476 L
.10586 .01512 L
.10701 .01577 L
.10766 .01625 L
.10835 .01687 L
.10961 .01827 L
.11204 .02193 L
.11428 .0264 L
.11943 .04056 L
.12487 .06101 L
.13406 .10685 L
.14415 .16999 L
.1653 .32388 L
.18458 .45732 L
.19415 .51146 L
.19919 .5355 L
.20456 .55725 L
.20923 .57286 L
.21439 .58635 L
.21665 .59101 L
.21908 .59519 L
.22139 .59835 L
.22348 .60054 L
.22472 .60153 L
.22588 .60226 L
.22711 .60283 L
.2278 .60305 L
.22844 .6032 L
.22951 .60332 L
.23068 .60327 L
.23191 .60302 L
.23306 .6026 L
.2337 .60229 L
.23441 .60188 L
.23569 .60098 L
.2381 .59872 L
Mistroke
.24092 .59519 L
.24353 .59108 L
.24889 .5803 L
.25374 .5681 L
.26462 .53402 L
.28553 .45413 L
.30474 .38252 L
.31446 .35243 L
.32353 .32986 L
.32848 .32005 L
.33298 .31273 L
.33799 .30645 L
.34074 .30382 L
.34335 .30186 L
.34449 .30117 L
.34572 .30053 L
.34679 .30007 L
.34795 .29966 L
.34924 .29932 L
.34995 .29919 L
.3506 .2991 L
.35177 .29901 L
.35303 .29902 L
.35372 .29907 L
.35436 .29915 L
.35506 .29927 L
.3558 .29943 L
.35704 .29978 L
.35841 .30028 L
.36094 .30153 L
.3633 .30304 L
.36794 .30695 L
.37219 .31152 L
.38173 .32466 L
.4024 .36137 L
.42154 .39608 L
.43111 .4108 L
.4401 .42205 L
.44499 .42697 L
.44948 .43067 L
.45446 .43387 L
.45708 .43516 L
.45984 .43623 L
.46107 .43661 L
.4624 .43696 L
.46358 .43721 L
.46483 .43742 L
.46595 .43755 L
.46719 .43765 L
.46831 .43769 L
Mistroke
.46937 .43768 L
.47068 .43762 L
.47193 .4375 L
.47305 .43734 L
.47428 .43713 L
.47701 .43646 L
.47956 .43562 L
.48422 .43357 L
.48844 .43119 L
.49791 .42429 L
.5188 .40436 L
.538 .38529 L
.54771 .37698 L
.55676 .37059 L
.56621 .36559 L
.57121 .36368 L
.57381 .3629 L
.57657 .36223 L
.57909 .36175 L
.58042 .36155 L
.58186 .36138 L
.58318 .36126 L
.58439 .36118 L
.58554 .36113 L
.58675 .36111 L
.58745 .36111 L
.58808 .36112 L
.58881 .36114 L
.5895 .36116 L
.59072 .36123 L
.59204 .36134 L
.59351 .3615 L
.59505 .36171 L
.59783 .36218 L
.60278 .36335 L
.60741 .36478 L
.61795 .36902 L
.6568 .3895 L
.66694 .39417 L
.67229 .39629 L
.67799 .39824 L
.68346 .39979 L
.68842 .40091 L
.69082 .40136 L
.69341 .40176 L
.69586 .40208 L
.69809 .40231 L
.70048 .40249 L
.70179 .40257 L
.70303 .40262 L
Mistroke
.70418 .40266 L
.70524 .40268 L
.7064 .40269 L
.70763 .40268 L
.70887 .40266 L
.70956 .40264 L
.7102 .40262 L
.71143 .40256 L
.71261 .4025 L
.71523 .40231 L
.71809 .40203 L
.72338 .40132 L
.72902 .40034 L
.73917 .39807 L
.75913 .39255 L
.78074 .38667 L
.79088 .38445 L
.79642 .38345 L
.8016 .38266 L
.80638 .38208 L
.81075 .38166 L
.81307 .38148 L
.81559 .38133 L
.81698 .38126 L
.81826 .38121 L
.81949 .38116 L
.82079 .38113 L
.82195 .3811 L
.82321 .38108 L
.82435 .38108 L
.82542 .38107 L
.82669 .38108 L
.82783 .38109 L
.82847 .3811 L
.82916 .38112 L
.83041 .38115 L
.8327 .38123 L
.83511 .38134 L
.83945 .3816 L
.84451 .38201 L
.84926 .38248 L
.86005 .38381 L
.87861 .38656 L
.89886 .38947 L
.90984 .39075 L
.91518 .39125 L
.92002 .39164 L
.9247 .39195 L
.92976 .3922 L
.93254 .39231 L
Mistroke
.9351 .39238 L
.93754 .39244 L
.93877 .39246 L
.93943 .39247 L
.94012 .39248 L
.94129 .39249 L
.94237 .39249 L
.94353 .39249 L
.94481 .39249 L
.94591 .39249 L
.94709 .39248 L
.94821 .39247 L
.94924 .39245 L
.95117 .39242 L
.95328 .39237 L
.95754 .39224 L
.96222 .39204 L
.96721 .39179 L
.97619 .39122 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0492261 0.501404 [
[.2619 .03673 -3 -9 ]
[.2619 .03673 3 0 ]
[.5 .03673 -3 -9 ]
[.5 .03673 3 0 ]
[.7381 .03673 -3 -9 ]
[.7381 .03673 3 0 ]
[.97619 .03673 -3 -9 ]
[.97619 .03673 3 0 ]
[.01131 .14951 -18 -4.5 ]
[.01131 .14951 0 4.5 ]
[.01131 .24979 -18 -4.5 ]
[.01131 .24979 0 4.5 ]
[.01131 .35007 -18 -4.5 ]
[.01131 .35007 0 4.5 ]
[.01131 .45035 -18 -4.5 ]
[.01131 .45035 0 4.5 ]
[.01131 .55063 -6 -4.5 ]
[.01131 .55063 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .04923 m
.2619 .05548 L
s
[(2)] .2619 .03673 0 1 Mshowa
.5 .04923 m
.5 .05548 L
s
[(4)] .5 .03673 0 1 Mshowa
.7381 .04923 m
.7381 .05548 L
s
[(6)] .7381 .03673 0 1 Mshowa
.97619 .04923 m
.97619 .05548 L
s
[(8)] .97619 .03673 0 1 Mshowa
.125 Mabswid
.08333 .04923 m
.08333 .05298 L
s
.14286 .04923 m
.14286 .05298 L
s
.20238 .04923 m
.20238 .05298 L
s
.32143 .04923 m
.32143 .05298 L
s
.38095 .04923 m
.38095 .05298 L
s
.44048 .04923 m
.44048 .05298 L
s
.55952 .04923 m
.55952 .05298 L
s
.61905 .04923 m
.61905 .05298 L
s
.67857 .04923 m
.67857 .05298 L
s
.79762 .04923 m
.79762 .05298 L
s
.85714 .04923 m
.85714 .05298 L
s
.91667 .04923 m
.91667 .05298 L
s
.25 Mabswid
0 .04923 m
1 .04923 L
s
.02381 .14951 m
.03006 .14951 L
s
[(0.2)] .01131 .14951 1 0 Mshowa
.02381 .24979 m
.03006 .24979 L
s
[(0.4)] .01131 .24979 1 0 Mshowa
.02381 .35007 m
.03006 .35007 L
s
[(0.6)] .01131 .35007 1 0 Mshowa
.02381 .45035 m
.03006 .45035 L
s
[(0.8)] .01131 .45035 1 0 Mshowa
.02381 .55063 m
.03006 .55063 L
s
[(1)] .01131 .55063 1 0 Mshowa
.125 Mabswid
.02381 .0743 m
.02756 .0743 L
s
.02381 .09937 m
.02756 .09937 L
s
.02381 .12444 m
.02756 .12444 L
s
.02381 .17458 m
.02756 .17458 L
s
.02381 .19965 m
.02756 .19965 L
s
.02381 .22472 m
.02756 .22472 L
s
.02381 .27486 m
.02756 .27486 L
s
.02381 .29993 m
.02756 .29993 L
s
.02381 .325 m
.02756 .325 L
s
.02381 .37514 m
.02756 .37514 L
s
.02381 .40021 m
.02756 .40021 L
s
.02381 .42528 m
.02756 .42528 L
s
.02381 .47542 m
.02756 .47542 L
s
.02381 .50049 m
.02756 .50049 L
s
.02381 .52556 m
.02756 .52556 L
s
.02381 .02416 m
.02756 .02416 L
s
.02381 .5757 m
.02756 .5757 L
s
.02381 .60077 m
.02756 .60077 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 0 r
.5 Mabswid
.02381 .55063 m
.02499 .55088 L
.02605 .55149 L
.02729 .5526 L
.02846 .554 L
.03279 .56132 L
.04262 .58242 L
.04723 .59113 L
.04976 .59507 L
.05212 .59812 L
.05468 .60065 L
.05603 .60166 L
.05673 .60208 L
.05749 .60247 L
.05818 .60276 L
.05882 .60297 L
.06008 .60322 L
.06122 .60327 L
.06244 .60313 L
.0631 .60297 L
.06383 .60272 L
.06459 .6024 L
.06529 .60203 L
.06791 .60008 L
.0694 .59858 L
.07076 .59697 L
.07382 .59254 L
.07933 .58192 L
.08454 .56905 L
.10458 .50112 L
.14291 .33763 L
.16229 .25674 L
.18369 .17746 L
.20418 .11524 L
.22296 .07161 L
.23238 .05469 L
.2423 .0404 L
.25227 .02951 L
.25791 .0248 L
.26316 .0213 L
.26821 .0187 L
.27087 .01761 L
.27368 .01666 L
.27615 .016 L
.27885 .01543 L
.28004 .01524 L
.28131 .01507 L
.28243 .01494 L
.28362 .01484 L
.28486 .01477 L
Mistroke
.286 .01473 L
.2867 .01472 L
.28737 .01472 L
.2886 .01473 L
.28979 .01478 L
.29087 .01484 L
.29207 .01493 L
.29333 .01505 L
.29552 .01533 L
.29756 .01565 L
.30221 .0166 L
.31268 .01965 L
.3226 .0233 L
.34117 .0308 L
.35942 .03739 L
.36981 .04031 L
.37489 .04147 L
.37955 .04237 L
.38411 .04311 L
.38909 .04375 L
.3941 .04423 L
.39683 .04442 L
.39936 .04456 L
.40068 .04462 L
.40211 .04467 L
.40345 .04471 L
.40469 .04474 L
.40581 .04476 L
.40705 .04477 L
.40833 .04477 L
.40953 .04477 L
.4102 .04477 L
.41094 .04476 L
.41163 .04475 L
.41227 .04474 L
.41477 .04469 L
.41606 .04465 L
.41749 .0446 L
.42038 .04448 L
.43046 .04389 L
.43971 .04322 L
.4505 .04241 L
.45577 .04205 L
.46055 .04177 L
.46493 .04155 L
.46969 .04136 L
.4723 .04129 L
.47345 .04126 L
.47471 .04124 L
.47582 .04122 L
Mistroke
.47701 .0412 L
.47827 .04119 L
.47945 .04118 L
.48012 .04118 L
.48083 .04118 L
.4821 .04118 L
.48289 .04119 L
.48362 .04119 L
.485 .04121 L
.48631 .04123 L
.48753 .04126 L
.49026 .04133 L
.49255 .04141 L
.49507 .04151 L
.50015 .04179 L
.51036 .04257 L
.51967 .04351 L
.54059 .04615 L
.5613 .04893 L
.57041 .05004 L
.58046 .05109 L
.59005 .05189 L
.59905 .05244 L
.60402 .05266 L
.60856 .05281 L
.61095 .05286 L
.61355 .05291 L
.61487 .05292 L
.61559 .05293 L
.61627 .05293 L
.61691 .05294 L
.6176 .05294 L
.6188 .05295 L
.62004 .05295 L
.62117 .05294 L
.62247 .05294 L
.6237 .05293 L
.62484 .05291 L
.62589 .0529 L
.62828 .05286 L
.63093 .0528 L
.63333 .05274 L
.6387 .05256 L
.64954 .05207 L
.65974 .05148 L
.67817 .05031 L
.68863 .04967 L
.69837 .04913 L
.70883 .04864 L
.71836 .04831 L
Mistroke
.72359 .04817 L
.72854 .04808 L
.73126 .04804 L
.73377 .04801 L
.73652 .04798 L
.73791 .04797 L
.73865 .04797 L
.73944 .04797 L
.74073 .04796 L
.74192 .04796 L
.74266 .04796 L
.74335 .04796 L
.74463 .04796 L
.74587 .04797 L
.74701 .04797 L
.74825 .04798 L
.74957 .04799 L
.75186 .048 L
.75399 .04803 L
.75884 .04809 L
.76411 .04818 L
.76892 .04828 L
.77972 .04855 L
.8004 .04913 L
.8095 .04937 L
.81955 .04961 L
.82913 .04979 L
.83351 .04986 L
.83813 .04991 L
.84049 .04994 L
.84308 .04996 L
.84546 .04998 L
.84762 .04999 L
.85019 .05 L
.8516 .05 L
.85225 .05001 L
.85293 .05001 L
.85416 .05001 L
.8553 .05001 L
.85652 .05001 L
.85722 .05001 L
.85787 .05001 L
.85912 .05001 L
.85982 .05001 L
.86045 .05001 L
.86284 .05 L
.86419 .04999 L
.86564 .04999 L
.86827 .04997 L
.87341 .04993 L
Mistroke
.87815 .04989 L
.89668 .04964 L
.91713 .04931 L
.92711 .04915 L
.93621 .04903 L
.945 .04893 L
.95456 .04885 L
.95981 .04882 L
.96212 .04881 L
.96466 .0488 L
.96705 .04879 L
.9693 .04879 L
.97053 .04878 L
.97167 .04878 L
.97291 .04878 L
.97422 .04878 L
.97524 .04878 L
.97619 .04878 L
Mfstroke
1 0 0 r
.02381 .55063 m
.02499 .55088 L
.02605 .5515 L
.02729 .55262 L
.02846 .55402 L
.03279 .56128 L
.04262 .58191 L
.04723 .59046 L
.05212 .59745 L
.05468 .60008 L
.05613 .60124 L
.05749 .6021 L
.05874 .60269 L
.05988 .60306 L
.06119 .60329 L
.06244 .60332 L
.0631 .60326 L
.06381 .60313 L
.0651 .60274 L
.06635 .60217 L
.0675 .60147 L
.07012 .59931 L
.07289 .59614 L
.07752 .58894 L
.08259 .57842 L
.09396 .54606 L
.10458 .50685 L
.14349 .32501 L
.1633 .23193 L
.18485 .14601 L
.19488 .11364 L
.20555 .08518 L
.21465 .06575 L
.22469 .04935 L
.22961 .04314 L
.23479 .0378 L
.23926 .03411 L
.24404 .03106 L
.24675 .02971 L
.2492 .0287 L
.2517 .02788 L
.254 .0273 L
.25528 .02704 L
.25669 .02681 L
.25811 .02663 L
.25888 .02656 L
.25961 .02651 L
.26029 .02647 L
.26094 .02644 L
.26216 .02641 L
Mistroke
.26347 .02643 L
.26421 .02645 L
.2649 .02648 L
.26619 .02657 L
.26755 .0267 L
.26999 .02702 L
.27262 .02747 L
.27549 .02809 L
.28546 .03098 L
.30408 .03769 L
.31412 .04106 L
.32363 .04365 L
.32888 .04475 L
.33165 .04523 L
.33458 .04565 L
.33705 .04595 L
.33977 .0462 L
.34096 .04629 L
.34224 .04637 L
.34343 .04643 L
.34456 .04647 L
.34582 .04651 L
.34696 .04653 L
.3482 .04654 L
.34889 .04653 L
.34953 .04653 L
.3506 .04651 L
.35178 .04648 L
.35301 .04643 L
.35415 .04637 L
.3568 .04621 L
.35921 .046 L
.36464 .04538 L
.36982 .04461 L
.37547 .04361 L
.38575 .04147 L
.40511 .03716 L
.4154 .03519 L
.4208 .03434 L
.4265 .03361 L
.43153 .03312 L
.43439 .03292 L
.43576 .03284 L
.43705 .03278 L
.43822 .03273 L
.4395 .03269 L
.44066 .03266 L
.44172 .03264 L
.44288 .03263 L
.44415 .03263 L
Mistroke
.44479 .03263 L
.44548 .03264 L
.44673 .03266 L
.44799 .03269 L
.44916 .03273 L
.45182 .03286 L
.45416 .033 L
.45665 .0332 L
.46142 .03368 L
.46573 .03423 L
.47577 .03591 L
.48499 .03785 L
.50582 .04305 L
.52626 .04818 L
.53623 .05034 L
.54533 .05201 L
.55475 .05337 L
.55907 .05386 L
.56367 .05428 L
.56599 .05446 L
.56856 .05463 L
.57092 .05476 L
.57308 .05485 L
.57562 .05494 L
.57696 .05497 L
.57836 .055 L
.57959 .05501 L
.58073 .05502 L
.58198 .05503 L
.58268 .05503 L
.58332 .05503 L
.58451 .05502 L
.58563 .05501 L
.58686 .05499 L
.58817 .05496 L
.59086 .05488 L
.59331 .05479 L
.59803 .05456 L
.60252 .05428 L
.61247 .05348 L
.62332 .05241 L
.64469 .05013 L
.66404 .04837 L
.67375 .04772 L
.67922 .04744 L
.68424 .04724 L
.68865 .04711 L
.69116 .04705 L
.69349 .04701 L
.69476 .047 L
Mistroke
.69595 .04698 L
.69703 .04697 L
.6982 .04697 L
.69947 .04696 L
.70011 .04696 L
.70082 .04696 L
.70207 .04696 L
.70324 .04697 L
.70448 .04697 L
.70581 .04698 L
.7082 .04701 L
.71104 .04706 L
.71361 .04711 L
.71869 .04725 L
.72348 .0474 L
.742 .04823 L
.76037 .04917 L
.7708 .04967 L
.78054 .05007 L
.79015 .05038 L
.79555 .05051 L
.80047 .0506 L
.80316 .05064 L
.80565 .05067 L
.80838 .05069 L
.80976 .0507 L
.8105 .0507 L
.81128 .05071 L
.81191 .05071 L
.81261 .05071 L
.81382 .05071 L
.81451 .05072 L
.81524 .05072 L
.81657 .05071 L
.81721 .05071 L
.8179 .05071 L
.81916 .05071 L
.82039 .0507 L
.82153 .05069 L
.82397 .05067 L
.8262 .05065 L
.83122 .05059 L
.84028 .05042 L
.85087 .05016 L
.86092 .04987 L
.88098 .04927 L
.89915 .04881 L
.90403 .04872 L
.9093 .04863 L
.91386 .04856 L
Mistroke
.91885 .04851 L
.92142 .04848 L
.92417 .04846 L
.92569 .04845 L
.92708 .04845 L
.92849 .04844 L
.92979 .04844 L
.93099 .04843 L
.93226 .04843 L
.93354 .04843 L
.93427 .04843 L
.93495 .04843 L
.93618 .04843 L
.9373 .04843 L
.93854 .04843 L
.93984 .04843 L
.94102 .04844 L
.9423 .04844 L
.94461 .04845 L
.94895 .04848 L
.95401 .04852 L
.95868 .04857 L
.97619 .0488 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.37569 2.09278 [
[.2619 .36319 -3 -9 ]
[.2619 .36319 3 0 ]
[.5 .36319 -3 -9 ]
[.5 .36319 3 0 ]
[.7381 .36319 -3 -9 ]
[.7381 .36319 3 0 ]
[.97619 .36319 -3 -9 ]
[.97619 .36319 3 0 ]
[.01131 .06177 -30 -4.5 ]
[.01131 .06177 0 4.5 ]
[.01131 .16641 -24 -4.5 ]
[.01131 .16641 0 4.5 ]
[.01131 .27105 -30 -4.5 ]
[.01131 .27105 0 4.5 ]
[.01131 .48033 -24 -4.5 ]
[.01131 .48033 0 4.5 ]
[.01131 .58497 -18 -4.5 ]
[.01131 .58497 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37569 m
.2619 .38194 L
s
[(2)] .2619 .36319 0 1 Mshowa
.5 .37569 m
.5 .38194 L
s
[(4)] .5 .36319 0 1 Mshowa
.7381 .37569 m
.7381 .38194 L
s
[(6)] .7381 .36319 0 1 Mshowa
.97619 .37569 m
.97619 .38194 L
s
[(8)] .97619 .36319 0 1 Mshowa
.125 Mabswid
.08333 .37569 m
.08333 .37944 L
s
.14286 .37569 m
.14286 .37944 L
s
.20238 .37569 m
.20238 .37944 L
s
.32143 .37569 m
.32143 .37944 L
s
.38095 .37569 m
.38095 .37944 L
s
.44048 .37569 m
.44048 .37944 L
s
.55952 .37569 m
.55952 .37944 L
s
.61905 .37569 m
.61905 .37944 L
s
.67857 .37569 m
.67857 .37944 L
s
.79762 .37569 m
.79762 .37944 L
s
.85714 .37569 m
.85714 .37944 L
s
.91667 .37569 m
.91667 .37944 L
s
.25 Mabswid
0 .37569 m
1 .37569 L
s
.02381 .06177 m
.03006 .06177 L
s
[(-0.15)] .01131 .06177 1 0 Mshowa
.02381 .16641 m
.03006 .16641 L
s
[(-0.1)] .01131 .16641 1 0 Mshowa
.02381 .27105 m
.03006 .27105 L
s
[(-0.05)] .01131 .27105 1 0 Mshowa
.02381 .48033 m
.03006 .48033 L
s
[(0.05)] .01131 .48033 1 0 Mshowa
.02381 .58497 m
.03006 .58497 L
s
[(0.1)] .01131 .58497 1 0 Mshowa
.125 Mabswid
.02381 .0827 m
.02756 .0827 L
s
.02381 .10363 m
.02756 .10363 L
s
.02381 .12456 m
.02756 .12456 L
s
.02381 .14548 m
.02756 .14548 L
s
.02381 .18734 m
.02756 .18734 L
s
.02381 .20827 m
.02756 .20827 L
s
.02381 .2292 m
.02756 .2292 L
s
.02381 .25012 m
.02756 .25012 L
s
.02381 .29198 m
.02756 .29198 L
s
.02381 .31291 m
.02756 .31291 L
s
.02381 .33383 m
.02756 .33383 L
s
.02381 .35476 m
.02756 .35476 L
s
.02381 .39662 m
.02756 .39662 L
s
.02381 .41755 m
.02756 .41755 L
s
.02381 .43847 m
.02756 .43847 L
s
.02381 .4594 m
.02756 .4594 L
s
.02381 .50126 m
.02756 .50126 L
s
.02381 .52219 m
.02756 .52219 L
s
.02381 .54311 m
.02756 .54311 L
s
.02381 .56404 m
.02756 .56404 L
s
.02381 .04085 m
.02756 .04085 L
s
.02381 .01992 m
.02756 .01992 L
s
.02381 .6059 m
.02756 .6059 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 0 r
.5 Mabswid
.02381 .58497 m
.04262 .2678 L
.04754 .17658 L
.0522 .10798 L
.05477 .07827 L
.05756 .05273 L
.05879 .04364 L
.0601 .03543 L
.06133 .02904 L
.06244 .02427 L
.06368 .02017 L
.06431 .01852 L
.065 .01707 L
.06623 .01535 L
.0674 .01472 L
.06812 .01479 L
.06877 .01515 L
.06952 .01591 L
.07023 .01696 L
.07149 .01957 L
.07286 .02342 L
.07531 .03285 L
.07791 .04593 L
.08255 .07594 L
.10458 .27114 L
.11478 .36053 L
.12444 .43379 L
.13385 .49214 L
.14255 .53437 L
.1519 .56761 L
.15683 .58041 L
.15934 .58577 L
.16206 .59068 L
.16474 .59468 L
.16719 .59764 L
.16953 .59986 L
.172 .60159 L
.17332 .60226 L
.17404 .60255 L
.17472 .60279 L
.17535 .60297 L
.17604 .60312 L
.17724 .60328 L
.17793 .60332 L
.17869 .60331 L
.17948 .60324 L
.18023 .60314 L
.18092 .60299 L
.18155 .60283 L
.18298 .60234 L
Mistroke
.18427 .60176 L
.18548 .60109 L
.18776 .59956 L
.19285 .59487 L
.19725 .58955 L
.202 .58267 L
.22274 .54334 L
.24232 .50043 L
.26379 .45581 L
.28449 .42036 L
.30333 .39688 L
.31338 .38805 L
.32288 .38197 L
.32809 .37952 L
.33291 .37778 L
.3382 .37639 L
.34087 .37588 L
.34239 .37565 L
.34381 .37546 L
.34617 .37523 L
.34741 .37514 L
.34874 .37507 L
.34941 .37504 L
.35014 .37502 L
.35146 .375 L
.35274 .375 L
.35393 .37502 L
.35504 .37506 L
.35607 .3751 L
.35721 .37516 L
.35843 .37524 L
.36092 .37545 L
.36319 .3757 L
.37391 .37732 L
.38406 .37927 L
.39282 .38099 L
.40226 .38264 L
.40766 .38342 L
.41262 .38398 L
.41736 .38438 L
.41975 .38453 L
.42109 .38459 L
.42236 .38464 L
.4236 .38468 L
.42426 .3847 L
.42495 .38471 L
.42617 .38473 L
.4273 .38473 L
.4286 .38472 L
.42982 .38471 L
Mistroke
.43052 .3847 L
.43115 .38468 L
.43259 .38463 L
.43492 .38453 L
.43747 .38437 L
.44211 .38398 L
.44738 .38336 L
.453 .38252 L
.46311 .38064 L
.4831 .376 L
.50471 .37094 L
.51487 .36899 L
.52042 .3681 L
.5256 .3674 L
.53039 .36688 L
.53475 .3665 L
.53708 .36634 L
.5396 .3662 L
.54099 .36614 L
.54227 .36609 L
.5435 .36605 L
.5448 .36602 L
.54596 .36599 L
.54722 .36598 L
.54837 .36597 L
.54944 .36597 L
.5507 .36598 L
.55185 .36599 L
.55249 .366 L
.55318 .36602 L
.55444 .36605 L
.55672 .36612 L
.55914 .36623 L
.56348 .36649 L
.56855 .36689 L
.57329 .36736 L
.58409 .36869 L
.62293 .37471 L
.63307 .37611 L
.64412 .37737 L
.64918 .37783 L
.65456 .37825 L
.65926 .37854 L
.66423 .37878 L
.66679 .37887 L
.66961 .37895 L
.67084 .37898 L
.67216 .37901 L
.6734 .37902 L
.67455 .37904 L
Mistroke
.67523 .37905 L
.67599 .37905 L
.67674 .37906 L
.67755 .37906 L
.67825 .37906 L
.67901 .37906 L
.67973 .37906 L
.68038 .37905 L
.68168 .37905 L
.68242 .37904 L
.68311 .37903 L
.68569 .37899 L
.68833 .37894 L
.69082 .37887 L
.69546 .37871 L
.70588 .37822 L
.74442 .37568 L
.75472 .37508 L
.76435 .37462 L
.7696 .37442 L
.77439 .37427 L
.77971 .37414 L
.78263 .37409 L
.78541 .37405 L
.78655 .37404 L
.78777 .37403 L
.78883 .37402 L
.78999 .37401 L
.79128 .37401 L
.79198 .374 L
.79264 .374 L
.79381 .374 L
.79506 .374 L
.79575 .374 L
.79638 .374 L
.79708 .37401 L
.79782 .37401 L
.79906 .37402 L
.80043 .37403 L
.80295 .37405 L
.80531 .37408 L
.80995 .37415 L
.81419 .37424 L
.82373 .3745 L
.84435 .37521 L
.86348 .37589 L
.87301 .37618 L
.88199 .3764 L
.88696 .3765 L
.89234 .37658 L
Mistroke
.89722 .37664 L
.89953 .37667 L
.90171 .37668 L
.90289 .37669 L
.90417 .3767 L
.90524 .3767 L
.90642 .37671 L
.90769 .37671 L
.90839 .37671 L
.90904 .37671 L
.91021 .37672 L
.91146 .37672 L
.91257 .37672 L
.91378 .37671 L
.91504 .37671 L
.91621 .37671 L
.91832 .3767 L
.92056 .37668 L
.92614 .37664 L
.9314 .37658 L
.94124 .37644 L
.97619 .37575 L
Mfstroke
1 0 0 r
.02381 .58497 m
.02499 .58242 L
.02605 .5761 L
.02729 .56484 L
.02846 .55093 L
.03279 .48083 L
.04262 .29413 L
.04723 .2205 L
.05212 .16037 L
.05468 .13677 L
.05749 .11683 L
.05872 .11003 L
.06005 .10397 L
.06131 .09939 L
.06244 .09619 L
.06309 .09475 L
.0638 .0935 L
.06454 .09252 L
.06524 .09192 L
.0659 .09161 L
.06659 .09157 L
.06784 .09217 L
.06854 .09287 L
.06929 .09391 L
.07064 .0965 L
.07226 .10069 L
.07373 .1055 L
.07923 .13056 L
.08445 .16221 L
.10458 .3135 L
.1228 .4393 L
.13317 .49419 L
.13825 .51589 L
.14291 .53275 L
.14745 .54643 L
.15243 .55835 L
.15742 .56724 L
.16015 .57084 L
.16268 .57344 L
.164 .5745 L
.16542 .57545 L
.16677 .57615 L
.16801 .57663 L
.16912 .57693 L
.17035 .57712 L
.17164 .57716 L
.17284 .57706 L
.17351 .57695 L
.17424 .57677 L
.17557 .57634 L
Mistroke
.17687 .57577 L
.17807 .57512 L
.18079 .57321 L
.18369 .57056 L
.18907 .56412 L
.194 .55667 L
.20514 .53578 L
.22533 .49064 L
.24579 .44657 L
.25577 .42861 L
.26487 .41505 L
.2743 .40403 L
.28323 .39648 L
.28813 .39347 L
.29265 .39136 L
.29502 .39051 L
.29762 .38974 L
.29893 .38943 L
.30034 .38914 L
.30168 .38892 L
.30289 .38875 L
.30413 .38861 L
.3053 .38852 L
.30653 .38845 L
.30722 .38843 L
.30786 .38842 L
.30893 .38842 L
.31011 .38844 L
.31134 .3885 L
.31249 .38857 L
.31384 .38869 L
.31513 .38884 L
.31754 .38917 L
.32297 .39022 L
.33308 .39295 L
.34408 .39638 L
.35426 .39936 L
.35925 .40059 L
.36383 .40153 L
.36863 .40228 L
.37115 .40257 L
.37381 .4028 L
.37513 .40288 L
.37585 .40291 L
.37653 .40294 L
.37717 .40296 L
.37786 .40298 L
.37907 .40299 L
.37976 .40299 L
.38053 .40298 L
Mistroke
.38132 .40296 L
.38207 .40294 L
.38276 .40291 L
.3834 .40288 L
.38483 .40279 L
.38733 .40257 L
.3896 .4023 L
.39469 .40146 L
.3994 .40039 L
.40383 .39914 L
.41379 .39557 L
.42456 .39077 L
.44412 .38072 L
.46558 .37012 L
.47545 .36614 L
.48088 .36429 L
.48602 .3628 L
.4908 .36164 L
.496 .36064 L
.49829 .36029 L
.50072 .35998 L
.50281 .35976 L
.50509 .35957 L
.50624 .35949 L
.50748 .35942 L
.50878 .35937 L
.50999 .35933 L
.51119 .35931 L
.51234 .35931 L
.51336 .35931 L
.51447 .35933 L
.51569 .35936 L
.51638 .35938 L
.51703 .35941 L
.51973 .35955 L
.52207 .35973 L
.52458 .35998 L
.52948 .36059 L
.53413 .36134 L
.54286 .3631 L
.58113 .37327 L
.60085 .37778 L
.60653 .37877 L
.61187 .37956 L
.61663 .38014 L
.62184 .38063 L
.62429 .38082 L
.62692 .38098 L
.62939 .3811 L
.63164 .38118 L
Mistroke
.63297 .38122 L
.63419 .38124 L
.63488 .38126 L
.63553 .38126 L
.63621 .38127 L
.63695 .38128 L
.63822 .38128 L
.63937 .38128 L
.64001 .38127 L
.64071 .38126 L
.64198 .38124 L
.64323 .38122 L
.64441 .38119 L
.64662 .38112 L
.64899 .38102 L
.65156 .38088 L
.66047 .38025 L
.66997 .37933 L
.6804 .37815 L
.70146 .37563 L
.71147 .37456 L
.72096 .37372 L
.7262 .37334 L
.73189 .37301 L
.73708 .37277 L
.73958 .37269 L
.74187 .37262 L
.74412 .37257 L
.7465 .37253 L
.74773 .37251 L
.74888 .3725 L
.75014 .37249 L
.75085 .37249 L
.75149 .37249 L
.75265 .37248 L
.75372 .37249 L
.75489 .37249 L
.75614 .3725 L
.75722 .37251 L
.75823 .37253 L
.76053 .37256 L
.76319 .37262 L
.76571 .37269 L
.77045 .37285 L
.78112 .37335 L
.81936 .37582 L
.82951 .37641 L
.83906 .37688 L
.84435 .37709 L
.85007 .37727 L
Mistroke
.85527 .3774 L
.85777 .37745 L
.86004 .37748 L
.86246 .37752 L
.86475 .37754 L
.86601 .37755 L
.86717 .37755 L
.86844 .37756 L
.86909 .37756 L
.8698 .37756 L
.87098 .37756 L
.87206 .37756 L
.87324 .37755 L
.87449 .37755 L
.87558 .37754 L
.8766 .37754 L
.8789 .37752 L
.88159 .37748 L
.88414 .37745 L
.8889 .37736 L
.89957 .37709 L
.91828 .37645 L
.93808 .37572 L
.95623 .37518 L
.96121 .37506 L
.96655 .37496 L
.97619 .37482 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 41.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000:B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00[@3oool4000000P0oooo0`00
00050?ooo`<00000203oool200000580oooo002]0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo00000540oooo
002^0?ooo`030000003oool0oooo00H0oooo1@0000050?ooo`040000003oool0oooo000000H0oooo
00@000000?ooo`3oool00000D@3oool00:l0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000060?ooo`<00000203oool200000580oooo002]0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
0540oooo002^0?ooo`8000002@3oool2000000L0oooo0`0000070?ooo`800000DP3oool001`0oooo
1@0000240?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;03oool2000000@0oooo
0P0000030?ooo`D000000P3oool2000002d0oooo000N0?ooo`050000003oool0oooo0?ooo`3o0000
PP3oool00`000000oooo0?ooo`060?ooo`<0o`000P0000030?ooo`80o`009P3oool010000000oooo
0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000020000
02P0oooo000N0?ooo`050000003oool0oooo0?ooo`3o0000?`3oool2000000@0oooo0P0000030?oo
o`D00000<P3oool900000080o`000P00000M0?l000030000003oool0oooo00d0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000800000:03oool0
01H0oooo100000040?ooo`050000003oool0oooo0?ooo`3o0000?P3oool010000000oooo0?ooo`00
000:0?ooo`060000003oool0oooo0000003oool0o`00<03oool00`000000oooo0?ooo`050?ooo`03
0?l0003oool0oooo02P0oooo100000020?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00P3oool200000080oooo00<000000?l000000000:03oool00140oooo0P0000040?ooo`80
0000103oool2000000<0oooo00<0o`000000003oool0<@3oool2000000@0oooo0P0000030?ooo`@0
0000103oool00`000000oooo0?ooo`020?ooo`8000000P3oool010000000o`000?l0003oool40000
00<0oooo0`000000103oool000000000000000040?ooo`8000002P3oool2000000@0oooo0P000003
0?ooo`@000000P3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo02l0oooo00@00000
0?ooo`3oool000000`3oool2000000@0oooo0P0000030?ooo`H000000P3o00020?ooo`@000001@3o
ool3000000<0oooo0`0000050?ooo`8000003@3oool00100oooo00@000000?ooo`3oool00000203o
ool400000080oooo00<000000?l0003oool0<03oool010000000oooo0?ooo`0000020?ooo`@00000
0P3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0?ooo`000000oooo0P000000
1P3oool000000?l0003o0000oooo000000L0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0<03oool2
000000<0oooo00@000000?ooo`3oool000000`3oool2000000@0oooo0`000000103oool000000?l0
003o00020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`040000003oool0oooo000000`0oooo000@0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool00`000000o`000?ooo`0`0?ooo`040000003oool0
oooo000000<0oooo0P0000030?ooo`@000000`3oool2000000@0oooo0`0000001`3oool000000?l0
003oool0o`000?ooo`0000000`3oool5000000050?ooo`000000oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030?l000000000oooo03H0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`0000020?l000<0oooo00<000000?ooo`3oool00`3oool5000000<0
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00000<0?ooo`002P3oool40000
0080oooo00@000000?ooo`3oool000002@3oool2000000<0oooo00<000000?ooo`3o0000:P3oool4
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`@00000
0P3oool010000000oooo0?ooo`0000020?ooo`@0000000D0oooo0000003o000000000?l000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`0000040?ooo`8000002@3oool0
10000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`3o0000oooo
0?ooo`0`0?ooo`@000000P3oool4000000<0oooo0P0000040?ooo`8000000P3oool00`000000o`00
0?l000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000000D0
oooo0P00000=0?ooo`00403oool4000000<0oooo0P0000030?ooo`@000000P3oool00`000000oooo
0?l0000`0?ooo`@000000P3oool400000080oooo100000020?ooo`@000000`3oool3000000060?oo
o`000000o`000000003o000000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo
0300oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00P000000?ooo`00000000000?ooo`3o0000oooo0?l00080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000303oool00100oooo100000080?ooo`@000000P3oool010000000oooo0?l0
0000000_0?ooo`@000000P3oool010000000oooo0?ooo`0000020?ooo`@000000P3oool400000080
oooo100000001P3oool000000?l0003oool0o`000?ooo`800000103oool2000000<0oooo0`000003
0?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`@0000000<0oooo0000003oool0103oool0
0`3o0000oooo0?ooo`0`0?ooo`040000003oool0oooo000000<0oooo0P0000030?ooo`040000003o
ool0oooo000000<0oooo0`000000103oool0o`000?ooo`3o00030?ooo`8000001P3oool2000000D0
oooo0`0000040?ooo`8000003@3oool00100oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo0?l002l0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0P0000000`3oool0
00000?ooo`020?ooo`090000003oool000000?ooo`000000o`000?ooo`3o0000000000<0oooo00<0
o`000?ooo`3oool05P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000D0
oooo00<0o`000?ooo`3oool0:P3oool400000080oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`8000000P3oool00`3o0000oooo0?l0000X0?ooo`002P3oool40000
0080oooo00@000000?ooo`3oool00000203oool3000000<0oooo00@000000?ooo`3oool0o`00:@3o
ool400000080oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00@000000?ooo`3oool0
00000`3oool2000000@0oooo0`0000001P3oool0o`000000003oool0o`0000000080oooo0`3o000G
0?ooo`040000003oool0oooo000000P0oooo1@0000000`3oool000000?ooo`040?ooo`030?l0003o
ool0oooo0300oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`08
0000003oool0oooo0?ooo`3o0000oooo0?l00000000:0?ooo`80o`0000<000000?ooo`3oool0603o
ool00100oooo100000030?ooo`800000103oool4000000050?ooo`000000oooo0?ooo`3o0000;`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0?ooo`3oool0o`000080oooo00T0o`000000003oool0oooo0?l0
00000000o`000000003oool00`3o00000`000000oooo000000050?l000X0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0o`00
0000003oool0<P3oool2000000X0oooo0P0000040?ooo`@0000000<0o`000000003o00001@000002
0?l0008000000`3o00000`000000o`000?l0000<0?l000d0oooo000@0?ooo`@000002@3oool30000
0080oooo00@000000?ooo`3oool0o`000P3oool4000000L0oooo0`0000040?ooo`<000001P3oool2
00000140oooo0P0000040?ooo`800000103oool2000000<0oooo100000030?ooo`@0000000L0o`00
00000000000000000?l000000000o`0000<000000`3o0002000000@0o`000P0000030?l000T0oooo
100000030?ooo`8000000`3oool400000080oooo00<000000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0b0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool0103o0000oooo
0?ooo`3o00030?ooo`80o`0000@0oooo0?l0003o0000o`007P3oool00100oooo00@000000?ooo`3o
ool00000203oool5000000050?ooo`000000oooo0?ooo`3o00000P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`00000?0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool0103o000000000?l0
000000020?ooo`80o`005@3oool4000000P0oooo00@000000?ooo`00000000000P3oool00`000000
oooo0?ooo`020?ooo`030?l0003oool0oooo0340oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool0o`000P3oool01@3o0000oooo
0?ooo`3oool0o`0002<0oooo000:0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0?l000020?ooo`030000003oool0
oooo00D0oooo1@0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
3`3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool4000000<0oooo0P0000040?ooo`<0
000000<0oooo0000003oool00P3oool0103o000000000?l00000000I0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo0340oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0o`000080oooo00D0o`000?ooo`3oool0o`000000000S0?ooo`00403oool4000000<0
oooo0P0000030?ooo`@000000P3oool01P000000oooo0?ooo`3oool000000?l00080oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`<000001P3oool200000100oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`00000000000P3oool4000000030?ooo`000000oooo0080oooo00<0o`00
0?ooo`3o00006P3oool010000000oooo0?ooo`0000080?ooo`<000000`3oool01@000000oooo0?oo
o`3oool0o`0003@0oooo00@000000?ooo`3oool000000`3oool2000000<0oooo100000020?ooo`D0
000000P0o`000?ooo`3oool0o`000?ooo`3o0000oooo000002<0oooo000@0?ooo`@00000203oool0
10000000oooo0000000000020?ooo`030000003oool0oooo0080oooo00D0o`000000003oool0oooo
000000060?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000?0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000
oooo000000030?ooo`80o`006`3oool4000000<0oooo0P0000040?ooo`8000000`3oool01@000000
oooo0?ooo`3oool0o`0003@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`030?l0003oool0oooo00<0o`00
00<000000?ooo`3oool08P3oool00100oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?l0000000000000203oool2000000H0
oooo0`0000050?ooo`8000004@3oool2000000<0oooo00@000000?ooo`3oool000000`3oool20000
00<0oooo100000030?ooo`<0000000<0oooo0000003oool00`3oool00`3o0000oooo0?ooo`0I0?oo
o`@00000203oool400000080oooo00D000000?ooo`3oool0oooo0?l0000e0?ooo`8000000`3oool0
10000000oooo0?ooo`0000030?ooo`800000103oool3000000030?ooo`3o0000oooo0080oooo0P3o
000U0?ooo`002P3oool400000080oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?l0003oool0<03oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0?l0000j0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000000`3oool2000002D0oooo000@0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`04
0?ooo`030?l0003oool0oooo0300oooo0P00000:0?ooo`800000103oool300000280oooo00@00000
0?ooo`3oool000002@3oool2000000<0oooo00@000000?ooo`3oool0o`00>`3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo02/0oooo000A0?ooo`8000002P3oool2000000<0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`80o`000P0000020?ooo`800000
00@0oooo0?l0003o000000000P3oool01@3o000000000?ooo`3oool0o`0000800000C@3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0o`00
?03oool2000000X0oooo0P00000]0?ooo`008@3oool:000000040?l0000000000000000000<0o`00
00<000000?l0003o0000403o00000`000000oooo0?ooo`1<0?ooo`8000002@3oool5000000050?oo
o`000000oooo0?ooo`3o0000M`3oool00280oooo00<000000?ooo`3oool01`3oool40?l00740oooo
00P000000?ooo`3oool0oooo0000003oool000000?l007L0oooo000R0?ooo`030000003oool0oooo
07`0oooo00L000000?ooo`3oool0oooo0?l0003oool0o`0007P0oooo002Q0?ooo`040000003oool0
oooo0?ooo`<0o`00N03oool00:40oooo00D000000?ooo`3oool0oooo000000020?l007P0oooo002P
0?ooo`800000OP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {40.375, 0}} -> {-0.145559, -0.0143759, \
0.0149516, 0.0149516}, {{9.6875, 71.9375}, {39.375, 0.9375}} -> {-7.85082, \
-1.57013, 0.22993, 0.0498003}, {{78.125, 140.375}, {39.375, 0.9375}} -> \
{-39.8895, -0.258952, 0.348604, 0.011571}, {{146.563, 208.813}, {39.375, \
0.9375}} -> {-32.4393, -0.560663, 0.196486, 0.0466515}, {{215, 277.25}, \
{39.375, 0.9375}} -> {-67.9935, -0.343701, 0.277096, 0.0157626}}]
}, Open  ]],

Cell["\<\
We notice that the linear response (red) differs significantly from \
the nonlinear one.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["External Simulation of the Nonlinear Model", "Subsection"],

Cell[CellGroupData[{

Cell["Code for External Simulation of the Nonlinear Model", "Subsubsection"],

Cell["\<\
We first make an implementation of a state equation solver using \
the Runge-Kutta method\
\>", "Text"],

Cell[BoxData[
    \(RK[Integer\ n_, Real\ h_, Real\ t0_, Real[_]\ startv_, Integer\ dimen_, 
          Integer\ dimPlusOne_] \[Rule] 
        Real[n, dimPlusOne] := \n\t\t\tModule[{\n\t\t\t\t\tReal[dimen]\ {x, 
              k1, k2, k3, 
              k4}, \n\t\t\t\t\tInteger\ i, \n\t\t\t\t\tReal\ t, \n\t\t\t\t\t\
Real[n, dimPlusOne]\ res\ \n\t\t\t\t}, \n\t\t\t\tt = t0; \n\t\t\t\tx = 
          startv; \n\t\t\t\tres\[LeftDoubleBracket]1, 
            1\[RightDoubleBracket] = 
          t; \n\t\t\t\tres\[LeftDoubleBracket]1, 
            2 | dimPlusOne\[RightDoubleBracket] = x; \n\t\t\t\tFor[i = 1, \ 
          i \[LessEqual] n - 1, \ \(i++\), \n\t\t\t\t\tk1 = 
            h\ ClosedLoopPendulumEquationsRHS[
                x\[LeftDoubleBracket]1\[RightDoubleBracket], 
                x\[LeftDoubleBracket]2\[RightDoubleBracket], 
                x\[LeftDoubleBracket]3\[RightDoubleBracket], 
                x\[LeftDoubleBracket]4\[RightDoubleBracket], 
                x\[LeftDoubleBracket]5\[RightDoubleBracket], 
                x\[LeftDoubleBracket]6\[RightDoubleBracket], 
                x\[LeftDoubleBracket]7\[RightDoubleBracket], 
                x\[LeftDoubleBracket]8\[RightDoubleBracket]]; \n\t\t\t\t\tk2 \
= h\ ClosedLoopPendulumEquationsRHS[
                x\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]1\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]2\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]3\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]3\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]4\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]4\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]5\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]5\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]6\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]6\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]7\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]7\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]8\[RightDoubleBracket] + 
                  k1\[LeftDoubleBracket]8\[RightDoubleBracket]/
                    2]; \n\t\t\t\t\tk3 = 
            h\ ClosedLoopPendulumEquationsRHS[
                x\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]1\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]2\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]3\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]3\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]4\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]4\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]5\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]5\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]6\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]6\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]7\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]7\[RightDoubleBracket]/2, 
                x\[LeftDoubleBracket]8\[RightDoubleBracket] + 
                  k2\[LeftDoubleBracket]8\[RightDoubleBracket]/
                    2]; \n\t\t\t\t\tk4 = 
            h\ ClosedLoopPendulumEquationsRHS[\n\t\t\t\t\t\tx\
\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]1\[RightDoubleBracket], 
                x\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]2\[RightDoubleBracket], 
                x\[LeftDoubleBracket]3\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]3\[RightDoubleBracket], 
                x\[LeftDoubleBracket]4\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]4\[RightDoubleBracket], 
                x\[LeftDoubleBracket]5\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]5\[RightDoubleBracket], 
                x\[LeftDoubleBracket]6\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]6\[RightDoubleBracket], 
                x\[LeftDoubleBracket]7\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]7\[RightDoubleBracket], 
                x\[LeftDoubleBracket]8\[RightDoubleBracket] + 
                  k3\[LeftDoubleBracket]8\[RightDoubleBracket]]; \n\t\t\t\t\t\
x = x + 1/6\ \((k1 + 2\ k2 + 2  k3 + k4)\); \n\t\t\t\t\tt = 
            t + h; \n\t\t\t\t\tres\[LeftDoubleBracket]i + 1, 
              1\[RightDoubleBracket] = 
            t; \n\t\t\t\t\tres\[LeftDoubleBracket]i + 1, 
              2 | dimPlusOne\[RightDoubleBracket] = 
            x;\n\t\t\t\t]; \n\t\t\t\tres\n\t\t\t]\)], "Input"],

Cell["We use RK in the following ODE solver", "Text"],

Cell[BoxData[
    \(ndSolve[initvalue_, maxstepsize_, {x_, xmin_, xmax_}] := \n\t
      Module[{n, dimen}, \n\t\tn = \ 
          IntegerPart[\((xmax - xmin)\)/maxstepsize] + 1; \n\t\tdimen = 
          Length[initvalue]; \n\t\tres = 
          RK[n, maxstepsize, xmin, initvalue, dimen, 
            dimen + 1]; \n\t\tArray[\((Interpolation[
                AppendRows[
                  Transpose[{res\[LeftDoubleBracket]_, 
                        1\[RightDoubleBracket]}], \n\t\t\t\t\t\t\t\t\t\
Transpose[{res\[LeftDoubleBracket]_, # + 
                          1\[RightDoubleBracket]}]]])\) &, \ {8}]\n\t]\)], \
"Input"],

Cell["\<\
To get a correct estimate of the time spent by the external code \
for simulating the system we define the folowing function which repeats the \
external simulation n times.\
\>", "Text"],

Cell[BoxData[
    \(RKRepeated[Integer\ n_, Real\ h_, Real\ t0_, Real[_]\ startv_, 
          Integer\ dimen_, Integer\ dimPlusOne_, Integer\ loops_] \[Rule] 
        Real[n, dimPlusOne] := \n\t\ Module[{Real[n, 
              dimPlusOne]\ res}, \ \n\t\tDo[\t
          res\  = \ 
            RK[n, h, t0, startv, dimen, 
              dimPlusOne], {loops}]; \n\t\tres\n\t]\)], "Input"],

Cell[BoxData[
    \(ndSolveRepeated[\n\tinitvalue_, maxstepsize_, {x_, xmin_, xmax_}, 
        loops_] := \n\t
      Module[{n, dimen}, \n\t\tn = \ 
          IntegerPart[\((xmax - xmin)\)/maxstepsize] + 1; \n\t\tdimen = 
          Length[initvalue]; \n\t\tres = 
          RKRepeated[n, maxstepsize, xmin, initvalue, dimen, dimen + 1, \ 
            loops]; \n\t\tArray[\((Interpolation[
                AppendRows[
                  Transpose[{res\[LeftDoubleBracket]_, 
                        1\[RightDoubleBracket]}], \n\t\t\t\t\t\t\t\t\t\
Transpose[{res\[LeftDoubleBracket]_, # + 
                          1\[RightDoubleBracket]}]]])\) &, \ {8}]\n\t]\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compilation", "Subsubsection"],

Cell["\<\
We are now ready to compile the package. The rhs of the state \
equations are optimized using common subexpression elimination\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompilePackage[
      EvaluateFunctions \[Rule] {ClosedLoopPendulumEquationsRHS}]\)], "Input"],

Cell[BoxData[
    \("Successful compilation to Fortran90: 3 function(s)"\)], "Print"]
}, Open  ]],

Cell["The corresponding code", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FilePrint["\<Global.f90\>"]\)], "Input"],

Cell["\<\
! This file is automatically generated
! from a Mathematica package by MathCode F90.

#include \"Global.f90mac\"

module mc_Global

  use MathCodePrecision
  use MathCodeSheep
  implicit none

interface
! Declarations of external functions (if any)
include   'GlobalExt.f90inc'
end interface

contains

  subroutine GlobalInit()

    use MathCodePrecision
    use MathCodeSheep
    use mc_system
    implicit none
  end subroutine  GlobalInit

  function RK(n, h, t0, startv, dimen, dimPlusOne) result(mc_O1)

    use MathCodePrecision
    use MathCodeSheep
    use mc_system
    implicit none
    integer(mc_int), intent(in) :: n
    real(mc_real), intent(in) :: h
    real(mc_real), intent(in) :: t0
    real(mc_real), intent(in) :: startv(:)
    integer(mc_int), intent(in) :: dimen
    integer(mc_int), intent(in) :: dimPlusOne
    real(mc_real) mc_O1(dimPlusOne,n)
    real(mc_real) res(dimPlusOne,n)
    real(mc_real) t
    integer(mc_int) i
    real(mc_real) k4(dimen)
    real(mc_real) k3(dimen)
    real(mc_real) k2(dimen)
    real(mc_real) k1(dimen)
    real(mc_real) x(dimen)

    t = t0
    x = startv
    res(1, 1) = t
    res(2:dimPlusOne, 1) = x
    
    i = 1
    do while (i <= n+(-1))
      k1 = h* ClosedLoopPendulumEquationsRHS (x(1), x(2), x(3), x(4), x(5), \
x(6), x(7), x(8))
      k2 = h* ClosedLoopPendulumEquationsRHS (x(1)+k1(1)/2, x(2)+k1(2)/2, \
x(3)+k1(3)/2, x(4)+k1(4)/2, x(5)+k1(5)/2, x(6)+k1(6)/2, &
        &x(7)+k1(7)/2, x(8)+k1(8)/2)
      k3 = h* ClosedLoopPendulumEquationsRHS (x(1)+k2(1)/2, x(2)+k2(2)/2, \
x(3)+k2(3)/2, x(4)+k2(4)/2, x(5)+k2(5)/2, x(6)+k2(6)/2, &
        &x(7)+k2(7)/2, x(8)+k2(8)/2)
      k4 = h* ClosedLoopPendulumEquationsRHS (x(1)+k3(1), x(2)+k3(2), \
x(3)+k3(3), x(4)+k3(4), x(5)+k3(5), x(6)+k3(6), x(7)+k3(7), &
        &x(8)+k3(8))
      x = x+(k1+2*k2+2*k3+k4)/6
      t = t+h
      res(1, i+1) = t
      res(2:dimPlusOne, i+1) = x

      i = i+1

    end do
    mc_O1 = res
  end function  RK

  function RKRepeated(n, h, t0, startv, dimen, dimPlusOne, loops) \
result(mc_O1)

    use MathCodePrecision
    use MathCodeSheep
    use mc_system
    implicit none
    integer(mc_int), intent(in) :: n
    real(mc_real), intent(in) :: h
    real(mc_real), intent(in) :: t0
    real(mc_real), intent(in) :: startv(:)
    integer(mc_int), intent(in) :: dimen
    integer(mc_int), intent(in) :: dimPlusOne
    integer(mc_int), intent(in) :: loops
    real(mc_real) mc_O1(dimPlusOne,n)
    integer(mc_int) AD1
    real(mc_real) res(dimPlusOne,n)

    
    AD1 = 1
    do while (AD1 <= loops)
      res =  RK (n, h, t0, startv, dimen, dimPlusOne)

      AD1 = AD1+1

    end do
    mc_O1 = res
  end function  RKRepeated

  function ClosedLoopPendulumEquationsRHS(x1, theta, x2, alpha, dx1, dtheta, \
dx2, dalpha) result(mc_O1)

    use MathCodePrecision
    use MathCodeSheep
    use mc_system
    implicit none
    real(mc_real), intent(in) :: x1
    real(mc_real), intent(in) :: theta
    real(mc_real), intent(in) :: x2
    real(mc_real), intent(in) :: alpha
    real(mc_real), intent(in) :: dx1
    real(mc_real), intent(in) :: dtheta
    real(mc_real), intent(in) :: dx2
    real(mc_real), intent(in) :: dalpha
    real(mc_real) mc_O1(8)
    real(mc_real) mc_T1
    real(mc_real) mc_T2
    real(mc_real) mc_T3
    real(mc_real) mc_T4
    real(mc_real) mc_T5
    real(mc_real) mc_T6
    real(mc_real) mc_T7
    real(mc_real) mc_T8
    real(mc_real) mc_T9
    real(mc_real) mc_T10
    real(mc_real) mc_T11
    real(mc_real) mc_T12
    real(mc_real) mc_T13
    real(mc_real) mc_T14
    real(mc_real) mc_T15
    real(mc_real) mc_T16
    real(mc_real) mc_T17
    real(mc_real) mc_T18
    real(mc_real) mc_T19
    real(mc_real) mc_T20
    real(mc_real) mc_T21
    real(mc_real) mc_T22
    real(mc_real) mc_T23
    real(mc_real) mc_T24
    real(mc_real) mc_T25
    real(mc_real) mc_T26
    real(mc_real) mc_T27
    real(mc_real) mc_T28
    real(mc_real) mc_T29
    real(mc_real) mc_T30
    real(mc_real) mc_T31
    real(mc_real) mc_T32
    real(mc_real) mc_T33
    real(mc_real) mc_T34
    real(mc_real) mc_T35
    real(mc_real) mc_T36
    real(mc_real) mc_T37
    real(mc_real) mc_T38
    real(mc_real) mc_T39
    real(mc_real) mc_T40
    real(mc_real) mc_T41
    real(mc_real) mc_T42
    real(mc_real) mc_T43
    real(mc_real) mc_T44
    real(mc_real) mc_T45
    real(mc_real) mc_T46
    real(mc_real) mc_T47
    real(mc_real) mc_T48
    real(mc_real) mc_T49
    real(mc_real) mc_T50
    real(mc_real) mc_T51
    real(mc_real) mc_T52
    real(mc_real) mc_T53
    real(mc_real) mc_T54
    real(mc_real) mc_T55
    real(mc_real) mc_T56
    real(mc_real) mc_T57
    real(mc_real) mc_T58
    real(mc_real) mc_T59
    real(mc_real) mc_T60
    real(mc_real) mc_T61
    real(mc_real) mc_T62
    real(mc_real) mc_T63
    real(mc_real) mc_T64
    real(mc_real) mc_T65
    real(mc_real) mc_T66
    real(mc_real) mc_T67
    real(mc_real) mc_T68
    real(mc_real) mc_T69
    real(mc_real) mc_T70
    real(mc_real) mc_T71
    real(mc_real) mc_T72
    real(mc_real) mc_T73
    real(mc_real) mc_T74
    real(mc_real) mc_T75
    real(mc_real) mc_T76
    real(mc_real) mc_T77
    real(mc_real) mc_T78
    real(mc_real) mc_T79
    real(mc_real) mc_T80
    real(mc_real) mc_T81
    real(mc_real) mc_T82
    real(mc_real) mc_T83
    real(mc_real) mc_T84
    real(mc_real) mc_T85
    real(mc_real) mc_T86
    real(mc_real) mc_T87
    real(mc_real) mc_T88
    real(mc_real) mc_T89
    real(mc_real) mc_T90
    real(mc_real) mc_T91
    real(mc_real) mc_T92
    real(mc_real) mc_T93
    real(mc_real) mc_T94
    real(mc_real) mc_T95
    real(mc_real) mc_T96
    real(mc_real) mc_T97
    real(mc_real) mc_T98
    real(mc_real) mc_T99
    real(mc_real) mc_T100
    real(mc_real) mc_T101
    real(mc_real) mc_T102
    real(mc_real) mc_T103
    real(mc_real) mc_T104
    real(mc_real) mc_T105
    real(mc_real) mc_T106
    real(mc_real) mc_T107
    real(mc_real) mc_T108
    real(mc_real) mc_T109
    real(mc_real) mc_T110
    real(mc_real) mc_T111
    real(mc_real) mc_T112
    real(mc_real) mc_T113
    real(mc_real) mc_T114
    real(mc_real) mc_T115
    real(mc_real) mc_T116
    real(mc_real) mc_T117
    real(mc_real) mc_T118
    real(mc_real) mc_T119
    real(mc_real) mc_T120
    real(mc_real) mc_T121
    real(mc_real) mc_T122
    real(mc_real) mc_T123
    real(mc_real) mc_T124
    real(mc_real) mc_T125
    real(mc_real) mc_T126
    real(mc_real) mc_T127
    real(mc_real) mc_T128
    real(mc_real) mc_T129
    real(mc_real) mc_T130
    real(mc_real) mc_T131
    real(mc_real) mc_T132
    real(mc_real) mc_T133
    real(mc_real) mc_T134
    real(mc_real) mc_T135
    real(mc_real) mc_T136
    real(mc_real) mc_T137
    real(mc_real) mc_T138
    real(mc_real) mc_T139
    real(mc_real) mc_T140
    real(mc_real) mc_T141
    real(mc_real) mc_T142
    real(mc_real) mc_T143
    real(mc_real) mc_T144
    real(mc_real) mc_T145
    real(mc_real) mc_T146
    real(mc_real) mc_T147
    real(mc_real) mc_T148
    real(mc_real) mc_T149
    real(mc_real) mc_T150
    real(mc_real) mc_T151(8)

    mc_T1 = sin(alpha)
    mc_T2 = mc_T1**2
    mc_T3 = x2**2
    mc_T4 = 0.0391816D0*mc_T3*mc_T2
    mc_T5 = cos(alpha)
    mc_T6 = mc_T5**2
    mc_T7 = 0.0391816D0*mc_T3*mc_T6
    mc_T8 = x1**2
    mc_T9 = 0.049553199999999985D0*mc_T8*mc_T6
    mc_T10 = 0.09219200000000001D0*mc_T6
    mc_T11 = (-0.13321744D0)*mc_T3
    mc_T12 = (-0.16848087999999997D0)*mc_T8
    mc_T13 = -0.3134528D0+mc_T12+mc_T11+mc_T10+mc_T9+mc_T7+mc_T4
    mc_T14 = alpha+theta
    mc_T15 = sin(mc_T14)
    mc_T16 = 0.384371496D0*x2*mc_T1*mc_T15
    mc_T17 = 3.90108384D0*mc_T3*mc_T15
    mc_T18 = 4.93372368D0*mc_T8*mc_T15
    mc_T19 = 9.179020800000002D0*mc_T15
    mc_T20 = sin(theta)
    mc_T21 = (-0.384371496D0)*x2*mc_T5*mc_T1*mc_T20
    mc_T22 = (-2.271807648D0)*x2*mc_T1*mc_T20
    mc_T23 = 0.22383987119999996D0*mc_T6*mc_T20
    mc_T24 = (-3.9010838400000005D0)*mc_T3*mc_T5*mc_T20
    mc_T25 = (-4.93372368D0)*mc_T8*mc_T5*mc_T20
    mc_T26 = (-9.1790208D0)*mc_T5*mc_T20
    mc_T27 = (-0.7610555620799999D0)*mc_T20
    mc_T28 = dtheta**2
    mc_T29 = (-0.0038605399999999995D0)*mc_T28*x2*mc_T5*mc_T2
    mc_T30 = (-0.007721079999999999D0)*dalpha*dtheta*x2*mc_T5*mc_T2
    mc_T31 = dalpha**2
    mc_T32 = (-0.0038605399999999995D0)*mc_T31*x2*mc_T5*mc_T2
    mc_T33 = (-0.0783632D0)*dtheta*dx2*x2*mc_T2
    mc_T34 = (-0.004505884D0)*mc_T28*x2*mc_T2
    mc_T35 = cos(theta)
    mc_T36 = (-3.9010838400000005D0)*mc_T3*mc_T35*mc_T1
    mc_T37 = (-4.93372368D0)*x1*x2*mc_T35*mc_T1
    mc_T38 = 10.077528534522902D0*x2
    mc_T39 = 7.651828094119706D0*x1
    mc_T40 = 26.790811938533512D0*theta
    mc_T41 = 5.388408575784962D0*dx2
    mc_T42 = 1.6288942473520907D0*dx1
    mc_T43 = 8.778166989708991D0*dtheta
    mc_T44 = 4.549390017098657D0*dalpha
    mc_T45 = 27.725924950006533D0*alpha
    mc_T46 = mc_T45+mc_T44+mc_T43+mc_T42+mc_T41+mc_T40+mc_T39+mc_T38
    mc_T47 = (-0.05762D0)*x2*mc_T46*mc_T5*mc_T1
    mc_T48 = (-0.04955319999999999D0)*mc_T28*mc_T8*mc_T5*mc_T1
    mc_T49 = (-0.09910639999999998D0)*dalpha*dtheta*mc_T8*mc_T5*mc_T1
    mc_T50 = (-0.04955319999999999D0)*mc_T31*mc_T8*mc_T5*mc_T1
    mc_T51 = (-0.092192D0)*mc_T28*mc_T5*mc_T1
    mc_T52 = (-0.184384D0)*dalpha*dtheta*mc_T5*mc_T1
    mc_T53 = (-0.092192D0)*mc_T31*mc_T5*mc_T1
    mc_T54 = 0.067252D0*x2*mc_T46*mc_T1
    mc_T55 = (-21.367632436322573D0)*x2
    mc_T56 = (-26.792917634057044D0)*x1
    mc_T57 = (-52.94001757250692D0)*theta
    mc_T58 = (-6.5402793097390735D0)*dx2
    mc_T59 = (-7.239817088310017D0)*dx1
    mc_T60 = (-18.307498668068437D0)*dtheta
    mc_T61 = (-2.289195364739048D0)*dalpha
    mc_T62 = (-11.826075752237804D0)*alpha
    mc_T63 = mc_T62+mc_T61+mc_T60+mc_T59+mc_T58+mc_T57+mc_T56+mc_T55
    mc_T64 = 0.067252D0*mc_T63*x2*mc_T1
    mc_T65 = 1.0058559999999999D0*dtheta*dx1*x1*x2*mc_T1
    mc_T66 = 0.057836719999999994D0*mc_T28*x1*x2*mc_T1
    mc_T67 = (-1.0058559999999999D0)*dtheta*dx2*mc_T8*mc_T1
    mc_T68 = (-0.057836719999999994D0)*mc_T28*mc_T8*mc_T1
    mc_T69 = (-1.8713600000000001D0)*dtheta*dx2*mc_T1
    mc_T70 = (-0.10760320000000001D0)*mc_T28*mc_T1
    mc_T71 = 0.384371496D0*x2*mc_T6*mc_T35
    mc_T72 = 0.48611689199999997D0*x1*mc_T6*mc_T35
    mc_T73 = (-1.3068630864000002D0)*x2*mc_T35
    mc_T74 = (-1.6527974327999997D0)*x1*mc_T35
    mc_T75 = mc_T5**3
    mc_T76 = (-0.0038605399999999995D0)*mc_T28*x2*mc_T75
    mc_T77 = (-0.007721079999999999D0)*dalpha*dtheta*x2*mc_T75
    mc_T78 = (-0.0038605399999999995D0)*mc_T31*x2*mc_T75
    mc_T79 = (-0.006626299999999999D0)*mc_T46*mc_T6
    mc_T80 = (-0.0783632D0)*dtheta*dx2*x2*mc_T6
    mc_T81 = (-0.004505884D0)*mc_T28*x2*mc_T6
    mc_T82 = (-0.006626299999999999D0)*mc_T63*mc_T6
    mc_T83 = (-0.09910639999999998D0)*dtheta*dx1*x1*mc_T6
    mc_T84 = (-0.005698617999999998D0)*mc_T28*x1*mc_T6
    mc_T85 = (-0.5848D0)*mc_T3*mc_T46*mc_T5
    mc_T86 = (-0.7395999999999999D0)*mc_T8*mc_T46*mc_T5
    mc_T87 = (-1.3760000000000001D0)*mc_T46*mc_T5
    mc_T88 = 0.013125835999999998D0*mc_T28*x2*mc_T5
    mc_T89 = 0.026251671999999993D0*dalpha*dtheta*x2*mc_T5
    mc_T90 = 0.013125835999999998D0*mc_T31*x2*mc_T5
    mc_T91 = 0.022529419999999994D0*mc_T46
    mc_T92 = 0.26643488D0*dtheta*dx2*x2
    mc_T93 = 0.015320005599999999D0*mc_T28*x2
    mc_T94 = 0.022529419999999994D0*mc_T63
    mc_T95 = 0.33696175999999994D0*dtheta*dx1*x1
    mc_T96 = 0.019375301199999997D0*mc_T28*x1
    mc_T97 = \
mc_T96+mc_T95+mc_T94+mc_T93+mc_T92+mc_T91+mc_T90+mc_T89+mc_T88+mc_T87+mc_T86+\
mc_T85+mc_T84+mc_T83+mc_T82+mc_T81+&
      &mc_T80+mc_T79+mc_T78+mc_T77+mc_T76+mc_T74+mc_T73+mc_T72+mc_T71+mc_T70+\
mc_T69+mc_T68+mc_T67+mc_T66+mc_T65+mc_T64+mc_T54+&
      &mc_T53+mc_T52+mc_T51+mc_T50+mc_T49+mc_T48+mc_T47+mc_T37+mc_T36+mc_T34+\
mc_T33+mc_T32+mc_T30+mc_T29+mc_T27+mc_T26+mc_T25+&
      &mc_T24+mc_T23+mc_T22+mc_T21+mc_T19+mc_T18+mc_T17+mc_T16
    mc_T98 = mc_T97/mc_T13
    mc_T99 = (-mc_T98)
    mc_T100 = 0.5848D0*x2*mc_T1
    mc_T101 = (-0.05762D0)*mc_T6
    mc_T102 = 0.19590799999999997D0+mc_T101+mc_T100
    mc_T103 = mc_T13*mc_T102
    mc_T104 = 0.19590799999999997D0+mc_T101
    mc_T105 = mc_T104*mc_T97
    mc_T106 = mc_T105/mc_T103
    mc_T107 = (-mc_T106)
    mc_T108 = (-5.736888D0)*mc_T15
    mc_T109 = 5.736888D0*mc_T5*mc_T20
    mc_T110 = 0.05761999999999999D0*mc_T28*mc_T5*mc_T1
    mc_T111 = 0.11524D0*dalpha*dtheta*mc_T5*mc_T1
    mc_T112 = 0.05761999999999999D0*mc_T31*mc_T5*mc_T1
    mc_T113 = 1.1696D0*dtheta*dx2*mc_T1
    mc_T114 = 0.067252D0*mc_T28*mc_T1
    mc_T115 = 0.86D0*mc_T46*mc_T5
    mc_T116 = mc_T115+mc_T114+mc_T113+mc_T112+mc_T111+mc_T110+mc_T109+mc_T108
    mc_T117 = mc_T116/mc_T102
    mc_T118 = mc_T117+mc_T107
    mc_T119 = x2*mc_T1
    mc_T120 = 0.115D0*mc_T5
    mc_T121 = 0.33499999999999996D0+mc_T120+mc_T119
    mc_T122 = 1/cos(alpha)
    mc_T123 = mc_T122*mc_T121*mc_T118
    mc_T124 = 0.33499999999999996D0*mc_T122*mc_T97
    mc_T125 = mc_T124/mc_T13
    mc_T126 = (-9.81D0)*mc_T15
    mc_T127 = 2*dtheta*dx2*mc_T1
    mc_T128 = 0.115D0*mc_T28*mc_T1
    mc_T129 = mc_T28*x2*mc_T5
    mc_T130 = (-mc_T129)
    mc_T131 = mc_T130+mc_T128+mc_T127+mc_T126
    mc_T132 = mc_T122*mc_T131
    mc_T133 = (-mc_T132)
    mc_T134 = mc_T133+mc_T125+mc_T123
    mc_T135 = (-mc_T117)
    mc_T136 = mc_T135+mc_T106
    mc_T137 = 0.115D0*mc_T118
    mc_T138 = (-8.4366D0)*mc_T20
    mc_T139 = 21.367632436322573D0*x2
    mc_T140 = (-0.86D0)*mc_T28*x1
    mc_T141 = 26.792917634057044D0*x1
    mc_T142 = 52.94001757250692D0*theta
    mc_T143 = 6.5402793097390735D0*dx2
    mc_T144 = 7.239817088310017D0*dx1
    mc_T145 = 18.307498668068437D0*dtheta
    mc_T146 = 2.289195364739048D0*dalpha
    mc_T147 = 11.826075752237804D0*alpha
    mc_T148 = \
mc_T147+mc_T146+mc_T145+mc_T144+mc_T143+mc_T142+mc_T141+mc_T140+mc_T139+mc_\
T138
    mc_T149 = (-1.1627906976744187D0)*mc_T148
    mc_T150 = mc_T149+mc_T137
    mc_T151 = \
mc_mkpc(dx1,mc_mkpc(dtheta,mc_mkpc(dx2,mc_mkpc(dalpha,mc_mkpc(mc_T150,mc_mkpc(\
mc_T136,mc_mkpc(mc_T134,mc_mkc(mc_T99)&
      &)))))))
    mc_O1 = mc_T151
  end function  ClosedLoopPendulumEquationsRHS



end module mc_Global\
\>", "Print"]
}, Open  ]],

Cell[TextData[{
  "All necessary files for building binaries are now generated. The \
MakeBinary command can build either a standalone application using the code \
specified by the option GenerateMainFileAndFunction or a ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " version which can be easily installed into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". We build the ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " version"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MakeBinary[];\)\)], "Input"],

Cell[BoxData[
    \(Compiler::"msg" \(\(:\)\(\ \)\) 
      "\!\(\"cl : Command line warning D4029 : optimization is not available \
in the standard edition compiler\\n\"\)"\)], "Message"]
}, Open  ]],

Cell["\<\
To use the generated code for the simulation we only have to \
install the code using the Install command.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["External Simulation", "Subsubsection"],

Cell["\<\
This function is a fix to be able to measure the time for external \
processes.\
\>", "Text"],

Cell[BoxData[
    \(SetAttributes[AbsTime, HoldFirst]; 
    AbsTime[x_] := 
      Module[{start, res}, \n\t\tstart = AbsoluteTime[]; 
        res = x; {\((AbsoluteTime[] - start)\)\ Second, res}];\)], "Input"],

Cell[TextData[{
  StyleBox["Uncompiled code (computations within ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dsolUncompiled = 
          ndSolve[{\(-1\), 0, 1, 0.1, 0, 0, 0, 0}, 0.01, {t, 0. , 10. }];\) // 
      Timing\), "\n", 
    \(\(ndSolveUncompiledTime = First[%];\)\)}], "Input"],

Cell[BoxData[
    \({9.891000000000002`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["We plot the result to verify the Runge-Kutta solver", "Text"],

Cell[BoxData[
    \(\(Map[
        Plot[#[t], {t, 0, 8}, PlotRange \[Rule] All, 
            DisplayFunction \[Rule] Identity] &, 
        Part[dsolUncompiled, Range[4]]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[%], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.575347 0.560632 [
[.2619 .56285 -3 -9 ]
[.2619 .56285 3 0 ]
[.5 .56285 -3 -9 ]
[.5 .56285 3 0 ]
[.7381 .56285 -3 -9 ]
[.7381 .56285 3 0 ]
[.97619 .56285 -3 -9 ]
[.97619 .56285 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .12684 -24 -4.5 ]
[.01131 .12684 0 4.5 ]
[.01131 .23897 -24 -4.5 ]
[.01131 .23897 0 4.5 ]
[.01131 .35109 -24 -4.5 ]
[.01131 .35109 0 4.5 ]
[.01131 .46322 -24 -4.5 ]
[.01131 .46322 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .57535 m
.2619 .5816 L
s
[(2)] .2619 .56285 0 1 Mshowa
.5 .57535 m
.5 .5816 L
s
[(4)] .5 .56285 0 1 Mshowa
.7381 .57535 m
.7381 .5816 L
s
[(6)] .7381 .56285 0 1 Mshowa
.97619 .57535 m
.97619 .5816 L
s
[(8)] .97619 .56285 0 1 Mshowa
.125 Mabswid
.08333 .57535 m
.08333 .5791 L
s
.14286 .57535 m
.14286 .5791 L
s
.20238 .57535 m
.20238 .5791 L
s
.32143 .57535 m
.32143 .5791 L
s
.38095 .57535 m
.38095 .5791 L
s
.44048 .57535 m
.44048 .5791 L
s
.55952 .57535 m
.55952 .5791 L
s
.61905 .57535 m
.61905 .5791 L
s
.67857 .57535 m
.67857 .5791 L
s
.79762 .57535 m
.79762 .5791 L
s
.85714 .57535 m
.85714 .5791 L
s
.91667 .57535 m
.91667 .5791 L
s
.25 Mabswid
0 .57535 m
1 .57535 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .12684 m
.03006 .12684 L
s
[(-0.8)] .01131 .12684 1 0 Mshowa
.02381 .23897 m
.03006 .23897 L
s
[(-0.6)] .01131 .23897 1 0 Mshowa
.02381 .35109 m
.03006 .35109 L
s
[(-0.4)] .01131 .35109 1 0 Mshowa
.02381 .46322 m
.03006 .46322 L
s
[(-0.2)] .01131 .46322 1 0 Mshowa
.125 Mabswid
.02381 .04275 m
.02756 .04275 L
s
.02381 .07078 m
.02756 .07078 L
s
.02381 .09881 m
.02756 .09881 L
s
.02381 .15487 m
.02756 .15487 L
s
.02381 .1829 m
.02756 .1829 L
s
.02381 .21094 m
.02756 .21094 L
s
.02381 .267 m
.02756 .267 L
s
.02381 .29503 m
.02756 .29503 L
s
.02381 .32306 m
.02756 .32306 L
s
.02381 .37913 m
.02756 .37913 L
s
.02381 .40716 m
.02756 .40716 L
s
.02381 .43519 m
.02756 .43519 L
s
.02381 .49125 m
.02756 .49125 L
s
.02381 .51928 m
.02756 .51928 L
s
.02381 .54732 m
.02756 .54732 L
s
.02381 .60338 m
.02756 .60338 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01485 L
.02605 .0152 L
.02729 .01585 L
.02846 .01669 L
.03053 .0187 L
.03279 .02155 L
.0379 .03019 L
.04262 .04032 L
.06244 .09673 L
.10458 .2473 L
.1249 .32174 L
.14393 .38525 L
.16333 .43908 L
.18177 .47799 L
.19145 .49378 L
.20201 .50791 L
.22054 .52671 L
.26118 .556 L
.30031 .58124 L
.3106 .58713 L
.32172 .59273 L
.33134 .59675 L
.33643 .59852 L
.34189 .60012 L
.34729 .60139 L
.35221 .60227 L
.35457 .6026 L
.35715 .60289 L
.35833 .60299 L
.35958 .60309 L
.36068 .60316 L
.36183 .60322 L
.36313 .60327 L
.36432 .6033 L
.3656 .60332 L
.36632 .60332 L
.367 .60332 L
.36823 .6033 L
.36934 .60327 L
.37063 .60321 L
.37185 .60315 L
.37461 .60295 L
.37715 .6027 L
.3829 .60191 L
.38757 .60106 L
.39259 .59995 L
.40166 .59753 L
.4223 .59064 L
.44205 .58361 L
Mistroke
.45248 .58021 L
.46358 .57706 L
.47441 .57459 L
.48421 .57291 L
.48895 .57229 L
.49407 .57177 L
.49642 .57158 L
.4989 .57141 L
.50103 .5713 L
.50334 .57119 L
.50467 .57115 L
.50589 .57111 L
.50707 .57108 L
.50831 .57106 L
.50942 .57105 L
.51047 .57104 L
.51161 .57104 L
.51284 .57105 L
.51408 .57106 L
.51478 .57107 L
.51543 .57108 L
.51675 .5711 L
.51815 .57114 L
.5207 .57122 L
.52302 .57132 L
.52755 .57155 L
.53246 .57188 L
.54136 .57261 L
.56089 .57452 L
.57123 .57552 L
.58233 .57646 L
.58781 .57684 L
.593 .57715 L
.59805 .57739 L
.60273 .57757 L
.60715 .57769 L
.60939 .57774 L
.61067 .57776 L
.61186 .57777 L
.61305 .57778 L
.61432 .57779 L
.61559 .5778 L
.61631 .5778 L
.61698 .5778 L
.61819 .5778 L
.6193 .5778 L
.62058 .57779 L
.62179 .57778 L
.62294 .57777 L
.62417 .57775 L
Mistroke
.62641 .57771 L
.63149 .5776 L
.63687 .57742 L
.64178 .57722 L
.66022 .57625 L
.68083 .57503 L
.69086 .57448 L
.69995 .57407 L
.70453 .57389 L
.70948 .57373 L
.71376 .57361 L
.71845 .57351 L
.72104 .57347 L
.72345 .57344 L
.72599 .57341 L
.72742 .5734 L
.72872 .5734 L
.72993 .57339 L
.73104 .57339 L
.73227 .57339 L
.73357 .57339 L
.7347 .57339 L
.73576 .57339 L
.73691 .5734 L
.73816 .57341 L
.74056 .57343 L
.74313 .57345 L
.74774 .57352 L
.75323 .57363 L
.75822 .57375 L
.77932 .57444 L
.80014 .5752 L
.80928 .5755 L
.81933 .57579 L
.82899 .576 L
.83363 .57608 L
.83803 .57614 L
.84041 .57617 L
.84301 .5762 L
.8454 .57622 L
.84757 .57623 L
.85014 .57624 L
.85156 .57625 L
.8522 .57625 L
.85288 .57625 L
.85412 .57625 L
.85525 .57626 L
.85647 .57626 L
.85717 .57625 L
.85781 .57625 L
Mistroke
.85908 .57625 L
.85972 .57625 L
.86043 .57625 L
.86284 .57624 L
.8642 .57623 L
.86566 .57622 L
.8683 .57621 L
.87348 .57616 L
.87822 .57611 L
.89679 .57582 L
.91737 .57545 L
.9274 .57528 L
.93649 .57515 L
.946 .57504 L
.95036 .57499 L
.95497 .57496 L
.95989 .57493 L
.96208 .57492 L
.96443 .57491 L
.96575 .5749 L
.96695 .5749 L
.96818 .5749 L
.96931 .5749 L
.97063 .57489 L
.97132 .57489 L
.97206 .57489 L
.9733 .57489 L
.97401 .57489 L
.97467 .57489 L
.97546 .57489 L
.97619 .57489 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.40199 5.69505 [
[.2619 .38949 -3 -9 ]
[.2619 .38949 3 0 ]
[.5 .38949 -3 -9 ]
[.5 .38949 3 0 ]
[.7381 .38949 -3 -9 ]
[.7381 .38949 3 0 ]
[.97619 .38949 -3 -9 ]
[.97619 .38949 3 0 ]
[.01131 .06029 -30 -4.5 ]
[.01131 .06029 0 4.5 ]
[.01131 .17419 -30 -4.5 ]
[.01131 .17419 0 4.5 ]
[.01131 .28809 -30 -4.5 ]
[.01131 .28809 0 4.5 ]
[.01131 .51589 -24 -4.5 ]
[.01131 .51589 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .40199 m
.2619 .40824 L
s
[(2)] .2619 .38949 0 1 Mshowa
.5 .40199 m
.5 .40824 L
s
[(4)] .5 .38949 0 1 Mshowa
.7381 .40199 m
.7381 .40824 L
s
[(6)] .7381 .38949 0 1 Mshowa
.97619 .40199 m
.97619 .40824 L
s
[(8)] .97619 .38949 0 1 Mshowa
.125 Mabswid
.08333 .40199 m
.08333 .40574 L
s
.14286 .40199 m
.14286 .40574 L
s
.20238 .40199 m
.20238 .40574 L
s
.32143 .40199 m
.32143 .40574 L
s
.38095 .40199 m
.38095 .40574 L
s
.44048 .40199 m
.44048 .40574 L
s
.55952 .40199 m
.55952 .40574 L
s
.61905 .40199 m
.61905 .40574 L
s
.67857 .40199 m
.67857 .40574 L
s
.79762 .40199 m
.79762 .40574 L
s
.85714 .40199 m
.85714 .40574 L
s
.91667 .40199 m
.91667 .40574 L
s
.25 Mabswid
0 .40199 m
1 .40199 L
s
.02381 .06029 m
.03006 .06029 L
s
[(-0.06)] .01131 .06029 1 0 Mshowa
.02381 .17419 m
.03006 .17419 L
s
[(-0.04)] .01131 .17419 1 0 Mshowa
.02381 .28809 m
.03006 .28809 L
s
[(-0.02)] .01131 .28809 1 0 Mshowa
.02381 .51589 m
.03006 .51589 L
s
[(0.02)] .01131 .51589 1 0 Mshowa
.125 Mabswid
.02381 .08876 m
.02756 .08876 L
s
.02381 .11724 m
.02756 .11724 L
s
.02381 .14571 m
.02756 .14571 L
s
.02381 .20266 m
.02756 .20266 L
s
.02381 .23114 m
.02756 .23114 L
s
.02381 .25961 m
.02756 .25961 L
s
.02381 .31656 m
.02756 .31656 L
s
.02381 .34504 m
.02756 .34504 L
s
.02381 .37352 m
.02756 .37352 L
s
.02381 .43047 m
.02756 .43047 L
s
.02381 .45894 m
.02756 .45894 L
s
.02381 .48742 m
.02756 .48742 L
s
.02381 .03181 m
.02756 .03181 L
s
.02381 .00334 m
.02756 .00334 L
s
.02381 .54437 m
.02756 .54437 L
s
.02381 .57284 m
.02756 .57284 L
s
.02381 .60132 m
.02756 .60132 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .40199 m
.06244 .24068 L
.08255 .13088 L
.0932 .08404 L
.09905 .06273 L
.10458 .04584 L
.10972 .0332 L
.11243 .02779 L
.11531 .02304 L
.11772 .01986 L
.119 .01847 L
.12038 .01722 L
.12164 .01629 L
.1228 .01562 L
.12396 .01514 L
.12507 .01485 L
.12627 .01472 L
.12736 .01477 L
.12861 .01503 L
.1298 .01548 L
.1309 .01607 L
.13191 .01677 L
.13419 .01886 L
.1365 .02172 L
.13903 .02573 L
.14415 .03656 L
.14939 .05142 L
.15436 .06888 L
.16366 .10985 L
.18458 .2323 L
.2028 .35435 L
.22291 .47767 L
.23242 .52456 L
.24268 .56372 L
.24833 .57973 L
.25081 .58544 L
.25352 .59078 L
.25591 .5947 L
.25847 .59808 L
.25989 .59958 L
.26117 .60073 L
.26247 .60167 L
.26369 .60236 L
.2648 .60283 L
.266 .60316 L
.26668 .60327 L
.26732 .60332 L
.26854 .60328 L
.26981 .60305 L
.27099 .60266 L
Mistroke
.27229 .60205 L
.27367 .60119 L
.27616 .59909 L
.2785 .5965 L
.28287 .59015 L
.28808 .58019 L
.29287 .56899 L
.30367 .53792 L
.32413 .46671 L
.34321 .40137 L
.35265 .37404 L
.36157 .35277 L
.36651 .34319 L
.37186 .33463 L
.37673 .32857 L
.38123 .32443 L
.38366 .32278 L
.38588 .32161 L
.38715 .32109 L
.38832 .3207 L
.38955 .3204 L
.39019 .32027 L
.39089 .32017 L
.39206 .32007 L
.39333 .32005 L
.39453 .32013 L
.39563 .32028 L
.39663 .32047 L
.39772 .32076 L
.39994 .32154 L
.40262 .32286 L
.40508 .32441 L
.41059 .32896 L
.42055 .34042 L
.44122 .3725 L
.46036 .40377 L
.46993 .41733 L
.47893 .42792 L
.4883 .43628 L
.49329 .43952 L
.49588 .44086 L
.49866 .44205 L
.50125 .44291 L
.50361 .4435 L
.50475 .44371 L
.50598 .4439 L
.50714 .44403 L
.50822 .4441 L
.50947 .44415 L
.51064 .44415 L
Mistroke
.51192 .44409 L
.51264 .44404 L
.5133 .44398 L
.51462 .44381 L
.51606 .44357 L
.51868 .44298 L
.52146 .44214 L
.52398 .4412 L
.52962 .43853 L
.53977 .43203 L
.56065 .41459 L
.57986 .39813 L
.58956 .39104 L
.59862 .38565 L
.60356 .38327 L
.60806 .38149 L
.61307 .37994 L
.61582 .37929 L
.61843 .37879 L
.6208 .37845 L
.62188 .37833 L
.62302 .37823 L
.62429 .37814 L
.62546 .37808 L
.62672 .37805 L
.62743 .37804 L
.62809 .37804 L
.62873 .37805 L
.62943 .37806 L
.63069 .37811 L
.63192 .37819 L
.63305 .37828 L
.63563 .37856 L
.63835 .37897 L
.64289 .37988 L
.64713 .38099 L
.65678 .38427 L
.69562 .40214 L
.70576 .40635 L
.71681 .41009 L
.72187 .41144 L
.72725 .41262 L
.73232 .41346 L
.73692 .41401 L
.73925 .41421 L
.74059 .4143 L
.74181 .41437 L
.7431 .41442 L
.74377 .41445 L
.74449 .41447 L
Mistroke
.74577 .41449 L
.74698 .4145 L
.74809 .41449 L
.74931 .41448 L
.75058 .41445 L
.75178 .4144 L
.75392 .41429 L
.75622 .41414 L
.75888 .4139 L
.76179 .41358 L
.7671 .41285 L
.77706 .41103 L
.79836 .40594 L
.81769 .40121 L
.82736 .3992 L
.83783 .39745 L
.84263 .39683 L
.84771 .39629 L
.85205 .39594 L
.85452 .39578 L
.85681 .39566 L
.85931 .39557 L
.86064 .39553 L
.86204 .3955 L
.86326 .39548 L
.8644 .39547 L
.86565 .39546 L
.86636 .39546 L
.867 .39546 L
.86813 .39547 L
.86917 .39549 L
.87031 .39551 L
.87154 .39554 L
.87403 .39561 L
.87631 .39571 L
.88147 .396 L
.88706 .39643 L
.89722 .39744 L
.91669 .39991 L
.93812 .40265 L
.9476 .40366 L
.95283 .40413 L
.95779 .40452 L
.96239 .40482 L
.9674 .40508 L
.96961 .40518 L
.97196 .40526 L
.97619 .40538 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.049229 0.501446 [
[.2619 .03673 -3 -9 ]
[.2619 .03673 3 0 ]
[.5 .03673 -3 -9 ]
[.5 .03673 3 0 ]
[.7381 .03673 -3 -9 ]
[.7381 .03673 3 0 ]
[.97619 .03673 -3 -9 ]
[.97619 .03673 3 0 ]
[.01131 .14952 -18 -4.5 ]
[.01131 .14952 0 4.5 ]
[.01131 .24981 -18 -4.5 ]
[.01131 .24981 0 4.5 ]
[.01131 .3501 -18 -4.5 ]
[.01131 .3501 0 4.5 ]
[.01131 .45039 -18 -4.5 ]
[.01131 .45039 0 4.5 ]
[.01131 .55068 -6 -4.5 ]
[.01131 .55068 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .04923 m
.2619 .05548 L
s
[(2)] .2619 .03673 0 1 Mshowa
.5 .04923 m
.5 .05548 L
s
[(4)] .5 .03673 0 1 Mshowa
.7381 .04923 m
.7381 .05548 L
s
[(6)] .7381 .03673 0 1 Mshowa
.97619 .04923 m
.97619 .05548 L
s
[(8)] .97619 .03673 0 1 Mshowa
.125 Mabswid
.08333 .04923 m
.08333 .05298 L
s
.14286 .04923 m
.14286 .05298 L
s
.20238 .04923 m
.20238 .05298 L
s
.32143 .04923 m
.32143 .05298 L
s
.38095 .04923 m
.38095 .05298 L
s
.44048 .04923 m
.44048 .05298 L
s
.55952 .04923 m
.55952 .05298 L
s
.61905 .04923 m
.61905 .05298 L
s
.67857 .04923 m
.67857 .05298 L
s
.79762 .04923 m
.79762 .05298 L
s
.85714 .04923 m
.85714 .05298 L
s
.91667 .04923 m
.91667 .05298 L
s
.25 Mabswid
0 .04923 m
1 .04923 L
s
.02381 .14952 m
.03006 .14952 L
s
[(0.2)] .01131 .14952 1 0 Mshowa
.02381 .24981 m
.03006 .24981 L
s
[(0.4)] .01131 .24981 1 0 Mshowa
.02381 .3501 m
.03006 .3501 L
s
[(0.6)] .01131 .3501 1 0 Mshowa
.02381 .45039 m
.03006 .45039 L
s
[(0.8)] .01131 .45039 1 0 Mshowa
.02381 .55068 m
.03006 .55068 L
s
[(1)] .01131 .55068 1 0 Mshowa
.125 Mabswid
.02381 .0743 m
.02756 .0743 L
s
.02381 .09937 m
.02756 .09937 L
s
.02381 .12445 m
.02756 .12445 L
s
.02381 .17459 m
.02756 .17459 L
s
.02381 .19966 m
.02756 .19966 L
s
.02381 .22474 m
.02756 .22474 L
s
.02381 .27488 m
.02756 .27488 L
s
.02381 .29995 m
.02756 .29995 L
s
.02381 .32502 m
.02756 .32502 L
s
.02381 .37517 m
.02756 .37517 L
s
.02381 .40024 m
.02756 .40024 L
s
.02381 .42531 m
.02756 .42531 L
s
.02381 .47546 m
.02756 .47546 L
s
.02381 .50053 m
.02756 .50053 L
s
.02381 .5256 m
.02756 .5256 L
s
.02381 .02416 m
.02756 .02416 L
s
.02381 .57575 m
.02756 .57575 L
s
.02381 .60082 m
.02756 .60082 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .55068 m
.02499 .55092 L
.02605 .55153 L
.02729 .55265 L
.02846 .55405 L
.03279 .56137 L
.04262 .58246 L
.04723 .59118 L
.04976 .59512 L
.05212 .59817 L
.05468 .6007 L
.05603 .60171 L
.05673 .60213 L
.05749 .60252 L
.05818 .60281 L
.05882 .60302 L
.06008 .60327 L
.06122 .60332 L
.06244 .60318 L
.0631 .60302 L
.06383 .60277 L
.06459 .60245 L
.06529 .60207 L
.06791 .60013 L
.0694 .59863 L
.07076 .59702 L
.07382 .59259 L
.07933 .58197 L
.08454 .5691 L
.10458 .50116 L
.14291 .33765 L
.16229 .25676 L
.18369 .17748 L
.20418 .11524 L
.22296 .07162 L
.23238 .0547 L
.2423 .0404 L
.25227 .02951 L
.25791 .0248 L
.26316 .0213 L
.26821 .0187 L
.27087 .01761 L
.27368 .01666 L
.27615 .016 L
.27885 .01543 L
.28004 .01524 L
.28131 .01507 L
.28243 .01494 L
.28362 .01484 L
.28486 .01477 L
Mistroke
.286 .01473 L
.2867 .01472 L
.28737 .01472 L
.2886 .01473 L
.28979 .01478 L
.29087 .01484 L
.29207 .01493 L
.29333 .01505 L
.29552 .01533 L
.29756 .01565 L
.30221 .0166 L
.31268 .01965 L
.3226 .0233 L
.34117 .0308 L
.35942 .03739 L
.36981 .04031 L
.37489 .04147 L
.37955 .04238 L
.38411 .04311 L
.38909 .04375 L
.3941 .04423 L
.39683 .04443 L
.39936 .04457 L
.40068 .04462 L
.40211 .04467 L
.40345 .04471 L
.40469 .04474 L
.40581 .04476 L
.40705 .04477 L
.40833 .04477 L
.40953 .04477 L
.4102 .04477 L
.41094 .04476 L
.41163 .04475 L
.41227 .04474 L
.41477 .04469 L
.41606 .04465 L
.41749 .0446 L
.42038 .04448 L
.43046 .0439 L
.43971 .04322 L
.4505 .04241 L
.45577 .04205 L
.46055 .04177 L
.46493 .04155 L
.46969 .04137 L
.4723 .04129 L
.47345 .04126 L
.47471 .04124 L
.47582 .04122 L
Mistroke
.47701 .0412 L
.47827 .04119 L
.47945 .04119 L
.48012 .04118 L
.48083 .04118 L
.4821 .04119 L
.48289 .04119 L
.48362 .0412 L
.485 .04121 L
.48631 .04123 L
.48753 .04126 L
.49026 .04133 L
.49255 .04141 L
.49507 .04151 L
.50015 .04179 L
.51036 .04257 L
.51967 .04351 L
.54059 .04616 L
.5613 .04894 L
.57041 .05004 L
.58046 .05109 L
.59005 .05189 L
.59905 .05245 L
.60402 .05266 L
.60856 .05281 L
.61095 .05286 L
.61355 .05291 L
.61487 .05293 L
.61559 .05293 L
.61627 .05294 L
.61691 .05294 L
.6176 .05295 L
.6188 .05295 L
.62004 .05295 L
.62117 .05295 L
.62247 .05294 L
.6237 .05293 L
.62484 .05292 L
.62589 .0529 L
.62828 .05286 L
.63093 .05281 L
.63333 .05274 L
.6387 .05256 L
.64954 .05207 L
.65974 .05149 L
.67817 .05031 L
.68863 .04967 L
.69837 .04913 L
.70883 .04865 L
.71836 .04831 L
Mistroke
.72359 .04818 L
.72854 .04808 L
.73126 .04804 L
.73377 .04801 L
.73652 .04799 L
.73791 .04798 L
.73865 .04797 L
.73944 .04797 L
.74073 .04797 L
.74192 .04796 L
.74266 .04796 L
.74335 .04796 L
.74463 .04797 L
.74587 .04797 L
.74701 .04797 L
.74825 .04798 L
.74957 .04799 L
.75186 .04801 L
.75399 .04803 L
.75884 .04809 L
.76411 .04818 L
.76892 .04828 L
.77972 .04855 L
.8004 .04913 L
.8095 .04938 L
.81955 .04961 L
.82913 .04979 L
.83351 .04986 L
.83813 .04992 L
.84049 .04994 L
.84308 .04996 L
.84546 .04998 L
.84762 .04999 L
.85019 .05 L
.8516 .05001 L
.85225 .05001 L
.85293 .05001 L
.85416 .05001 L
.8553 .05001 L
.85652 .05001 L
.85722 .05001 L
.85787 .05001 L
.85912 .05001 L
.85982 .05001 L
.86045 .05001 L
.86284 .05 L
.86419 .05 L
.86564 .04999 L
.86827 .04998 L
.87341 .04994 L
Mistroke
.87815 .04989 L
.89668 .04964 L
.91713 .04931 L
.92711 .04916 L
.93621 .04903 L
.945 .04893 L
.95456 .04885 L
.95981 .04882 L
.96212 .04881 L
.96466 .0488 L
.96705 .04879 L
.9693 .04879 L
.97053 .04879 L
.97167 .04879 L
.97291 .04878 L
.97422 .04878 L
.97524 .04878 L
.97619 .04878 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.37569 2.09278 [
[.2619 .36319 -3 -9 ]
[.2619 .36319 3 0 ]
[.5 .36319 -3 -9 ]
[.5 .36319 3 0 ]
[.7381 .36319 -3 -9 ]
[.7381 .36319 3 0 ]
[.97619 .36319 -3 -9 ]
[.97619 .36319 3 0 ]
[.01131 .06177 -30 -4.5 ]
[.01131 .06177 0 4.5 ]
[.01131 .16641 -24 -4.5 ]
[.01131 .16641 0 4.5 ]
[.01131 .27105 -30 -4.5 ]
[.01131 .27105 0 4.5 ]
[.01131 .48033 -24 -4.5 ]
[.01131 .48033 0 4.5 ]
[.01131 .58497 -18 -4.5 ]
[.01131 .58497 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37569 m
.2619 .38194 L
s
[(2)] .2619 .36319 0 1 Mshowa
.5 .37569 m
.5 .38194 L
s
[(4)] .5 .36319 0 1 Mshowa
.7381 .37569 m
.7381 .38194 L
s
[(6)] .7381 .36319 0 1 Mshowa
.97619 .37569 m
.97619 .38194 L
s
[(8)] .97619 .36319 0 1 Mshowa
.125 Mabswid
.08333 .37569 m
.08333 .37944 L
s
.14286 .37569 m
.14286 .37944 L
s
.20238 .37569 m
.20238 .37944 L
s
.32143 .37569 m
.32143 .37944 L
s
.38095 .37569 m
.38095 .37944 L
s
.44048 .37569 m
.44048 .37944 L
s
.55952 .37569 m
.55952 .37944 L
s
.61905 .37569 m
.61905 .37944 L
s
.67857 .37569 m
.67857 .37944 L
s
.79762 .37569 m
.79762 .37944 L
s
.85714 .37569 m
.85714 .37944 L
s
.91667 .37569 m
.91667 .37944 L
s
.25 Mabswid
0 .37569 m
1 .37569 L
s
.02381 .06177 m
.03006 .06177 L
s
[(-0.15)] .01131 .06177 1 0 Mshowa
.02381 .16641 m
.03006 .16641 L
s
[(-0.1)] .01131 .16641 1 0 Mshowa
.02381 .27105 m
.03006 .27105 L
s
[(-0.05)] .01131 .27105 1 0 Mshowa
.02381 .48033 m
.03006 .48033 L
s
[(0.05)] .01131 .48033 1 0 Mshowa
.02381 .58497 m
.03006 .58497 L
s
[(0.1)] .01131 .58497 1 0 Mshowa
.125 Mabswid
.02381 .0827 m
.02756 .0827 L
s
.02381 .10363 m
.02756 .10363 L
s
.02381 .12456 m
.02756 .12456 L
s
.02381 .14548 m
.02756 .14548 L
s
.02381 .18734 m
.02756 .18734 L
s
.02381 .20827 m
.02756 .20827 L
s
.02381 .2292 m
.02756 .2292 L
s
.02381 .25012 m
.02756 .25012 L
s
.02381 .29198 m
.02756 .29198 L
s
.02381 .31291 m
.02756 .31291 L
s
.02381 .33383 m
.02756 .33383 L
s
.02381 .35476 m
.02756 .35476 L
s
.02381 .39662 m
.02756 .39662 L
s
.02381 .41755 m
.02756 .41755 L
s
.02381 .43847 m
.02756 .43847 L
s
.02381 .4594 m
.02756 .4594 L
s
.02381 .50126 m
.02756 .50126 L
s
.02381 .52219 m
.02756 .52219 L
s
.02381 .54311 m
.02756 .54311 L
s
.02381 .56404 m
.02756 .56404 L
s
.02381 .04085 m
.02756 .04085 L
s
.02381 .01992 m
.02756 .01992 L
s
.02381 .6059 m
.02756 .6059 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .58497 m
.04262 .2678 L
.04754 .17658 L
.0522 .10798 L
.05477 .07827 L
.05756 .05273 L
.05879 .04364 L
.0601 .03543 L
.06133 .02904 L
.06244 .02427 L
.06368 .02017 L
.06431 .01852 L
.065 .01707 L
.06623 .01535 L
.0674 .01472 L
.06812 .01479 L
.06877 .01515 L
.06952 .01591 L
.07023 .01696 L
.07149 .01957 L
.07286 .02342 L
.07531 .03285 L
.07791 .04593 L
.08255 .07594 L
.10458 .27114 L
.11478 .36053 L
.12444 .43379 L
.13385 .49214 L
.14255 .53437 L
.1519 .56761 L
.15683 .58041 L
.15934 .58577 L
.16206 .59068 L
.16474 .59468 L
.16719 .59764 L
.16953 .59986 L
.172 .60159 L
.17332 .60226 L
.17404 .60255 L
.17472 .60279 L
.17535 .60297 L
.17604 .60312 L
.17724 .60328 L
.17793 .60332 L
.17869 .60331 L
.17948 .60324 L
.18023 .60314 L
.18092 .60299 L
.18155 .60283 L
.18298 .60234 L
Mistroke
.18427 .60176 L
.18548 .60109 L
.18776 .59956 L
.19285 .59487 L
.19725 .58955 L
.202 .58267 L
.22274 .54334 L
.24232 .50043 L
.26379 .45581 L
.28449 .42036 L
.30333 .39688 L
.31338 .38805 L
.32288 .38197 L
.32809 .37952 L
.33291 .37778 L
.3382 .37639 L
.34087 .37588 L
.34239 .37565 L
.34381 .37546 L
.34617 .37523 L
.34741 .37514 L
.34874 .37507 L
.34941 .37504 L
.35014 .37502 L
.35146 .375 L
.35274 .375 L
.35393 .37502 L
.35504 .37506 L
.35607 .3751 L
.35721 .37516 L
.35843 .37524 L
.36092 .37545 L
.36319 .3757 L
.37391 .37732 L
.38406 .37927 L
.39282 .38099 L
.40226 .38264 L
.40766 .38342 L
.41262 .38398 L
.41736 .38438 L
.41975 .38453 L
.42109 .38459 L
.42236 .38464 L
.4236 .38468 L
.42426 .3847 L
.42495 .38471 L
.42617 .38473 L
.4273 .38473 L
.4286 .38472 L
.42982 .38471 L
Mistroke
.43052 .3847 L
.43115 .38468 L
.43259 .38463 L
.43492 .38453 L
.43747 .38437 L
.44211 .38398 L
.44738 .38336 L
.453 .38252 L
.46311 .38064 L
.4831 .376 L
.50471 .37094 L
.51487 .36899 L
.52042 .3681 L
.5256 .3674 L
.53039 .36688 L
.53475 .3665 L
.53708 .36634 L
.5396 .3662 L
.54099 .36614 L
.54227 .36609 L
.5435 .36605 L
.5448 .36602 L
.54596 .36599 L
.54722 .36598 L
.54837 .36597 L
.54944 .36597 L
.5507 .36598 L
.55185 .36599 L
.55249 .366 L
.55318 .36602 L
.55444 .36605 L
.55672 .36612 L
.55914 .36623 L
.56348 .36649 L
.56855 .36689 L
.57329 .36736 L
.58409 .36869 L
.62293 .37471 L
.63307 .37611 L
.64412 .37737 L
.64918 .37783 L
.65456 .37825 L
.65926 .37854 L
.66423 .37878 L
.66679 .37887 L
.66961 .37895 L
.67084 .37898 L
.67216 .37901 L
.6734 .37902 L
.67455 .37904 L
Mistroke
.67523 .37905 L
.67599 .37905 L
.67674 .37906 L
.67755 .37906 L
.67825 .37906 L
.67901 .37906 L
.67973 .37906 L
.68038 .37905 L
.68168 .37905 L
.68242 .37904 L
.68311 .37903 L
.68569 .37899 L
.68833 .37894 L
.69082 .37887 L
.69546 .37871 L
.70588 .37822 L
.74442 .37568 L
.75472 .37508 L
.76435 .37462 L
.7696 .37442 L
.77439 .37427 L
.77971 .37414 L
.78263 .37409 L
.78541 .37405 L
.78655 .37404 L
.78777 .37403 L
.78883 .37402 L
.78999 .37401 L
.79128 .37401 L
.79198 .374 L
.79264 .374 L
.79381 .374 L
.79506 .374 L
.79575 .374 L
.79638 .374 L
.79708 .37401 L
.79782 .37401 L
.79906 .37402 L
.80043 .37403 L
.80295 .37405 L
.80531 .37408 L
.80995 .37415 L
.81419 .37424 L
.82373 .3745 L
.84435 .37521 L
.86348 .37589 L
.87301 .37618 L
.88199 .3764 L
.88696 .3765 L
.89234 .37658 L
Mistroke
.89722 .37664 L
.89953 .37667 L
.90171 .37668 L
.90289 .37669 L
.90417 .3767 L
.90524 .3767 L
.90642 .37671 L
.90769 .37671 L
.90839 .37671 L
.90904 .37671 L
.91021 .37672 L
.91146 .37672 L
.91257 .37672 L
.91378 .37671 L
.91504 .37671 L
.91621 .37671 L
.91832 .3767 L
.92056 .37668 L
.92614 .37664 L
.9314 .37658 L
.94124 .37644 L
.97619 .37575 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 41.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000:B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00[@3oool4000000P0oooo0`00
00050?ooo`<00000203oool200000580oooo002]0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo00000540oooo
002^0?ooo`030000003oool0oooo00H0oooo1@0000050?ooo`040000003oool0oooo000000H0oooo
00@000000?ooo`3oool00000D@3oool00:l0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000060?ooo`<00000203oool200000580oooo002]0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
0540oooo002^0?ooo`8000002@3oool2000000L0oooo0`0000070?ooo`800000DP3oool001`0oooo
1@0000240?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;03oool2000000@0oooo
0P0000030?ooo`D000000P3oool2000002d0oooo000N0?ooo`050000003oool0oooo0?ooo`000000
<`3oool2000000@0oooo0P0000040?ooo`8000000`3oool3000003/0oooo00<000000?ooo`3oool0
1P3oool5000002/0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000P00000X0?ooo`007P3oool01@000000oooo0?ooo`3oool00000
0380oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000P3oool2000003<0oooo:`00000?0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool0103oool00`000000oooo00000002000002P0oooo000F0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000380oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`070000003oool0oooo0000003oool000000?ooo`03000003@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`@000000P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`<00000:03oool00140
oooo0P0000040?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:P3oool400000080
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`<000000P3oool0
1@000000oooo0000003oool0000002<0oooo0P0000040?ooo`8000000`3oool400000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`040000003oool0oooo000000<0oooo
0P0000040?ooo`8000000`3oool800000080oooo100000050?ooo`<000000`3oool3000000D0oooo
0P00000=0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`@000000P3oool200000340oooo
100000030?ooo`8000000`3oool4000000<0oooo1@0000000`3oool000000?ooo`05000000D0oooo
0`0000030?ooo`<000001@3oool2000000T0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool2000000<0
oooo00@000000?ooo`3oool000000`3oool2000000@0oooo0`000000103oool00000000000000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00030?ooo`040000003oool0oooo000000`0oooo000@0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool200000340oooo100000080?ooo`@000000`3oool300000005
0?ooo`000000oooo0000003oool00P0000090?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3o
ool00`3oool5000000<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00000<
0?ooo`002P3oool400000080oooo00@000000?ooo`3oool000002@3oool2000000<0oooo00<00000
0?ooo`000000<03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
1P0000001P3oool000000?ooo`000000oooo000000D0oooo1@0000030?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000:0?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0`0?ooo`@000000P3oool4000000<0
oooo0P0000040?ooo`8000000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`<000001@3oool2000000d0oooo000@0?ooo`@000000`3oool2000000<0
oooo100000020?ooo`030000003oool0000002X0oooo100000020?ooo`@000000`3oool2000000<0
oooo100000020?ooo`@0000000<0oooo0000000000000`3oool00`000000oooo000000040?ooo`04
0000003oool0oooo000000@0oooo0`0000050?ooo`8000002@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`080000003oool000000000003oool000000?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000`0oooo000@0?ooo`@00000203oool400000080oooo00@000000?ooo`3o
ool00000;`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P00
00000`3oool000000?ooo`02000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002@3oool2000000@0
oooo0P0000040?ooo`@0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0`0?ooo`04
0000003oool0oooo000000<0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo0`000000
103oool000000?ooo`0000030?ooo`8000001P3oool2000000D0oooo0`0000040?ooo`8000003@3o
ool00100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000002l0oooo100000080?ooo`@000000`3oool3000000030?ooo`000000000000<0
oooo0`0000060?ooo`8000001@3oool3000000@0oooo0P0000090?ooo`040000003oool0oooo0000
00/0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Z0?ooo`@000000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`030000
003oool0000002P0oooo000:0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`<00000
0`3oool010000000oooo0?ooo`00000Y0?ooo`@000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo00<0oooo0P00000J0?ooo`040000003oool0oooo000000P0oooo1@0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01P0oooo000@0?ooo`@000000`3oool2000000@0oooo100000001@3oool0
00000?ooo`3oool0000002l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`060000003oool0oooo0000003oool00000103oool00`000000oooo0?ooo`020?ooo`<0
00006P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`8000002P3oool2000000@0oooo8P00000=
0?ooo`00403oool4000000T0oooo0`0000020?ooo`040000003oool0oooo00000300oooo0P00000:
0?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo0`0000060?ooo`030000003oool0oooo00X0oooo1000
00030?ooo`8000000`3oool400000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0b0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0200oooo000@0?ooo`040000003oool0oooo000000P0oooo
1@0000001@3oool000000?ooo`3oool000000080oooo100000070?ooo`<00000103oool3000000H0
oooo0P00000V0?ooob000000203oool4000000P0oooo00@000000?ooo`00000000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool01@000000
oooo0?ooo`3oool0000002<0oooo000:0?ooo`@000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
0100oooo0P0000040?ooo`800000103oool2000000<0oooo100000000`3oool000000?ooo`040?oo
o`040000003oool0oooo000000@0oooo0`00000F0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo0000000S0?ooo`00403oool4000000<0oooo0P0000030?oo
o`@000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool5
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00000?0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000007@3oool010000000oooo0?ooo`00
00080?ooo`<000000`3oool01@000000oooo0?ooo`3oool0000003@0oooo00@000000?ooo`3oool0
00000`3oool2000000<0oooo100000020?ooo`H000000P3oool01@000000oooo0?ooo`3oool00000
02<0oooo000@0?ooo`@00000203oool010000000oooo0000000000020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000050?ooo`<000001P3o
ool200000100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0000000N0?ooo`@000000`3oool20000
00@0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000=03oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0R0?ooo`00403oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool20000
0080oooo00<000000?ooo`3oool0103oool00`000000oooo000000060?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0000000N0?ooo`@0
0000203oool400000080oooo00D000000?ooo`3oool0oooo0000000e0?ooo`8000000`3oool01000
0000oooo0?ooo`0000030?ooo`800000103oool3000000030?ooo`000000oooo0080oooo0P00000U
0?ooo`002P3oool400000080oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo0`0000080?ooo`8000001P3oool3000000D0oooo0P00000@0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
000000H0oooo0P00000N0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool0000003X0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`0000030?ooo`8000009@3oool00100oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P00000/0?ooo`8000002P3o
ool2000000@0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P00000N0?ooo`040000003o
ool0oooo000000T0oooo0P0000030?ooo`040000003oool0oooo000003/0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`0[0?ooo`004@3oool2000000X0oooo0P0000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0IP3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000?03oool2000000X0oooo0P00
000]0?ooo`008@3ooolU000004h0oooo0P0000090?ooo`D0000000D0oooo0000003oool0oooo0000
001g0?ooo`008P3oool00`000000oooo0?ooo`080?ooo`@00000L03oool01`000000oooo0?ooo`3o
ool000000?ooo`000000N03oool00280oooo00<000000?ooo`3oool0O03oool01`000000oooo0?oo
o`3oool000000?ooo`000000N03oool00:40oooo00@000000?ooo`3oool0oooo0`00001h0?ooo`00
X@3oool010000000oooo0?ooo`3oool3000007P0oooo002P0?ooo`800000OP3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {40.375, 0}} -> {-0.145559, -0.0143759, \
0.0149516, 0.0149516}, {{9.6875, 71.9375}, {39.375, 0.9375}} -> {-7.85082, \
-1.55896, 0.22993, 0.0488248}, {{78.125, 140.375}, {39.375, 0.9375}} -> \
{-30.066, -0.137114, 0.277096, 0.00579234}, {{146.563, 208.813}, {39.375, \
0.9375}} -> {-32.4393, -0.560572, 0.196486, 0.0466476}, {{215, 277.25}, \
{39.375, 0.9375}} -> {-67.9935, -0.343701, 0.277096, 0.0157626}}]
}, Open  ]],

Cell[TextData[StyleBox["Compiled code (external computations)",
  FontWeight->"Bold"]], "Text"],

Cell["We install the executable code", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(InstallCode[];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Global"\[InvisibleSpace]" is installed."\),
      SequenceForm[ "Global", " is installed."],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
The external simulation is performed 600 times to get a accurate \
measure of its timing\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dsolCompiled = 
          ndSolveRepeated[{\(-1\), 0, 1, 0.1, 0, 0, 0, 0}, 
            0.01, {t, 0. , 10. }, 600];\) // AbsTime\), "\n", 
    \(\(ndSolveCompiledTime = First[%]/600;\)\)}], "Input"],

Cell[BoxData[
    \({3.515175`7.997491944371719\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["We plot the result to verify the compiled Runge-Kutta solver", "Text"],

Cell[BoxData[
    \(\(Map[
        Plot[#[t], {t, 0, 8}, PlotRange \[Rule] All, 
            DisplayFunction \[Rule] Identity] &, 
        Part[dsolCompiled, Range[4]]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[%], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.575347 0.560632 [
[.2619 .56285 -3 -9 ]
[.2619 .56285 3 0 ]
[.5 .56285 -3 -9 ]
[.5 .56285 3 0 ]
[.7381 .56285 -3 -9 ]
[.7381 .56285 3 0 ]
[.97619 .56285 -3 -9 ]
[.97619 .56285 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .12684 -24 -4.5 ]
[.01131 .12684 0 4.5 ]
[.01131 .23897 -24 -4.5 ]
[.01131 .23897 0 4.5 ]
[.01131 .35109 -24 -4.5 ]
[.01131 .35109 0 4.5 ]
[.01131 .46322 -24 -4.5 ]
[.01131 .46322 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .57535 m
.2619 .5816 L
s
[(2)] .2619 .56285 0 1 Mshowa
.5 .57535 m
.5 .5816 L
s
[(4)] .5 .56285 0 1 Mshowa
.7381 .57535 m
.7381 .5816 L
s
[(6)] .7381 .56285 0 1 Mshowa
.97619 .57535 m
.97619 .5816 L
s
[(8)] .97619 .56285 0 1 Mshowa
.125 Mabswid
.08333 .57535 m
.08333 .5791 L
s
.14286 .57535 m
.14286 .5791 L
s
.20238 .57535 m
.20238 .5791 L
s
.32143 .57535 m
.32143 .5791 L
s
.38095 .57535 m
.38095 .5791 L
s
.44048 .57535 m
.44048 .5791 L
s
.55952 .57535 m
.55952 .5791 L
s
.61905 .57535 m
.61905 .5791 L
s
.67857 .57535 m
.67857 .5791 L
s
.79762 .57535 m
.79762 .5791 L
s
.85714 .57535 m
.85714 .5791 L
s
.91667 .57535 m
.91667 .5791 L
s
.25 Mabswid
0 .57535 m
1 .57535 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .12684 m
.03006 .12684 L
s
[(-0.8)] .01131 .12684 1 0 Mshowa
.02381 .23897 m
.03006 .23897 L
s
[(-0.6)] .01131 .23897 1 0 Mshowa
.02381 .35109 m
.03006 .35109 L
s
[(-0.4)] .01131 .35109 1 0 Mshowa
.02381 .46322 m
.03006 .46322 L
s
[(-0.2)] .01131 .46322 1 0 Mshowa
.125 Mabswid
.02381 .04275 m
.02756 .04275 L
s
.02381 .07078 m
.02756 .07078 L
s
.02381 .09881 m
.02756 .09881 L
s
.02381 .15487 m
.02756 .15487 L
s
.02381 .1829 m
.02756 .1829 L
s
.02381 .21094 m
.02756 .21094 L
s
.02381 .267 m
.02756 .267 L
s
.02381 .29503 m
.02756 .29503 L
s
.02381 .32306 m
.02756 .32306 L
s
.02381 .37913 m
.02756 .37913 L
s
.02381 .40716 m
.02756 .40716 L
s
.02381 .43519 m
.02756 .43519 L
s
.02381 .49125 m
.02756 .49125 L
s
.02381 .51928 m
.02756 .51928 L
s
.02381 .54732 m
.02756 .54732 L
s
.02381 .60338 m
.02756 .60338 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01485 L
.02605 .0152 L
.02729 .01585 L
.02846 .01669 L
.03053 .0187 L
.03279 .02155 L
.0379 .03019 L
.04262 .04032 L
.06244 .09673 L
.10458 .2473 L
.1249 .32174 L
.14393 .38525 L
.16333 .43908 L
.18177 .47799 L
.19145 .49378 L
.20201 .50791 L
.22054 .52671 L
.26118 .556 L
.30031 .58124 L
.3106 .58713 L
.32172 .59273 L
.33134 .59675 L
.33643 .59852 L
.34189 .60012 L
.34729 .60139 L
.35221 .60227 L
.35457 .6026 L
.35715 .60289 L
.35833 .60299 L
.35958 .60309 L
.36068 .60316 L
.36183 .60322 L
.36313 .60327 L
.36432 .6033 L
.3656 .60332 L
.36632 .60332 L
.367 .60332 L
.36823 .6033 L
.36934 .60327 L
.37063 .60321 L
.37185 .60315 L
.37461 .60295 L
.37715 .6027 L
.3829 .60191 L
.38757 .60106 L
.39259 .59995 L
.40166 .59753 L
.4223 .59064 L
.44205 .58361 L
Mistroke
.45248 .58021 L
.46358 .57706 L
.47441 .57459 L
.48421 .57291 L
.48895 .57229 L
.49407 .57177 L
.49642 .57158 L
.4989 .57141 L
.50103 .5713 L
.50334 .57119 L
.50467 .57115 L
.50589 .57111 L
.50707 .57108 L
.50831 .57106 L
.50942 .57105 L
.51047 .57104 L
.51161 .57104 L
.51284 .57105 L
.51408 .57106 L
.51478 .57107 L
.51543 .57108 L
.51675 .5711 L
.51815 .57114 L
.5207 .57122 L
.52302 .57132 L
.52755 .57155 L
.53246 .57188 L
.54136 .57261 L
.56089 .57452 L
.57123 .57552 L
.58233 .57646 L
.58781 .57684 L
.593 .57715 L
.59805 .57739 L
.60273 .57757 L
.60715 .57769 L
.60939 .57774 L
.61067 .57776 L
.61186 .57777 L
.61305 .57778 L
.61432 .57779 L
.61559 .5778 L
.61631 .5778 L
.61698 .5778 L
.61819 .5778 L
.6193 .5778 L
.62058 .57779 L
.62179 .57778 L
.62294 .57777 L
.62417 .57775 L
Mistroke
.62641 .57771 L
.63149 .5776 L
.63687 .57742 L
.64178 .57722 L
.66022 .57625 L
.68083 .57503 L
.69086 .57448 L
.69995 .57407 L
.70453 .57389 L
.70948 .57373 L
.71376 .57361 L
.71845 .57351 L
.72104 .57347 L
.72345 .57344 L
.72599 .57341 L
.72742 .5734 L
.72872 .5734 L
.72993 .57339 L
.73104 .57339 L
.73227 .57339 L
.73357 .57339 L
.7347 .57339 L
.73576 .57339 L
.73691 .5734 L
.73816 .57341 L
.74056 .57343 L
.74313 .57345 L
.74774 .57352 L
.75323 .57363 L
.75822 .57375 L
.77932 .57444 L
.80014 .5752 L
.80928 .5755 L
.81933 .57579 L
.82899 .576 L
.83363 .57608 L
.83803 .57614 L
.84041 .57617 L
.84301 .5762 L
.8454 .57622 L
.84757 .57623 L
.85014 .57624 L
.85156 .57625 L
.8522 .57625 L
.85288 .57625 L
.85412 .57625 L
.85525 .57626 L
.85647 .57626 L
.85717 .57625 L
.85781 .57625 L
Mistroke
.85908 .57625 L
.85972 .57625 L
.86043 .57625 L
.86284 .57624 L
.8642 .57623 L
.86566 .57622 L
.8683 .57621 L
.87348 .57616 L
.87822 .57611 L
.89679 .57582 L
.91737 .57545 L
.9274 .57528 L
.93649 .57515 L
.946 .57504 L
.95036 .57499 L
.95497 .57496 L
.95989 .57493 L
.96208 .57492 L
.96443 .57491 L
.96575 .5749 L
.96695 .5749 L
.96818 .5749 L
.96931 .5749 L
.97063 .57489 L
.97132 .57489 L
.97206 .57489 L
.9733 .57489 L
.97401 .57489 L
.97467 .57489 L
.97546 .57489 L
.97619 .57489 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.40199 5.69505 [
[.2619 .38949 -3 -9 ]
[.2619 .38949 3 0 ]
[.5 .38949 -3 -9 ]
[.5 .38949 3 0 ]
[.7381 .38949 -3 -9 ]
[.7381 .38949 3 0 ]
[.97619 .38949 -3 -9 ]
[.97619 .38949 3 0 ]
[.01131 .06029 -30 -4.5 ]
[.01131 .06029 0 4.5 ]
[.01131 .17419 -30 -4.5 ]
[.01131 .17419 0 4.5 ]
[.01131 .28809 -30 -4.5 ]
[.01131 .28809 0 4.5 ]
[.01131 .51589 -24 -4.5 ]
[.01131 .51589 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .40199 m
.2619 .40824 L
s
[(2)] .2619 .38949 0 1 Mshowa
.5 .40199 m
.5 .40824 L
s
[(4)] .5 .38949 0 1 Mshowa
.7381 .40199 m
.7381 .40824 L
s
[(6)] .7381 .38949 0 1 Mshowa
.97619 .40199 m
.97619 .40824 L
s
[(8)] .97619 .38949 0 1 Mshowa
.125 Mabswid
.08333 .40199 m
.08333 .40574 L
s
.14286 .40199 m
.14286 .40574 L
s
.20238 .40199 m
.20238 .40574 L
s
.32143 .40199 m
.32143 .40574 L
s
.38095 .40199 m
.38095 .40574 L
s
.44048 .40199 m
.44048 .40574 L
s
.55952 .40199 m
.55952 .40574 L
s
.61905 .40199 m
.61905 .40574 L
s
.67857 .40199 m
.67857 .40574 L
s
.79762 .40199 m
.79762 .40574 L
s
.85714 .40199 m
.85714 .40574 L
s
.91667 .40199 m
.91667 .40574 L
s
.25 Mabswid
0 .40199 m
1 .40199 L
s
.02381 .06029 m
.03006 .06029 L
s
[(-0.06)] .01131 .06029 1 0 Mshowa
.02381 .17419 m
.03006 .17419 L
s
[(-0.04)] .01131 .17419 1 0 Mshowa
.02381 .28809 m
.03006 .28809 L
s
[(-0.02)] .01131 .28809 1 0 Mshowa
.02381 .51589 m
.03006 .51589 L
s
[(0.02)] .01131 .51589 1 0 Mshowa
.125 Mabswid
.02381 .08876 m
.02756 .08876 L
s
.02381 .11724 m
.02756 .11724 L
s
.02381 .14571 m
.02756 .14571 L
s
.02381 .20266 m
.02756 .20266 L
s
.02381 .23114 m
.02756 .23114 L
s
.02381 .25961 m
.02756 .25961 L
s
.02381 .31656 m
.02756 .31656 L
s
.02381 .34504 m
.02756 .34504 L
s
.02381 .37352 m
.02756 .37352 L
s
.02381 .43047 m
.02756 .43047 L
s
.02381 .45894 m
.02756 .45894 L
s
.02381 .48742 m
.02756 .48742 L
s
.02381 .03181 m
.02756 .03181 L
s
.02381 .00334 m
.02756 .00334 L
s
.02381 .54437 m
.02756 .54437 L
s
.02381 .57284 m
.02756 .57284 L
s
.02381 .60132 m
.02756 .60132 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .40199 m
.06244 .24068 L
.08255 .13088 L
.0932 .08404 L
.09905 .06273 L
.10458 .04584 L
.10972 .0332 L
.11243 .02779 L
.11531 .02304 L
.11772 .01986 L
.119 .01847 L
.12038 .01722 L
.12164 .01629 L
.1228 .01562 L
.12396 .01514 L
.12507 .01485 L
.12627 .01472 L
.12736 .01477 L
.12861 .01503 L
.1298 .01548 L
.1309 .01607 L
.13191 .01677 L
.13419 .01886 L
.1365 .02172 L
.13903 .02573 L
.14415 .03656 L
.14939 .05142 L
.15436 .06888 L
.16366 .10985 L
.18458 .2323 L
.2028 .35435 L
.22291 .47767 L
.23242 .52456 L
.24268 .56372 L
.24833 .57973 L
.25081 .58544 L
.25352 .59078 L
.25591 .5947 L
.25847 .59808 L
.25989 .59958 L
.26117 .60073 L
.26247 .60167 L
.26369 .60236 L
.2648 .60283 L
.266 .60316 L
.26668 .60327 L
.26732 .60332 L
.26854 .60328 L
.26981 .60305 L
.27099 .60266 L
Mistroke
.27229 .60205 L
.27367 .60119 L
.27616 .59909 L
.2785 .5965 L
.28287 .59015 L
.28808 .58019 L
.29287 .56899 L
.30367 .53792 L
.32413 .46671 L
.34321 .40137 L
.35265 .37404 L
.36157 .35277 L
.36651 .34319 L
.37186 .33463 L
.37673 .32857 L
.38123 .32443 L
.38366 .32278 L
.38588 .32161 L
.38715 .32109 L
.38832 .3207 L
.38955 .3204 L
.39019 .32027 L
.39089 .32017 L
.39206 .32007 L
.39333 .32005 L
.39453 .32013 L
.39563 .32028 L
.39663 .32047 L
.39772 .32076 L
.39994 .32154 L
.40262 .32286 L
.40508 .32441 L
.41059 .32896 L
.42055 .34042 L
.44122 .3725 L
.46036 .40377 L
.46993 .41733 L
.47893 .42792 L
.4883 .43628 L
.49329 .43952 L
.49588 .44086 L
.49866 .44205 L
.50125 .44291 L
.50361 .4435 L
.50475 .44371 L
.50598 .4439 L
.50714 .44403 L
.50822 .4441 L
.50947 .44415 L
.51064 .44415 L
Mistroke
.51192 .44409 L
.51264 .44404 L
.5133 .44398 L
.51462 .44381 L
.51606 .44357 L
.51868 .44298 L
.52146 .44214 L
.52398 .4412 L
.52962 .43853 L
.53977 .43203 L
.56065 .41459 L
.57986 .39813 L
.58956 .39104 L
.59862 .38565 L
.60356 .38327 L
.60806 .38149 L
.61307 .37994 L
.61582 .37929 L
.61843 .37879 L
.6208 .37845 L
.62188 .37833 L
.62302 .37823 L
.62429 .37814 L
.62546 .37808 L
.62672 .37805 L
.62743 .37804 L
.62809 .37804 L
.62873 .37805 L
.62943 .37806 L
.63069 .37811 L
.63192 .37819 L
.63305 .37828 L
.63563 .37856 L
.63835 .37897 L
.64289 .37988 L
.64713 .38099 L
.65678 .38427 L
.69562 .40214 L
.70576 .40635 L
.71681 .41009 L
.72187 .41144 L
.72725 .41262 L
.73232 .41346 L
.73692 .41401 L
.73925 .41421 L
.74059 .4143 L
.74181 .41437 L
.7431 .41442 L
.74377 .41445 L
.74449 .41447 L
Mistroke
.74577 .41449 L
.74698 .4145 L
.74809 .41449 L
.74931 .41448 L
.75058 .41445 L
.75178 .4144 L
.75392 .41429 L
.75622 .41414 L
.75888 .4139 L
.76179 .41358 L
.7671 .41285 L
.77706 .41103 L
.79836 .40594 L
.81769 .40121 L
.82736 .3992 L
.83783 .39745 L
.84263 .39683 L
.84771 .39629 L
.85205 .39594 L
.85452 .39578 L
.85681 .39566 L
.85931 .39557 L
.86064 .39553 L
.86204 .3955 L
.86326 .39548 L
.8644 .39547 L
.86565 .39546 L
.86636 .39546 L
.867 .39546 L
.86813 .39547 L
.86917 .39549 L
.87031 .39551 L
.87154 .39554 L
.87403 .39561 L
.87631 .39571 L
.88147 .396 L
.88706 .39643 L
.89722 .39744 L
.91669 .39991 L
.93812 .40265 L
.9476 .40366 L
.95283 .40413 L
.95779 .40452 L
.96239 .40482 L
.9674 .40508 L
.96961 .40518 L
.97196 .40526 L
.97619 .40538 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.049229 0.501446 [
[.2619 .03673 -3 -9 ]
[.2619 .03673 3 0 ]
[.5 .03673 -3 -9 ]
[.5 .03673 3 0 ]
[.7381 .03673 -3 -9 ]
[.7381 .03673 3 0 ]
[.97619 .03673 -3 -9 ]
[.97619 .03673 3 0 ]
[.01131 .14952 -18 -4.5 ]
[.01131 .14952 0 4.5 ]
[.01131 .24981 -18 -4.5 ]
[.01131 .24981 0 4.5 ]
[.01131 .3501 -18 -4.5 ]
[.01131 .3501 0 4.5 ]
[.01131 .45039 -18 -4.5 ]
[.01131 .45039 0 4.5 ]
[.01131 .55068 -6 -4.5 ]
[.01131 .55068 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .04923 m
.2619 .05548 L
s
[(2)] .2619 .03673 0 1 Mshowa
.5 .04923 m
.5 .05548 L
s
[(4)] .5 .03673 0 1 Mshowa
.7381 .04923 m
.7381 .05548 L
s
[(6)] .7381 .03673 0 1 Mshowa
.97619 .04923 m
.97619 .05548 L
s
[(8)] .97619 .03673 0 1 Mshowa
.125 Mabswid
.08333 .04923 m
.08333 .05298 L
s
.14286 .04923 m
.14286 .05298 L
s
.20238 .04923 m
.20238 .05298 L
s
.32143 .04923 m
.32143 .05298 L
s
.38095 .04923 m
.38095 .05298 L
s
.44048 .04923 m
.44048 .05298 L
s
.55952 .04923 m
.55952 .05298 L
s
.61905 .04923 m
.61905 .05298 L
s
.67857 .04923 m
.67857 .05298 L
s
.79762 .04923 m
.79762 .05298 L
s
.85714 .04923 m
.85714 .05298 L
s
.91667 .04923 m
.91667 .05298 L
s
.25 Mabswid
0 .04923 m
1 .04923 L
s
.02381 .14952 m
.03006 .14952 L
s
[(0.2)] .01131 .14952 1 0 Mshowa
.02381 .24981 m
.03006 .24981 L
s
[(0.4)] .01131 .24981 1 0 Mshowa
.02381 .3501 m
.03006 .3501 L
s
[(0.6)] .01131 .3501 1 0 Mshowa
.02381 .45039 m
.03006 .45039 L
s
[(0.8)] .01131 .45039 1 0 Mshowa
.02381 .55068 m
.03006 .55068 L
s
[(1)] .01131 .55068 1 0 Mshowa
.125 Mabswid
.02381 .0743 m
.02756 .0743 L
s
.02381 .09937 m
.02756 .09937 L
s
.02381 .12445 m
.02756 .12445 L
s
.02381 .17459 m
.02756 .17459 L
s
.02381 .19966 m
.02756 .19966 L
s
.02381 .22474 m
.02756 .22474 L
s
.02381 .27488 m
.02756 .27488 L
s
.02381 .29995 m
.02756 .29995 L
s
.02381 .32502 m
.02756 .32502 L
s
.02381 .37517 m
.02756 .37517 L
s
.02381 .40024 m
.02756 .40024 L
s
.02381 .42531 m
.02756 .42531 L
s
.02381 .47546 m
.02756 .47546 L
s
.02381 .50053 m
.02756 .50053 L
s
.02381 .5256 m
.02756 .5256 L
s
.02381 .02416 m
.02756 .02416 L
s
.02381 .57575 m
.02756 .57575 L
s
.02381 .60082 m
.02756 .60082 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .55068 m
.02499 .55092 L
.02605 .55153 L
.02729 .55265 L
.02846 .55405 L
.03279 .56137 L
.04262 .58246 L
.04723 .59118 L
.04976 .59512 L
.05212 .59817 L
.05468 .6007 L
.05603 .60171 L
.05673 .60213 L
.05749 .60252 L
.05818 .60281 L
.05882 .60302 L
.06008 .60327 L
.06122 .60332 L
.06244 .60318 L
.0631 .60302 L
.06383 .60277 L
.06459 .60245 L
.06529 .60207 L
.06791 .60013 L
.0694 .59863 L
.07076 .59702 L
.07382 .59259 L
.07933 .58197 L
.08454 .5691 L
.10458 .50116 L
.14291 .33765 L
.16229 .25676 L
.18369 .17748 L
.20418 .11524 L
.22296 .07162 L
.23238 .0547 L
.2423 .0404 L
.25227 .02951 L
.25791 .0248 L
.26316 .0213 L
.26821 .0187 L
.27087 .01761 L
.27368 .01666 L
.27615 .016 L
.27885 .01543 L
.28004 .01524 L
.28131 .01507 L
.28243 .01494 L
.28362 .01484 L
.28486 .01477 L
Mistroke
.286 .01473 L
.2867 .01472 L
.28737 .01472 L
.2886 .01473 L
.28979 .01478 L
.29087 .01484 L
.29207 .01493 L
.29333 .01505 L
.29552 .01533 L
.29756 .01565 L
.30221 .0166 L
.31268 .01965 L
.3226 .0233 L
.34117 .0308 L
.35942 .03739 L
.36981 .04031 L
.37489 .04147 L
.37955 .04238 L
.38411 .04311 L
.38909 .04375 L
.3941 .04423 L
.39683 .04443 L
.39936 .04457 L
.40068 .04462 L
.40211 .04467 L
.40345 .04471 L
.40469 .04474 L
.40581 .04476 L
.40705 .04477 L
.40833 .04477 L
.40953 .04477 L
.4102 .04477 L
.41094 .04476 L
.41163 .04475 L
.41227 .04474 L
.41477 .04469 L
.41606 .04465 L
.41749 .0446 L
.42038 .04448 L
.43046 .0439 L
.43971 .04322 L
.4505 .04241 L
.45577 .04205 L
.46055 .04177 L
.46493 .04155 L
.46969 .04137 L
.4723 .04129 L
.47345 .04126 L
.47471 .04124 L
.47582 .04122 L
Mistroke
.47701 .0412 L
.47827 .04119 L
.47945 .04119 L
.48012 .04118 L
.48083 .04118 L
.4821 .04119 L
.48289 .04119 L
.48362 .0412 L
.485 .04121 L
.48631 .04123 L
.48753 .04126 L
.49026 .04133 L
.49255 .04141 L
.49507 .04151 L
.50015 .04179 L
.51036 .04257 L
.51967 .04351 L
.54059 .04616 L
.5613 .04894 L
.57041 .05004 L
.58046 .05109 L
.59005 .05189 L
.59905 .05245 L
.60402 .05266 L
.60856 .05281 L
.61095 .05286 L
.61355 .05291 L
.61487 .05293 L
.61559 .05293 L
.61627 .05294 L
.61691 .05294 L
.6176 .05295 L
.6188 .05295 L
.62004 .05295 L
.62117 .05295 L
.62247 .05294 L
.6237 .05293 L
.62484 .05292 L
.62589 .0529 L
.62828 .05286 L
.63093 .05281 L
.63333 .05274 L
.6387 .05256 L
.64954 .05207 L
.65974 .05149 L
.67817 .05031 L
.68863 .04967 L
.69837 .04913 L
.70883 .04865 L
.71836 .04831 L
Mistroke
.72359 .04818 L
.72854 .04808 L
.73126 .04804 L
.73377 .04801 L
.73652 .04799 L
.73791 .04798 L
.73865 .04797 L
.73944 .04797 L
.74073 .04797 L
.74192 .04796 L
.74266 .04796 L
.74335 .04796 L
.74463 .04797 L
.74587 .04797 L
.74701 .04797 L
.74825 .04798 L
.74957 .04799 L
.75186 .04801 L
.75399 .04803 L
.75884 .04809 L
.76411 .04818 L
.76892 .04828 L
.77972 .04855 L
.8004 .04913 L
.8095 .04938 L
.81955 .04961 L
.82913 .04979 L
.83351 .04986 L
.83813 .04992 L
.84049 .04994 L
.84308 .04996 L
.84546 .04998 L
.84762 .04999 L
.85019 .05 L
.8516 .05001 L
.85225 .05001 L
.85293 .05001 L
.85416 .05001 L
.8553 .05001 L
.85652 .05001 L
.85722 .05001 L
.85787 .05001 L
.85912 .05001 L
.85982 .05001 L
.86045 .05001 L
.86284 .05 L
.86419 .05 L
.86564 .04999 L
.86827 .04998 L
.87341 .04994 L
Mistroke
.87815 .04989 L
.89668 .04964 L
.91713 .04931 L
.92711 .04916 L
.93621 .04903 L
.945 .04893 L
.95456 .04885 L
.95981 .04882 L
.96212 .04881 L
.96466 .0488 L
.96705 .04879 L
.9693 .04879 L
.97053 .04879 L
.97167 .04879 L
.97291 .04878 L
.97422 .04878 L
.97524 .04878 L
.97619 .04878 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.37569 2.09278 [
[.2619 .36319 -3 -9 ]
[.2619 .36319 3 0 ]
[.5 .36319 -3 -9 ]
[.5 .36319 3 0 ]
[.7381 .36319 -3 -9 ]
[.7381 .36319 3 0 ]
[.97619 .36319 -3 -9 ]
[.97619 .36319 3 0 ]
[.01131 .06177 -30 -4.5 ]
[.01131 .06177 0 4.5 ]
[.01131 .16641 -24 -4.5 ]
[.01131 .16641 0 4.5 ]
[.01131 .27105 -30 -4.5 ]
[.01131 .27105 0 4.5 ]
[.01131 .48033 -24 -4.5 ]
[.01131 .48033 0 4.5 ]
[.01131 .58497 -18 -4.5 ]
[.01131 .58497 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37569 m
.2619 .38194 L
s
[(2)] .2619 .36319 0 1 Mshowa
.5 .37569 m
.5 .38194 L
s
[(4)] .5 .36319 0 1 Mshowa
.7381 .37569 m
.7381 .38194 L
s
[(6)] .7381 .36319 0 1 Mshowa
.97619 .37569 m
.97619 .38194 L
s
[(8)] .97619 .36319 0 1 Mshowa
.125 Mabswid
.08333 .37569 m
.08333 .37944 L
s
.14286 .37569 m
.14286 .37944 L
s
.20238 .37569 m
.20238 .37944 L
s
.32143 .37569 m
.32143 .37944 L
s
.38095 .37569 m
.38095 .37944 L
s
.44048 .37569 m
.44048 .37944 L
s
.55952 .37569 m
.55952 .37944 L
s
.61905 .37569 m
.61905 .37944 L
s
.67857 .37569 m
.67857 .37944 L
s
.79762 .37569 m
.79762 .37944 L
s
.85714 .37569 m
.85714 .37944 L
s
.91667 .37569 m
.91667 .37944 L
s
.25 Mabswid
0 .37569 m
1 .37569 L
s
.02381 .06177 m
.03006 .06177 L
s
[(-0.15)] .01131 .06177 1 0 Mshowa
.02381 .16641 m
.03006 .16641 L
s
[(-0.1)] .01131 .16641 1 0 Mshowa
.02381 .27105 m
.03006 .27105 L
s
[(-0.05)] .01131 .27105 1 0 Mshowa
.02381 .48033 m
.03006 .48033 L
s
[(0.05)] .01131 .48033 1 0 Mshowa
.02381 .58497 m
.03006 .58497 L
s
[(0.1)] .01131 .58497 1 0 Mshowa
.125 Mabswid
.02381 .0827 m
.02756 .0827 L
s
.02381 .10363 m
.02756 .10363 L
s
.02381 .12456 m
.02756 .12456 L
s
.02381 .14548 m
.02756 .14548 L
s
.02381 .18734 m
.02756 .18734 L
s
.02381 .20827 m
.02756 .20827 L
s
.02381 .2292 m
.02756 .2292 L
s
.02381 .25012 m
.02756 .25012 L
s
.02381 .29198 m
.02756 .29198 L
s
.02381 .31291 m
.02756 .31291 L
s
.02381 .33383 m
.02756 .33383 L
s
.02381 .35476 m
.02756 .35476 L
s
.02381 .39662 m
.02756 .39662 L
s
.02381 .41755 m
.02756 .41755 L
s
.02381 .43847 m
.02756 .43847 L
s
.02381 .4594 m
.02756 .4594 L
s
.02381 .50126 m
.02756 .50126 L
s
.02381 .52219 m
.02756 .52219 L
s
.02381 .54311 m
.02756 .54311 L
s
.02381 .56404 m
.02756 .56404 L
s
.02381 .04085 m
.02756 .04085 L
s
.02381 .01992 m
.02756 .01992 L
s
.02381 .6059 m
.02756 .6059 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .58497 m
.04262 .2678 L
.04754 .17658 L
.0522 .10798 L
.05477 .07827 L
.05756 .05273 L
.05879 .04364 L
.0601 .03543 L
.06133 .02904 L
.06244 .02427 L
.06368 .02017 L
.06431 .01852 L
.065 .01707 L
.06623 .01535 L
.0674 .01472 L
.06812 .01479 L
.06877 .01515 L
.06952 .01591 L
.07023 .01696 L
.07149 .01957 L
.07286 .02342 L
.07531 .03285 L
.07791 .04593 L
.08255 .07594 L
.10458 .27114 L
.11478 .36053 L
.12444 .43379 L
.13385 .49214 L
.14255 .53437 L
.1519 .56761 L
.15683 .58041 L
.15934 .58577 L
.16206 .59068 L
.16474 .59468 L
.16719 .59764 L
.16953 .59986 L
.172 .60159 L
.17332 .60226 L
.17404 .60255 L
.17472 .60279 L
.17535 .60297 L
.17604 .60312 L
.17724 .60328 L
.17793 .60332 L
.17869 .60331 L
.17948 .60324 L
.18023 .60314 L
.18092 .60299 L
.18155 .60283 L
.18298 .60234 L
Mistroke
.18427 .60176 L
.18548 .60109 L
.18776 .59956 L
.19285 .59487 L
.19725 .58955 L
.202 .58267 L
.22274 .54334 L
.24232 .50043 L
.26379 .45581 L
.28449 .42036 L
.30333 .39688 L
.31338 .38805 L
.32288 .38197 L
.32809 .37952 L
.33291 .37778 L
.3382 .37639 L
.34087 .37588 L
.34239 .37565 L
.34381 .37546 L
.34617 .37523 L
.34741 .37514 L
.34874 .37507 L
.34941 .37504 L
.35014 .37502 L
.35146 .375 L
.35274 .375 L
.35393 .37502 L
.35504 .37506 L
.35607 .3751 L
.35721 .37516 L
.35843 .37524 L
.36092 .37545 L
.36319 .3757 L
.37391 .37732 L
.38406 .37927 L
.39282 .38099 L
.40226 .38264 L
.40766 .38342 L
.41262 .38398 L
.41736 .38438 L
.41975 .38453 L
.42109 .38459 L
.42236 .38464 L
.4236 .38468 L
.42426 .3847 L
.42495 .38471 L
.42617 .38473 L
.4273 .38473 L
.4286 .38472 L
.42982 .38471 L
Mistroke
.43052 .3847 L
.43115 .38468 L
.43259 .38463 L
.43492 .38453 L
.43747 .38437 L
.44211 .38398 L
.44738 .38336 L
.453 .38252 L
.46311 .38064 L
.4831 .376 L
.50471 .37094 L
.51487 .36899 L
.52042 .3681 L
.5256 .3674 L
.53039 .36688 L
.53475 .3665 L
.53708 .36634 L
.5396 .3662 L
.54099 .36614 L
.54227 .36609 L
.5435 .36605 L
.5448 .36602 L
.54596 .36599 L
.54722 .36598 L
.54837 .36597 L
.54944 .36597 L
.5507 .36598 L
.55185 .36599 L
.55249 .366 L
.55318 .36602 L
.55444 .36605 L
.55672 .36612 L
.55914 .36623 L
.56348 .36649 L
.56855 .36689 L
.57329 .36736 L
.58409 .36869 L
.62293 .37471 L
.63307 .37611 L
.64412 .37737 L
.64918 .37783 L
.65456 .37825 L
.65926 .37854 L
.66423 .37878 L
.66679 .37887 L
.66961 .37895 L
.67084 .37898 L
.67216 .37901 L
.6734 .37902 L
.67455 .37904 L
Mistroke
.67523 .37905 L
.67599 .37905 L
.67674 .37906 L
.67755 .37906 L
.67825 .37906 L
.67901 .37906 L
.67973 .37906 L
.68038 .37905 L
.68168 .37905 L
.68242 .37904 L
.68311 .37903 L
.68569 .37899 L
.68833 .37894 L
.69082 .37887 L
.69546 .37871 L
.70588 .37822 L
.74442 .37568 L
.75472 .37508 L
.76435 .37462 L
.7696 .37442 L
.77439 .37427 L
.77971 .37414 L
.78263 .37409 L
.78541 .37405 L
.78655 .37404 L
.78777 .37403 L
.78883 .37402 L
.78999 .37401 L
.79128 .37401 L
.79198 .374 L
.79264 .374 L
.79381 .374 L
.79506 .374 L
.79575 .374 L
.79638 .374 L
.79708 .37401 L
.79782 .37401 L
.79906 .37402 L
.80043 .37403 L
.80295 .37405 L
.80531 .37408 L
.80995 .37415 L
.81419 .37424 L
.82373 .3745 L
.84435 .37521 L
.86348 .37589 L
.87301 .37618 L
.88199 .3764 L
.88696 .3765 L
.89234 .37658 L
Mistroke
.89722 .37664 L
.89953 .37667 L
.90171 .37668 L
.90289 .37669 L
.90417 .3767 L
.90524 .3767 L
.90642 .37671 L
.90769 .37671 L
.90839 .37671 L
.90904 .37671 L
.91021 .37672 L
.91146 .37672 L
.91257 .37672 L
.91378 .37671 L
.91504 .37671 L
.91621 .37671 L
.91832 .3767 L
.92056 .37668 L
.92614 .37664 L
.9314 .37658 L
.94124 .37644 L
.97619 .37575 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 41.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000:B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00[@3oool4000000P0oooo0`00
00050?ooo`<00000203oool200000580oooo002]0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo00000540oooo
002^0?ooo`030000003oool0oooo00H0oooo1@0000050?ooo`040000003oool0oooo000000H0oooo
00@000000?ooo`3oool00000D@3oool00:l0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000060?ooo`<00000203oool200000580oooo002]0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
0540oooo002^0?ooo`8000002@3oool2000000L0oooo0`0000070?ooo`800000DP3oool001`0oooo
1@0000240?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;03oool2000000@0oooo
0P0000030?ooo`D000000P3oool2000002d0oooo000N0?ooo`050000003oool0oooo0?ooo`000000
<`3oool2000000@0oooo0P0000040?ooo`8000000`3oool3000003/0oooo00<000000?ooo`3oool0
1P3oool5000002/0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000P00000X0?ooo`007P3oool01@000000oooo0?ooo`3oool00000
0380oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000P3oool2000003<0oooo:`00000?0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool0103oool00`000000oooo00000002000002P0oooo000F0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000380oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`070000003oool0oooo0000003oool000000?ooo`03000003@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`@000000P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`<00000:03oool00140
oooo0P0000040?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:P3oool400000080
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`<000000P3oool0
1@000000oooo0000003oool0000002<0oooo0P0000040?ooo`8000000`3oool400000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`040000003oool0oooo000000<0oooo
0P0000040?ooo`8000000`3oool800000080oooo100000050?ooo`<000000`3oool3000000D0oooo
0P00000=0?ooo`00403oool010000000oooo0?ooo`0000080?ooo`@000000P3oool200000340oooo
100000030?ooo`8000000`3oool4000000<0oooo1@0000000`3oool000000?ooo`05000000D0oooo
0`0000030?ooo`<000001@3oool2000000T0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool2000000<0
oooo00@000000?ooo`3oool000000`3oool2000000@0oooo0`000000103oool00000000000000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00030?ooo`040000003oool0oooo000000`0oooo000@0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool200000340oooo100000080?ooo`@000000`3oool300000005
0?ooo`000000oooo0000003oool00P0000090?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3o
ool00`3oool5000000<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00000<
0?ooo`002P3oool400000080oooo00@000000?ooo`3oool000002@3oool2000000<0oooo00<00000
0?ooo`000000<03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
1P0000001P3oool000000?ooo`000000oooo000000D0oooo1@0000030?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000:0?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0`0?ooo`@000000P3oool4000000<0
oooo0P0000040?ooo`8000000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`<000001@3oool2000000d0oooo000@0?ooo`@000000`3oool2000000<0
oooo100000020?ooo`030000003oool0000002X0oooo100000020?ooo`@000000`3oool2000000<0
oooo100000020?ooo`@0000000<0oooo0000000000000`3oool00`000000oooo000000040?ooo`04
0000003oool0oooo000000@0oooo0`0000050?ooo`8000002@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`080000003oool000000000003oool000000?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000`0oooo000@0?ooo`@00000203oool400000080oooo00@000000?ooo`3o
ool00000;`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P00
00000`3oool000000?ooo`02000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002@3oool2000000@0
oooo0P0000040?ooo`@0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0`0?ooo`04
0000003oool0oooo000000<0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo0`000000
103oool000000?ooo`0000030?ooo`8000001P3oool2000000D0oooo0`0000040?ooo`8000003@3o
ool00100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000002l0oooo100000080?ooo`@000000`3oool3000000030?ooo`000000000000<0
oooo0`0000060?ooo`8000001@3oool3000000@0oooo0P0000090?ooo`040000003oool0oooo0000
00/0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Z0?ooo`@000000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`030000
003oool0000002P0oooo000:0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`<00000
0`3oool010000000oooo0?ooo`00000Y0?ooo`@000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo00<0oooo0P00000J0?ooo`040000003oool0oooo000000P0oooo1@0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01P0oooo000@0?ooo`@000000`3oool2000000@0oooo100000001@3oool0
00000?ooo`3oool0000002l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`060000003oool0oooo0000003oool00000103oool00`000000oooo0?ooo`020?ooo`<0
00006P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`8000002P3oool2000000@0oooo8P00000=
0?ooo`00403oool4000000T0oooo0`0000020?ooo`040000003oool0oooo00000300oooo0P00000:
0?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo0`0000060?ooo`030000003oool0oooo00X0oooo1000
00030?ooo`8000000`3oool400000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0b0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0200oooo000@0?ooo`040000003oool0oooo000000P0oooo
1@0000001@3oool000000?ooo`3oool000000080oooo100000070?ooo`<00000103oool3000000H0
oooo0P00000V0?ooob000000203oool4000000P0oooo00@000000?ooo`00000000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool01@000000
oooo0?ooo`3oool0000002<0oooo000:0?ooo`@000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
0100oooo0P0000040?ooo`800000103oool2000000<0oooo100000000`3oool000000?ooo`040?oo
o`040000003oool0oooo000000@0oooo0`00000F0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo0000000S0?ooo`00403oool4000000<0oooo0P0000030?oo
o`@000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool5
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00000?0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000007@3oool010000000oooo0?ooo`00
00080?ooo`<000000`3oool01@000000oooo0?ooo`3oool0000003@0oooo00@000000?ooo`3oool0
00000`3oool2000000<0oooo100000020?ooo`H000000P3oool01@000000oooo0?ooo`3oool00000
02<0oooo000@0?ooo`@00000203oool010000000oooo0000000000020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000050?ooo`<000001P3o
ool200000100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0000000N0?ooo`@000000`3oool20000
00@0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000=03oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0R0?ooo`00403oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool20000
0080oooo00<000000?ooo`3oool0103oool00`000000oooo000000060?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0000000N0?ooo`@0
0000203oool400000080oooo00D000000?ooo`3oool0oooo0000000e0?ooo`8000000`3oool01000
0000oooo0?ooo`0000030?ooo`800000103oool3000000030?ooo`000000oooo0080oooo0P00000U
0?ooo`002P3oool400000080oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo0`0000080?ooo`8000001P3oool3000000D0oooo0P00000@0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
000000H0oooo0P00000N0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool0000003X0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`0000030?ooo`8000009@3oool00100oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P00000/0?ooo`8000002P3o
ool2000000@0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P00000N0?ooo`040000003o
ool0oooo000000T0oooo0P0000030?ooo`040000003oool0oooo000003/0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`0[0?ooo`004@3oool2000000X0oooo0P0000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0IP3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000?03oool2000000X0oooo0P00
000]0?ooo`008@3ooolU000004h0oooo0P0000090?ooo`D0000000D0oooo0000003oool0oooo0000
001g0?ooo`008P3oool00`000000oooo0?ooo`080?ooo`@00000L03oool01`000000oooo0?ooo`3o
ool000000?ooo`000000N03oool00280oooo00<000000?ooo`3oool0O03oool01`000000oooo0?oo
o`3oool000000?ooo`000000N03oool00:40oooo00@000000?ooo`3oool0oooo0`00001h0?ooo`00
X@3oool010000000oooo0?ooo`3oool3000007P0oooo002P0?ooo`800000OP3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {40.375, 0}} -> {-0.145559, -0.0143759, \
0.0149516, 0.0149516}, {{9.6875, 71.9375}, {39.375, 0.9375}} -> {-7.85082, \
-1.55896, 0.22993, 0.0488248}, {{78.125, 140.375}, {39.375, 0.9375}} -> \
{-30.066, -0.137114, 0.277096, 0.00579234}, {{146.563, 208.813}, {39.375, \
0.9375}} -> {-32.4393, -0.560572, 0.196486, 0.0466476}, {{215, 277.25}, \
{39.375, 0.9375}} -> {-67.9935, -0.343701, 0.277096, 0.0157626}}]
}, Open  ]],

Cell["Looks good!", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparing Performance", "Section"],

Cell["\<\
We present the comparision of performance in the following \
table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                "NDSolveStandardTime", \(NDSolveStandardTime/
                  ndSolveCompiledTime\)},
              {
                "NDSolveUncompiledTime", \(NDSolveUncompiledTime/
                  ndSolveCompiledTime\)},
              {"NDSolveRKTime", \(NDSolveRKTime/ndSolveCompiledTime\)},
              {
                "NDSolveRKUncompiledTime", \(NDSolveRKUncompiledTime/
                  ndSolveCompiledTime\)},
              {
                "ndSolveUncompiledTime", \(ndSolveUncompiledTime/
                  ndSolveCompiledTime\)},
              {
                "ndSolveCompiledTime", \(ndSolveCompiledTime/
                  ndSolveCompiledTime\)}
              }], ")"}], 
        ",", \(TableHeadings \[Rule] {{"\<NDSolve, Standard Mathematica\>", "\
\<NDSolve, Uncomp eqns, Mathematica\>", "\<NDSolve, Runge-Kutta \
Mathematica\>", "\<NDSolve, Runge-Kutta, Uncomp eqns, Mathematica\>", \
"\<ndSolve, Mathematica\>", "\<ndSolve, MathCode F90\>"}, {"\<Time \
consumed\>", "\<Relative\>"}}\)}], " ", "]"}]], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Time consumed\"\>", "\<\"Relative\"\>"},
          {"\<\"NDSolve, Standard Mathematica\"\>", \(0.125`\ Second\), 
            "21.33606434957008`"},
          {"\<\"NDSolve, Uncomp eqns, Mathematica\"\>", \(0.3439999999999994`\
\ Second\), "58.71684909001676`"},
          {"\<\"NDSolve, Runge-Kutta Mathematica\"\>", \(0.5629999999999988`\ \
Second\), "96.09763383046344`"},
          {"\<\"NDSolve, Runge-Kutta, Uncomp eqns, Mathematica\"\>", \
\(7.233999999999998`\ Second\), "1234.7607160383193`"},
          {"\<\"ndSolve, Mathematica\"\>", \(9.891000000000002`\ Second\), 
            "1688.2800998527816`"},
          {"\<\"ndSolve, MathCode F90\"\>", \
\(0.0058586250000000000000205276`7.997491944371718\ Second\), 
            "1.`7.696461948707737"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"NDSolve, Standard Mathematica", 
          "NDSolve, Uncomp eqns, Mathematica", 
          "NDSolve, Runge-Kutta Mathematica", 
          "NDSolve, Runge-Kutta, Uncomp eqns, Mathematica", 
          "ndSolve, Mathematica", "ndSolve, MathCode F90"}, {"Time consumed", 
          "Relative"}}]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cleaning Up", "Section"],

Cell["Uninstall the code and delete the temporary files. ", "Text"],

Cell[BoxData[{
    \(\(UninstallCode[];\)\), "\n", 
    \(\(CleanMathCodeFiles[Confirm \[Rule] False];\)\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 949}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{861, 869},
WindowMargins->{{18, Automatic}, {Automatic, 17}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->20],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{74, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Itemize"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{65, Inherited}, {8, 8}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Itemize", "Presentation"],
    CellMargins->{{Inherited, 10}, {8, 12}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Itemize", "Condensed"],
    CellMargins->{{Inherited, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Itemize", "Printout"],
    CellMargins->{{Inherited, 0}, {4, 20}},
    FontSize->11]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayCode"],
    CellFrame->2,
    CellMargins->{{52, 10}, {8, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->True,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["DisplayCode", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["DisplayCode", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["DisplayCode", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 228, 5, 55, "Title",
  Evaluatable->False],
Cell[1985, 58, 166, 4, 80, "Subtitle"],
Cell[2154, 64, 65, 0, 56, "Copyright"],
Cell[2222, 66, 176, 4, 34, "Text"],

Cell[CellGroupData[{
Cell[2423, 74, 148, 3, 50, "Input"],
Cell[2574, 79, 39, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2650, 85, 31, 0, 56, "Section"],
Cell[2684, 87, 150, 3, 29, "Text"],
Cell[2837, 92, 256, 5, 48, "Text"],
Cell[3096, 99, 679, 18, 67, "Text"],
Cell[3778, 119, 12193, 202, 302, 12101, 199, "GraphicsData", "Bitmap", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16008, 326, 90, 2, 56, "Section",
  Evaluatable->False],
Cell[16101, 330, 569, 17, 215, "Text",
  Evaluatable->False],
Cell[16673, 349, 745, 21, 308, "Text",
  Evaluatable->False],
Cell[17421, 372, 362, 6, 124, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17820, 383, 88, 2, 56, "Section",
  Evaluatable->False],
Cell[17911, 387, 474, 8, 67, "Text"],

Cell[CellGroupData[{
Cell[18410, 399, 99, 2, 46, "Subsection",
  Evaluatable->False],
Cell[18512, 403, 111, 2, 29, "Text",
  Evaluatable->False],
Cell[18626, 407, 106, 2, 70, "Input"],
Cell[18735, 411, 112, 2, 29, "Text",
  Evaluatable->False],
Cell[18850, 415, 142, 3, 83, "Input"],
Cell[18995, 420, 98, 2, 29, "Text",
  Evaluatable->False],
Cell[19096, 424, 106, 2, 70, "Input"],
Cell[19205, 428, 85, 2, 29, "Text",
  Evaluatable->False],
Cell[19293, 432, 134, 2, 70, "Input"],
Cell[19430, 436, 108, 2, 29, "Text",
  Evaluatable->False],
Cell[19541, 440, 182, 4, 83, "Input"],
Cell[19726, 446, 85, 2, 29, "Text",
  Evaluatable->False],
Cell[19814, 450, 134, 2, 70, "Input"],
Cell[19951, 454, 108, 2, 29, "Text",
  Evaluatable->False],
Cell[20062, 458, 182, 4, 83, "Input"],
Cell[20247, 464, 113, 2, 29, "Text",
  Evaluatable->False],
Cell[20363, 468, 156, 2, 70, "Input"],
Cell[20522, 472, 114, 2, 29, "Text",
  Evaluatable->False],
Cell[20639, 476, 177, 4, 83, "Input"],
Cell[20819, 482, 90, 2, 29, "Text",
  Evaluatable->False],
Cell[20912, 486, 70, 1, 50, "Input"],
Cell[20985, 489, 88, 2, 29, "Text",
  Evaluatable->False],
Cell[21076, 493, 70, 1, 50, "Input"],
Cell[21149, 496, 93, 2, 29, "Text",
  Evaluatable->False],
Cell[21245, 500, 53, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21335, 506, 108, 2, 46, "Subsection",
  Evaluatable->False],
Cell[21446, 510, 327, 9, 98, "Text"],
Cell[21776, 521, 620, 12, 112, "Input"],
Cell[22399, 535, 1057, 26, 172, "Text"],
Cell[23459, 563, 98, 2, 29, "Text",
  Evaluatable->False],
Cell[23560, 567, 346, 6, 90, "Input"],
Cell[23909, 575, 151, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[24085, 582, 36, 1, 50, "Input"],
Cell[24124, 585, 191454, 3369, 5517, "Output"]
}, Open  ]],
Cell[215593, 3957, 43, 0, 29, "Text"],
Cell[215639, 3959, 59, 1, 50, "Input"],
Cell[215701, 3962, 119, 2, 29, "Text",
  Evaluatable->False],
Cell[215823, 3966, 549, 10, 110, "Input"],
Cell[216375, 3978, 282, 8, 30, "Text",
  Evaluatable->False],
Cell[216660, 3988, 756, 17, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217453, 4010, 152, 5, 46, "Subsection",
  Evaluatable->False],
Cell[217608, 4017, 234, 5, 48, "Text"],
Cell[217845, 4024, 82, 1, 50, "Input"],
Cell[217930, 4027, 705, 22, 91, "Text",
  Evaluatable->False],
Cell[218638, 4051, 354, 7, 110, "Input"],
Cell[218995, 4060, 130, 3, 29, "Text"],
Cell[219128, 4065, 201, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[219354, 4073, 64, 1, 50, "Input"],
Cell[219421, 4076, 120, 3, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219578, 4084, 64, 1, 50, "Input"],
Cell[219645, 4087, 120, 3, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219802, 4095, 64, 1, 50, "Input"],
Cell[219869, 4098, 120, 3, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220026, 4106, 64, 1, 50, "Input"],
Cell[220093, 4109, 120, 3, 65, "Output"]
}, Open  ]],
Cell[220228, 4115, 37, 0, 29, "Text"],
Cell[220268, 4117, 76, 1, 50, "Input"],
Cell[220347, 4120, 124, 3, 29, "Text"],
Cell[220474, 4125, 301, 5, 130, "Input"],
Cell[220778, 4132, 433, 13, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[221248, 4150, 109, 3, 46, "Subsection"],
Cell[221360, 4155, 141, 3, 29, "Text"],
Cell[221504, 4160, 1104, 19, 211, "Input"],
Cell[222611, 4181, 514, 13, 209, "Input"],
Cell[223128, 4196, 423, 10, 93, "Input"],
Cell[223554, 4208, 303, 10, 93, "Input"],
Cell[223860, 4220, 636, 12, 108, "Input"],
Cell[224499, 4234, 66, 0, 29, "Text"],
Cell[224568, 4236, 79, 1, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[224696, 4243, 77, 2, 56, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[224798, 4249, 128, 5, 46, "Subsection"],
Cell[224929, 4256, 108, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[225062, 4265, 38, 0, 50, "Input"],
Cell[225103, 4267, 175, 3, 25, "Print"]
}, Open  ]],
Cell[225293, 4273, 227, 6, 29, "Text"],
Cell[225523, 4281, 63, 0, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[225623, 4286, 35, 0, 46, "Subsection"],
Cell[225661, 4288, 47, 0, 29, "Text"],
Cell[225711, 4290, 119, 2, 50, "Input"],
Cell[225833, 4294, 124, 3, 29, "Text"],
Cell[225960, 4299, 133, 3, 50, "Input"],
Cell[226096, 4304, 43, 0, 29, "Text"],
Cell[226142, 4306, 59, 1, 50, "Input"],
Cell[226204, 4309, 105, 3, 29, "Text"],
Cell[226312, 4314, 333, 5, 130, "Input"],
Cell[226648, 4321, 117, 3, 29, "Text"],
Cell[226768, 4326, 86, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[226879, 4331, 73, 0, 37, "Subsubsection"],
Cell[226955, 4333, 375, 6, 67, "Text"],
Cell[227333, 4341, 228, 3, 90, "Input"],
Cell[227564, 4346, 123, 3, 29, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[227736, 4355, 131, 4, 46, "Subsection"],
Cell[227870, 4361, 165, 5, 29, "Text"],
Cell[228038, 4368, 164, 3, 70, "Input"],
Cell[228205, 4373, 32, 0, 29, "Text"],
Cell[228240, 4375, 130, 2, 50, "Input"],
Cell[228373, 4379, 69, 0, 29, "Text"],
Cell[228445, 4381, 69, 1, 50, "Input"],
Cell[228517, 4384, 302, 5, 48, "Text"],
Cell[228822, 4391, 90, 1, 50, "Input"],
Cell[228915, 4394, 52, 0, 29, "Text"],
Cell[228970, 4396, 72, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[229067, 4401, 254, 5, 70, "Input"],
Cell[229324, 4408, 56, 1, 49, "Output"]
}, Open  ]],
Cell[229395, 4412, 78, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[229498, 4417, 289, 6, 90, "Input"],
Cell[229790, 4425, 69, 1, 49, "Output"]
}, Open  ]],
Cell[229874, 4429, 434, 16, 29, "Text"],

Cell[CellGroupData[{
Cell[230333, 4449, 111, 2, 50, "Input"],
Cell[230447, 4453, 52, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230536, 4459, 488, 9, 170, "Input"],
Cell[231027, 4470, 69, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231133, 4476, 45, 1, 50, "Input"],
Cell[231181, 4479, 52, 1, 49, "Output"]
}, Open  ]],
Cell[231248, 4483, 256, 9, 29, "Text"],

Cell[CellGroupData[{
Cell[231529, 4496, 587, 10, 190, "Input"],
Cell[232119, 4508, 68, 1, 49, "Output"]
}, Open  ]],
Cell[232202, 4512, 75, 1, 29, "Text"],
Cell[232280, 4515, 166, 4, 50, "Input"],
Cell[232449, 4521, 59, 0, 29, "Text"],
Cell[232511, 4523, 181, 4, 50, "Input"],
Cell[232695, 4529, 328, 7, 48, "Text"],
Cell[233026, 4538, 380, 7, 130, "Input"],

Cell[CellGroupData[{
Cell[233431, 4549, 111, 2, 50, "Input"],
Cell[233545, 4553, 50314, 2684, 50, 38237, 2531, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[283874, 7240, 112, 3, 29, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[284023, 7248, 64, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[284112, 7252, 76, 0, 37, "Subsubsection"],
Cell[284191, 7254, 113, 3, 29, "Text"],
Cell[284307, 7259, 4891, 79, 610, "Input"],
Cell[289201, 7340, 53, 0, 29, "Text"],
Cell[289257, 7342, 626, 12, 190, "Input"],
Cell[289886, 7356, 197, 4, 48, "Text"],
Cell[290086, 7362, 386, 7, 150, "Input"],
Cell[290475, 7371, 672, 13, 210, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[291184, 7389, 36, 0, 37, "Subsubsection"],
Cell[291223, 7391, 150, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[291398, 7398, 114, 2, 50, "Input"],
Cell[291515, 7402, 85, 1, 25, "Print"]
}, Open  ]],
Cell[291615, 7406, 38, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[291678, 7410, 60, 1, 50, "Input"],
Cell[291741, 7413, 14053, 444, 7488, "Print"]
}, Open  ]],
Cell[305809, 7860, 469, 13, 48, "Text"],

Cell[CellGroupData[{
Cell[306303, 7877, 50, 1, 50, "Input"],
Cell[306356, 7880, 187, 3, 63, "Message"]
}, Open  ]],
Cell[306558, 7886, 130, 3, 29, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[306725, 7894, 44, 0, 37, "Subsubsection"],
Cell[306772, 7896, 103, 3, 29, "Text"],
Cell[306878, 7901, 209, 4, 70, "Input"],
Cell[307090, 7907, 220, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[307335, 7919, 201, 4, 70, "Input"],
Cell[307539, 7925, 68, 1, 49, "Output"]
}, Open  ]],
Cell[307622, 7929, 67, 0, 29, "Text"],
Cell[307692, 7931, 186, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[307903, 7939, 111, 2, 50, "Input"],
Cell[308017, 7943, 35068, 1751, 50, 23913, 1609, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[343100, 9697, 95, 1, 29, "Text"],
Cell[343198, 9700, 46, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[343269, 9704, 51, 1, 50, "Input"],
Cell[343323, 9707, 165, 3, 25, "Print"]
}, Open  ]],
Cell[343503, 9713, 112, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[343640, 9720, 221, 4, 70, "Input"],
Cell[343864, 9726, 76, 1, 49, "Output"]
}, Open  ]],
Cell[343955, 9730, 76, 0, 29, "Text"],
Cell[344034, 9732, 184, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[344243, 9740, 111, 2, 50, "Input"],
Cell[344357, 9744, 35068, 1751, 50, 23913, 1609, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[379440, 11498, 27, 0, 29, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[379528, 11505, 40, 0, 56, "Section"],
Cell[379571, 11507, 90, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[379686, 11514, 1146, 25, 195, "Input"],
Cell[380835, 11541, 1349, 28, 161, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[382233, 11575, 30, 0, 56, "Section"],
Cell[382266, 11577, 67, 0, 29, "Text"],
Cell[382336, 11579, 118, 2, 70, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

